        SUBROUTINE HZ00035(IFLAG)
****************************************************************************
*
* Purpose: Produces histograms for the differential di-jet cross
*          section in photoproduction, as a function of the momentum
*          fraction of the parton in the photon as reconstructed from the
*          two highest transverse energy final state jets.
*
*
*          d sigma(ep->2 jets + X)/(dx_gamma)
*
*          Event selection cuts : Q2 < 0.01 GeV^2
*          (cut scenario 1)       0.5 < y <0.7
*                                 -0.5 < eta1,eta2 < 2.5
*                                 |eta1-eta2| < 1
*                                 ET1,ET2 > 4 GeV
*                                 M_2Jet > 12 GeV
*
*          Event selection cuts : Q2 < 0.01 GeV^2
*          (cut scenario 2)       0.5 < y <0.7
*                                 -0.5 < eta1,eta2 < 2.5
*                                 |eta1-eta2| < 1
*                                 ET1,ET2 > 6 GeV after Pedestalsubtraction
*                                 eta1,eta2 > -0.9 - ln(x_gamma)
*
*          Definition Pedestal:
*                              ET_Ped= 1/A * Sum (ET)
*
*                        Sum = -1<eta-eta1<1,-pi<phi-phi1<pi
*                          A = Area for which the sum of Et is taken,
*                              outside of jets
*
*           with:   Q2 = photon virtuality
*                   y  = E(photon)/E(beam) = normalized photon energy
*            eta1,eta2 = pseudorapidities of the two highest transverse energy
*                        jets in HERA laboratory frame
*            ET1,ET2   = transverse energies of these two jets
*             M_2Jet   = invariant mass of these two jets
*            x_gamma   = (ET1*exp(-eta1)+ET2*exp(-eta2))/(2*E_photon)
*
*
* Reference : O.Kaufmann, Phd-thesis, Uni Heidelberg
*             H1 Collab, DESY00035, subm. Phys.Lett.
*
* Arguments:  iflag=1 initialisation/booking of histograms
*             iflag=2 event processing/filling of MC histograms
*             iflag=3 termination/final normalisation
*                     (the variables Xsec (total cross section) and
*                      Ntot (total number of events) have to be set before
*                      calling the termination routine in order to get a
*                      correct normalisation for the MC histograms)
*
*             This photoproduction routine has to be run twice with the
*             following code additions:
* 	              +1000 for the DIRECT component run.
*	              +2000 for the RESOLVED component run.
*                     +0 for both together
*             for all three phases (iflag=1,2,3)
*
* written by: Oliver Kaufmann (Kaufmann@slac.stanford.edu) on 26/08/99
*     modified for split resolved and direct components by Russell Taylor
*
* 3 bug fixes for JetWeb by M.Wing, J.Butterworth, Oct 2002:
*
*     Pedestal subtraction wass not implemented even though the comments
*     below indicate that it was. 
*     NB The pedestal energy density (ED) IS included in the routine. jets
*     are found with cone radius 0.7 and so the energy to subtract from
*     a jet is ED*PI*(0.7)**2
*     (affects only scenario 2)
*
*     Also, the eta cut is applied after the et ordering (affects both scenarios)
*     
*     The M2JET cut was not being applied (affects only cut scenario one)
*
****************************************************************************
*
* Output graphs:
*---------------
* DATA
*
* histograms -1,-2 contain the measured di-jet cross section data,
* d sigma/(dx_gamma)
* errors are statistical + uncorrelated systematic
* -1        cut scenario 1
* -2        cut scenario 2
*
*
* Monte-Carlo
* d sigma/(dx_gamma)
*  1        cut scenario 1
*  2        cut scenario 2
*               These graphs will be
*               meaningless unless Xsec and Ntot are set before
*               calling the termination routine.
*               (Xsec - total cross section returned by MC)
*               (Ntot - number of events passed to this routine)
* 201: dsigma/dxgamma scenario 1 Mjj>12
* 202: dsigma/dxgamma scenario 2
*****************************************************************************
        IMPLICIT NONE
*
#include "hzhbook.inc"
#include "hepevtp.inc"
#include "heracmn.inc"
#include "hzfunc.inc"
#include "hzjetcmn.inc"

      Character xxxx*6
      Data xxxx/'d00035'/
*
      REAL PI
      PARAMETER (PI=3.1412)

C --- PXCONE stuff ---
      INTEGER  ITKDM,MXTRK
      PARAMETER  (ITKDM=4,MXTRK=500)
      INTEGER  MXJET, MXTRAK, MXPROT
      PARAMETER  (MXJET=50,MXTRAK=500,MXPROT=500)
      INTEGER  IPASS (MXTRAK),IJMUL (MXJET)
      INTEGER  NTRAK,injet,IERR,MODE
      DOUBLE PRECISION  PTRAK (ITKDM,MXTRK),PJET (5,MXJET)
      DOUBLE PRECISION  EPSLON, OVLIM
*
      DOUBLE PRECISION phi,px,py,pz,pt,ptsq,ppsq
      DOUBLE PRECISION eta,rap,Et,theta
      INTEGER ref(NMXHEP)
*
      Real nev,nfill1,nfill2,nfill3,nfill4,nfill5,nfill6
      Save nev,nfill1,nfill2,nfill3,nfill4,nfill5,nfill6
      INTEGER NPTBIN,NXGBIN,CUTSCE
      Real IJ,JK
      PARAMETER (NPTBIN=1,NXGBIN=7,CUTSCE=2)
*
      REAL XBIN(NXGBIN+1),PTBIN(NPTBIN+1)
      REAL XSDI1(NXGBIN),XERR1(NXGBIN)
      REAL XSDI2(NXGBIN),XERR2(NXGBIN)
      REAL ETPED(6)	
*
      Integer count,loop
      INTEGER I,J,k,IP,IL,NJET1
      INTEGER IFLAG,IFFLAG,IPROC
      REAL TMP(10),TMPE(10)
      REAL EBEAM,Q2,Y,ETA1,ETA2,ET1,ET2,ETPED1,ETPED2
      REAL ETJET,M2JET,PH1,PH2
      REAL ET2LOG,XGAMMA,XGAMPED,WBIN,WBINPED,ANORM
      REAL help,XGAMPED1,XGAMMA1
*
      Logical lp, first
      Data lp, first/.false.,.true./
      Save lp, first
*
      Double precision RCONE
      parameter (rcone=0.7)
      INTEGER ID,IDMC,IMODE
      CHARACTER*5 JETNAM
*
*      binning definition
*
C     DATA XBIN /0.04,0.07,0.126,0.2,0.316,0.5,0.794,1.09/
      DATA XBIN /-1.4,-1.15,-0.9,-0.7,-0.5,-0.3,-0.1,0.04/
      Save xbin
*
*     di-jet cross section data
*
      DATA XSDI1/0.49,0.88,0.92,0.83,0.85,0.78,0.54/
      Data XSDI2/0.06,0.17,0.17,0.21,0.29,0.54,0.47/
      Save xsdi1,xsdi2
*
*     di-jet cross section errors
*
      DATA XERR1/0.14,0.22,0.24,0.14,0.17,0.14,0.12/
      Data Xerr2/0.03,0.06,0.06,0.06,0.09,0.14,0.12/
*
*     Pedestal Energy as measured in Data
*
      DATA ETPED /0.44,0.53,0.81,1.14,1.415,1.345/
      Save ETPED
*
*     Determine the process type.
      iproc=(mod(iflag,10000)/1000)
      if ((iproc.lt.0).or.(iproc.gt.2)) then
         write(HZUNIT,*) 'HZ',xxxx,': illegal IPROC:',iproc
         return
      endif
*
      IF (MOD(iflag,10).eq.1) THEN
* *** Initialisation run ***
*
       nev=0.
       nfill1=0.
       nfill2=0.
       nfill3=0.
       nfill4=0.
       nfill5=0.
       nfill6=0.
*
       IF (first) THEN
          CALL HCDIR('//PAWC',' ')
          CALL HMDIR(xxxx,'S')
          CALL HCDIR('//HISTO',' ')
          CALL HMDIR(xxxx,'S')
       ELSE
          CALL HCDIR('//PAWC/d00035',' ')
          CALL HCDIR('//HISTO/d00035',' ')
       ENDIF
*
       ID=1+100*iproc
       CALL HBOOKB(ID,' d[s]/dx?[g]! scen1 ',NXGBIN,XBIN,0.)
       CALL  HBARX(ID)
*
       ID=2+100*iproc
       CALL HBOOKB(id,' d[s]/dlog(x?[g]!) scen2 ',NXGBIN,XBIN,0.)
       CALL  HBARX(id)

       IF (first) THEN
c     Book and fill the data.
          ID=1
          CALL HBOOKB(-ID,' d[s]/dx?[g]! scen1 ',NXGBIN,XBIN,0.)
          CALL HPAK(-ID, XSDI1)
          CALL HPAKE(-ID,XERR1)

          ID=2
          CALL HBOOKB(-id,' d[s]/dlog(x?[g]!) scen2 ',NXGBIN,XBIN,0.)
          CALL HPAK(-id, XSDI2)
          CALL HPAKE(-id,XERR2)

          first=.FALSE.

       ENDIF
*
C==================================================================
*
      ELSE IF (MOD(iflag,10).EQ.2) THEN
* ***  Event loop, fill MC histograms ***
*
       CALL HCDIR('//PAWC/'//xxxx,' ')
*
*       nev=nev+wtx
*
*      test kinematic range
*
       Q2=REAL(HZPHOKIN(1))
       Y=REAL(HZPHOKIN(3))
*
       IF (Q2.GT.0.01) GOTO 65
       IF (Y.LT.0.5.OR.Y.GT.0.7) GOTO 65
*
*      find electron beam energy
*
       IFFLAG=HZIBEAM(IP,IL)
       IF (IFFLAG.EQ.0.OR.IFFLAG.EQ.1) THEN
        EBEAM=PHEP(4,IL)
        IF (ABS(EBEAM-27.55).GT.0.5) THEN
         PRINT *,'HZ',xxxx,' Warning: wrong electron beam energy'
        END IF
       ELSE
        EBEAM=27.55
       END IF
*
       if (lp) then
        write(hzunit,*) ' Q2= ',real(q2),' y= ',real(y),' Eb= ',ebeam
       endif
*
       numjets=0
*
* --- prepare pxcone call
       MODE=2
       EPSLON=4.D0
       OVLIM=7.5D-1
*
*       if (lp) call hzlihep(2)
*
       Do i=1,4
        do j=1,mxtrk
         ptrak(i,j)=0.
        enddo
       enddo
*
       count=0
       DO loop=1,NHEP
*      skip unstable particles and scattered lepton
        IF (ISTHEP(loop).eq.1 .and.abs(idhep(loop)).ne.11) THEN
         IF (count.eq.MXTRK) THEN
            write(hzunit,*) 'Hz',xxxx,'Too many particles for PXCONE'
     $           ,count
          GOTO 165
         ELSE
          count=count+1
          PTRAK(1,count)=PHEP(1,loop)
          PTRAK(2,count)=PHEP(2,loop)
          PTRAK(3,count)=PHEP(3,loop)
          PTRAK(4,count)=PHEP(4,loop)
          ref(count)=loop
         ENDIF
        ENDIF
       ENDDO
 165   CONTINUE
       if (lp) then
        write(hzunit,*) ' count= ',count
       endif
       NTRAK=count
* --- do pxcone call
       CALL PXCONE (MODE,NTRAK,ITKDM,PTRAK,RCONE,EPSLON,OVLIM,
     &          MXJET,injet,PJET,IPASS,IJMUL,IERR)
*
       if (lp) then
          write(hzunit,*) ' injet= ',injet,' Pjet= ',pjet
       endif
*
       IF (IERR.ne.0) THEN
        write(hzunit,*) 'Hz',xxxx, ' PXCONE returns error'
       ENDIF
       IF (injet.gt.MXJET) THEN
        write(hzunit,*) 'Hz',xxxx, 'Too many jets, increase MXJET',injet
       ENDIF
*
* --- get output
*
       IF (injet.gt.MAXHZJETS) THEN
        injet=MAXHZJETS
       ENDIF
*
       numjets=0
       DO loop=1,injet
        px=PJET(1,loop)
        py=PJET(2,loop)
        pz=PJET(3,loop)
        ptsq=px**2+py**2
        ppsq=(SQRT(ptsq+pz**2)+ABS(pz))**2
        IF (ptsq.le.4.25E-18*ppsq) THEN
         eta=20.D0
        ELSE
         eta=0.5*LOG(ppsq/ptsq)
        ENDIF
        eta=SIGN(eta,pz)
        IF (ptsq.EQ.0.D0) THEN
         phi=0.D0
        ELSE
         phi=ATAN2(py,px)
        ENDIF
*
        IF (eta.LT.2.5 .AND. eta.GT.-0.5 .AND. numjets.LT.MAXHZJETS)
     &       THEN
           NUMJETS=NUMJETS+1
           Et=PJET(4,loop)*SQRT(ptsq/(ptsq+pz**2))        
           Jets(numjets,1)=eta     ! eta
           Jets(numjets,2)=phi     ! phi
           Jets(numjets,3)=Et      ! Et
           Jets(numjets,4)=PJET(4,loop) ! E
           Jets(numjets,5)=PJET(1,loop) ! px
           Jets(numjets,6)=PJET(2,loop) ! py
           Jets(numjets,7)=PJET(3,loop) ! pz
           Jets(numjets,8)=0       ! m

        endif
      Enddo

*
C       DO loop=1,ntrak
C        iJetNo(ref(loop))=IPASS(loop)
C       ENDDO
*
*       if (lp) call hzlijet(numjets,jets)
*
*      at least two jets required
      IF (Numjets.LT.2) GOTO 65
*
*     pseudorapidity range of jets
       ETA1=jets(1,1)
       ETA2=jets(2,1)
*     
       if (lp) then
          write(hzunit,*) ' eta1= ',eta1,' eta2= ',eta2,ABS(ETA1-ETA2)
       endif
*     
       IF (ABS(ETA1-ETA2).GT.1.) GOTO 65
       
*     
       IF (ETA1.gt.2.5.or.eta2.gt.2.5.or.eta1.lt.-0.5
     +      .or.eta2.lt.-0.5) GOTO 65
*
       if (lp) write(hzunit,*) ' ...passed eta cuts '
*     
*     pedestal energy (as measured in data)
*     
       do i=1,6
          jk=-1.+(0.5*i)
          ij=-0.5+(0.5*i)
          if (lp) then
             write(hzunit,*) ' ik= ',jk,' ij= ',ij
          endif
          if(eta1.gt.jk.and.eta1.lt.ij)then
             ETPED1=JETS(1,3)-ETPED(I)*PI*(0.7)**2
          endif
*     
          if(eta2.gt.jk.and.eta2.lt.ij)then
             ETPED2=JETS(2,3)-ETPED(I)*PI*(0.7)**2
          endif
       end do
*     
       if (lp) then
          write(hzunit,*) ' ETPED1= ',ETPED1,' ETPED2= ',ETPED2
       endif
*     
*     jet transverse energies
*     
       ET1=JETS(1,3)
       ET2=JETS(2,3)
       PH1=JETS(1,2)
       PH2=JETS(2,2)
*
       M2JET=sqrt((2*ET1*ET2*(cosh(ETA1-ETA2)-cos(abs(PH1-PH2)))))
*     
       XGAMMA1=(ET1*EXP(-ETA1)+ET2*EXP(-ETA2))/(2.*Y*EBEAM)
       if (xgamma1.gt.0.) then
          XGAMMA=log10(xgamma1)
       else
          write(hzunit,*) ' xgamma1= ',xgamma1,' ?? '
       endif
*     
       XGAMPED1=(ETPED1*EXP(-ETA1)+ETPED2*EXP(-ETA2))/(2.*Y*EBEAM)
       if (xgamped1.gt.0.) then
          XGAMPED=log10(XGAMPED1)
       else
          write(hzunit,*) ' xgamped= ',xgamped1,' ?? '
       endif
*     
       if (lp) then
          write(hzunit,*) ' Et1= ',et1,' et2= ',et2
          write(hzunit,*) ' Phi1= ',ph1,' Phi2= ',ph2,abs(PH1-PH2)
          write(hzunit,*) ' M2JET= ',M2JET
          write(hzunit,*) ' XGAMMA= ',XGAMMA,' XGAMPED= ',XGAMPED
       endif
*     
*     cut scenario 1
*     
       IF (I.GT.NXGBIN) GOTO 65
*
       nfill1=nfill1+wtx
       if (lp) then
        write(hzunit,*) 1+100*iproc,' FILLING: '
        write(hzunit,*) ' xgamma= ',xgamma,' nfill1= ',nfill1
       endif
c     jmb
       if (m2jet.gt.12.) THEN
          CALL HFILL (1+100*iproc,XGAMMA,0.,WTX)   	
       endif
*
*      cut scenario 2
*
       if (lp) write(hzunit,*) '  et1,  et2= ',ET1,ET2
       if (lp) write(hzunit,*) ' eta1, eta2= ',ETA1,ETA2
       if (lp) write(hzunit,*) ' log= ',log(XGAMMA1)
*
c       IF(ET1.gt.6..and.ET2.gt.6..and.
c     +	 (ETA1.gt.(-0.9 - log(XGAMMA1))).and.
c     +   (ETA2.gt.(-0.9 - log(XGAMMA1))))THEN
c JMB
       IF(ETPED1.gt.6..and.ETPED2.gt.6..and.
     +      (ETA1.gt.(-0.9 - log(XGAMPED1))).and.
     +      (ETA2.gt.(-0.9 - log(XGAMPED1))))THEN
*
         nfill2=nfill2+wtx
         if (lp) then
          write(hzunit,*) ' xgamma= ',xgamma,' nfill2= ',nfill2
         endif
        CALL HFILL (2+100*iproc,XGAMMA,0.,WTX)
*
       ENDIF	
*
65     CONTINUE
*
      ELSE IF (MOD(iflag,10).eq.3) THEN
C *** Termination, fix normalisation of MC histograms ***
*
       IF (iproc.eq.2.or.iproc.eq.0) THEN
          WRITE (HZUNIT,*) 'HZ00035: finishing off'
       ENDIF

       CALL HCDIR('//PAWC/'//xxxx,' ')
*
       IF (Xsec.eq.0) THEN
	PRINT*,'HZ',xxxx,': termination called with zero cross section'
	PRINT*,'          cross section graph meaningless'
	PRINT*,'	      in process :',iproc*1000
	Xsec=1
       ENDIF
       IF (Ntot.eq.0) THEN
	PRINT*,'HZ',xxxx,' no total events'
	PRINT*,'          cross section graph meaningless'
        PRINT*,'	    in process :',iproc*1000
	Ntot=1
*
        ANORM=0.
       ELSE
        if (xsec.ne.1) then
         ANORM=Ntot/XSEC
        else
         ANORM=1000.
        endif
*
       ENDIF
*
       if (lp) then
          write(hzunit,*) ' iproc= ',iproc
          write(hzunit,*) 'HZ',xxxx,': ntot= ', ntot,' xsec (nb)= ',xsec
          write(hzunit,*) ' scenario1: ',nfill1,' sec: ',nfill1/ANORM
          write(hzunit,*) ' scenario2: ',nfill2,' sec: ',nfill2/ANORM
       endif

*
       DO I=1,2
          ID=100*iproc+i
          if (lp) write(hzunit,*) 'Hz',xxxx,' norm id= ',id
          call hzhinrm(ID,0,anorm,1)
       END DO

c     Finally, add the direct and resolved together.
       IF (iproc.eq.2.or.iproc.eq.0) THEN
          IF (iproc.eq.2) THEN
             CALL HOPERA(101,'+e',201,1,1.,1.)
             CALL HOPERA(102,'+e',202,2,1.,1.)
          ENDIF
       ENDIF

      ELSE
       WRITE(HZUNIT,*) 'HZ',xxxx,' Unknown flag',iflag
      ENDIF
      RETURN
      END
