      SUBROUTINE HZ01225(iflag)
c     -----------------------------------------------------------------------
c     
c     This photoproduction routine has to be run twice with the
c     following
c     code additions:
c     +1000 for the DIRECT component run.
c     +2000 for the RESOLVED component run.
c     +0 for both together
c     for all three phases (iflag=1,2,3)
c     
c     +10000 to run on parton showers instead of final state particles.
c     +100000 is used by NLO intergration options.
c     
c     iflag = 1,2 or 3 depending on whether it is the initialization,
c     processing or termination phase (respectively)
c     
c     The default jetfinder is KTCLUS(
c     To change jetfinder use these values to call the initialisation
c     phase.
c     1 + 10 c (jetfinder number)
c
c     All these graphs will be meaningless unless Xsec and Ntot are set
c     before calling the termination routine.
c     (Xsec - total cross section returned by MC)
c     (Ntot - number of events passed to this routine)
c     
c     Cuts :
c     Q2 < 1 GeV^2
c     0.1 < y_bj < 0.9
c     Et > 15, 25 GeV
c     -0.5 < eta < 2.5
c
c     id 11, d\sigma/dM_jj
c     id 12, d\sigma/dET(mean)
c     id 13, d\sigma/dET(max)
c     id 14, d\sigma/detabar, 0.1<y<0.5, 25<ET(max)<35 GeV
c     id 15, d\sigma/detabar, 0.1<y<0.5, 35<ET(max)<80 GeV
c     id 16, d\sigma/detabar, 0.5<y<0.9, 25<ET(max)<35 GeV
c     id 17, d\sigma/detabar, 0.5<y<0.9, 35<ET(max)<80 GeV
c     id 18, d\sigma/dxgamma, xp<0.1
c     id 19, d\sigma/dxgamma, xp>0.1
c     id 20, d\sigma/dxp,     xgamma<0.8
c     id 21, d\sigma/dxp,     xgamma>0.8
c     id 22, d\sigma/dxgamma, 25<ET(max)<35 GeV
c     id 23, d\sigma/dxgamma, 35<ET(max)<80 GeV
c     id 24, d\sigma/d\cos(theta*), xgamma<0.8
c     id 25, d\sigma/d\cos(theta*), xgamma>0.8
c     id 26, d\sigma/d\cos(theta*), xgamma<0.8, M_jj>65 GeV
c     id 27, d\sigma/d\cos(theta*), xgamma>0.8, M_jj>65 GeV
c     
c     Author : Matthew Wing (wing@mail.desy.de)
c     Reference : DESY 01-225, Eur.Phys.J.C25:13-23,2002
c     Version 1.0, 21/05/02,  Stat. errors only
c     Version 2.0, 12/07/02,  Stat.+syst. (uncorrelated) errors
c     
c     ---------------------------------------------------------------
*     
*     HERA Tuning defined commons

      IMPLICIT NONE

#include "hepevtp.inc"
#include "heracmn.inc"
#include "hzfunc.inc"
#include "hzjetcmn.inc"
      CHARACTER*6 jetf
      
      INTEGER NJET
c      DOUBLE PRECISION Jets(50,8)
      DOUBLE PRECISION CONER
      SAVE CONER
      
      DOUBLE PRECISION elecE
      INTEGER myil,myip

c     Iterators
      INTEGER i_etcut, i_jet, j_jet, i_plot, i_bin

      DOUBLE PRECISION xgamcut
      double precision xpcut
      DOUBLE PRECISION phi(2),px(2),py(2),pz(2),ptsq(2)
      DOUBLE PRECISION ppsq(2),energy(2),mass(2)
      DOUBLE PRECISION rap(2),Et(2)
      DOUBLE PRECISION ybj,q2

C     --- cuts arrays
      DOUBLE PRECISION ybjcut(3),q2cut(2)
      DOUBLE PRECISION rapcut(2),mjjcut,etabarcut(2)
      double precision etcut(4)
c     photoproduction cuts
      DATA ybjcut / 0.1, 0.5, 0.9 /
      DATA q2cut / 0., 1. /
      DATA xgamcut / 0.8 /
      DATA xpcut / 0.1 /
      DATA mjjcut / 65. /
      data rapcut / -0.5, 2.5 /
      data etcut / 15., 25., 35., 80. /

C     --- private copies of Xsec and Ntot from HERACMN
      DOUBLE PRECISION mhxsec(2),mhntot(2)

c     Unit to read data file from
      INTEGER ipunit
      PARAMETER(ipunit=8)

c     The data
c     --------------------------------------
c     Notes:
c
c     stat. and syst. errors given as % in paper. Convert to pb later.
c     Total uncertainty given in paper includes stat., syst., and energy scale 
c     uncertainties.
c     Remove energy scale uncertainty from total uncertainty for now and 
c     assume it is a ~10% normalisation uncertainty. See later.  (MW, 12/07/02)
c     
c --  Mjj cross section (TABLE 2)
      integer n_mjjbins
      parameter (n_mjjbins=6)
      real mjjbins(n_mjjbins+1)
      real mjjdat(n_mjjbins)
      real mjjstat(n_mjjbins)
      real mjjtotp(n_mjjbins)
      real mjjescalep(n_mjjbins)
      real mjjtotm(n_mjjbins)
      real mjjescalem(n_mjjbins)
      real mjjerr(n_mjjbins)
      data mjjbins    / 45.0, 57.5, 70.0, 90.0, 110.0, 135.0, 180.0 /
      data mjjdat     / 4.30, 3.69, 1.33, 0.39, 0.101, 0.0102 /
      data mjjstat    / 2.5, 2.9, 3.7, 6.9, 12.0, 27.1 /
      data mjjtotp   / 13., 11., 13., 12., 19., 32. /
      data mjjtotm   / 14., 11., 11., 16., 18., 30. /
      data mjjescalep / 8., 9., 11., 8., 13., 14. /
      data mjjescalem / 8., 8., 8., 12., 11., 9. /
      real mjj_zero(n_mjjbins)
      data mjj_zero / n_mjjbins*0. /

c --  ET(mean) cross section (TABLE 2)
      integer n_etmeanbins
      parameter (n_etmeanbins=4)
      real etmeanbins(n_etmeanbins+1)
      real etmeandat(n_etmeanbins)
      real etmeanstat(n_etmeanbins)
      real etmeantotp(n_etmeanbins)
      real etmeanescalep(n_etmeanbins)
      real etmeantotm(n_etmeanbins)
      real etmeanescalem(n_etmeanbins)
      real etmeanerr(n_etmeanbins)
      data etmeanbins    / 20.0, 30.0, 45.0, 60.0, 80.0 /
      data etmeandat     / 10.65, 2.41, 0.166, 0.0192 /
      data etmeanstat    / 1.8, 3.1, 11.6, 29.2 /
      data etmeantotp   / 12., 12., 16., 37. /
      data etmeantotm   / 12., 11., 17., 34. / 
      data etmeanescalep /  9., 10., 10., 22. / 
      data etmeanescalem /  8.,  8., 11., 16. /
      real etmean_zero(n_etmeanbins)
      data etmean_zero / n_etmeanbins*0. /

c --  ET(max) cross section (TABLE 2)
      integer n_etmaxbins
      parameter (n_etmaxbins=4)
      real etmaxbins(n_etmaxbins+1)
      real etmaxdat(n_etmaxbins)
      real etmaxstat(n_etmaxbins)
      real etmaxtotp(n_etmaxbins)
      real etmaxescalep(n_etmaxbins)
      real etmaxtotm(n_etmaxbins)
      real etmaxescalem(n_etmaxbins)
      real etmaxerr(n_etmaxbins)
      data etmaxbins    / 25.0, 35.0, 45.0, 60.0, 80.0 /
      data etmaxdat     / 12.36, 1.82, 0.252, 0.0198 /
      data etmaxstat    / 1.8, 3.9, 8.4, 27.4 /
      data etmaxtotp   / 11., 12., 15., 33. /
      data etmaxtotm   / 12., 12., 15., 32. /
      data etmaxescalep /  9.,  9., 11., 17. /
      data etmaxescalem /  8.,  9., 11., 15./
      real etmax_zero(n_etmaxbins)
      data etmax_zero / n_etmaxbins*0. /

c --  etabar cross sections (TABLE 3)
c     1: 0.1<y<0.5, 25<ET(max)<35 GeV 
c     2: 0.1<y<0.5, 35<ET(max)<80 GeV 
c     3: 0.5<y<0.9, 25<ET(max)<35 GeV 
c     4: 0.5<y<0.9, 35<ET(max)<80 GeV 
      integer n_etabarbins
      parameter (n_etabarbins=6)
      real etabarbins(n_etabarbins+1)
      real etabardat1(n_etabarbins), etabardat2(n_etabarbins)
      real etabarstat1(n_etabarbins), etabarstat2(n_etabarbins)
      real etabarerr1(n_etabarbins), etabarerr2(n_etabarbins)
      real etabartotp1(n_etabarbins), etabartotp2(n_etabarbins)
      real etabartotm1(n_etabarbins), etabartotm2(n_etabarbins)
      real etabarescalep1(n_etabarbins), etabarescalep2(n_etabarbins)
      real etabarescalem1(n_etabarbins), etabarescalem2(n_etabarbins)
      real etabardat3(n_etabarbins), etabardat4(n_etabarbins)
      real etabarstat3(n_etabarbins), etabarstat4(n_etabarbins)
      real etabarerr3(n_etabarbins), etabarerr4(n_etabarbins)
      real etabartotp3(n_etabarbins), etabartotp4(n_etabarbins)
      real etabartotm3(n_etabarbins), etabartotm4(n_etabarbins)
      real etabarescalep3(n_etabarbins), etabarescalep4(n_etabarbins)
      real etabarescalem3(n_etabarbins), etabarescalem4(n_etabarbins)
      data etabarbins     / 0., 0.6, 0.9, 1.3, 1.7, 2.1, 2.5 /
      data etabardat1     / 0., 7.55, 42.2, 52.2, 31.8, 10.3 /
      data etabarstat1    / 0., 10.0, 4.4, 4.2, 5.4, 10.1 /
      data etabartotp1   / 0., 20., 11., 10., 12., 17. /
      data etabartotm1   / 0., 22., 15., 11., 11., 18. /
      data etabarescalep1 / 0.,  7.,  7.,  7., 10., 10. /
      data etabarescalem1 / 0., 11., 12.,  8.,  7., 10. /
      data etabardat2     / 0.0, 0.0, 2.57, 10.2, 6.80, 1.47 /
      data etabarstat2    / 0.0, 0.0, 14.0, 8.0, 9.9, 21.0 /
      data etabartotp2   / 0., 0., 20., 14., 14., 24. /
      data etabartotm2   / 0., 0., 20., 13., 16., 24. /
      data etabarescalep2 / 0., 0.,  8., 10.,  9.,  9. /
      data etabarescalem2 / 0., 0.,  9.,  8., 11., 10. /
      data etabardat3     / 27.9, 66.4, 43.9, 20.8, 10.2, 2.75 /
      data etabarstat3    / 4.7, 4.5, 4.9, 7.4, 11.7, 24.8 /
      data etabartotp3   / 17., 13., 14., 13., 14., 30. / 
      data etabartotm3   / 14., 13., 11., 16., 14., 29. /
      data etabarescalep3 / 11.,  9., 11., 10.,  6.,  9. /
      data etabarescalem3 /  6.,  8.,  6., 13.,  4.,  3. /
      data etabardat4     / 0.0, 9.77, 14.14, 9.12, 2.59, 0.0 /
      data etabarstat4    / 0.0, 9.7, 7.5, 9.3, 18.1, 0.0 /
      data etabartotp4   / 0., 20., 13., 15., 24., 0. /
      data etabartotm4   / 0., 20., 13., 15., 24., 0. /
      data etabarescalep4 / 0., 10., 10., 10., 13., 0. /
      data etabarescalem4 / 0., 11.,  8.,  9., 13., 0. /
      real etabar_zero(n_etabarbins)
      data etabar_zero / n_etabarbins*0. /

c --  xgamma cross sections (TABLE 4 and TABLE 6)
c     1: xproton<0.1
c     2: xproton>0.1
c     3: 25<ET(max)<35 GeV 
c     4: 35<ET(max)<80 GeV 
      integer n_xgammabins
      parameter (n_xgammabins=5)
      real xgammabins(n_xgammabins+1)
      real xgammadat1(n_xgammabins), xgammadat2(n_xgammabins)
      real xgammastat1(n_xgammabins), xgammastat2(n_xgammabins)
      real xgammaerr1(n_xgammabins), xgammaerr2(n_xgammabins)
      real xgammatotp1(n_xgammabins), xgammatotp2(n_xgammabins)
      real xgammaescalep1(n_xgammabins), xgammaescalep2(n_xgammabins)
      real xgammatotm1(n_xgammabins), xgammatotm2(n_xgammabins)
      real xgammaescalem1(n_xgammabins), xgammaescalem2(n_xgammabins)
      real xgammadat3(n_xgammabins), xgammadat4(n_xgammabins)
      real xgammastat3(n_xgammabins), xgammastat4(n_xgammabins) 
      real xgammaerr3(n_xgammabins), xgammaerr4(n_xgammabins) 
      real xgammatotp3(n_xgammabins), xgammatotp4(n_xgammabins)
      real xgammaescalep3(n_xgammabins), xgammaescalep4(n_xgammabins)
      real xgammatotm3(n_xgammabins), xgammatotm4(n_xgammabins)
      real xgammaescalem3(n_xgammabins), xgammaescalem4(n_xgammabins)
      data xgammabins     / 0.1, 0.3, 0.5, 0.7, 0.85, 1.0 /
      data xgammadat1     / 0.0, 0.0, 33.5, 75.0, 182.7 /
      data xgammastat1    / 0.0, 0.0, 7.5, 5.8, 3.3 /
      data xgammatotp1   / 0., 0., 20., 19., 13. /
      data xgammatotm1   / 0., 0., 20., 14., 13. /
      data xgammaescalep1 / 0., 0., 15., 15.,  7. /
      data xgammaescalem1 / 0., 0., 15.,  7.,  6. /
      data xgammadat2     / 41.4, 78.9, 87.2, 126.8, 256.1 / 
      data xgammastat2    / 8.0, 5.1, 4.5, 4.3, 3.0 /
      data xgammatotp2   / 15., 13., 12., 12., 10. /
      data xgammatotm2   / 16., 13., 12., 12., 12. /
      data xgammaescalep2 /  7., 10., 10., 10.,  8. /
      data xgammaescalem2 /  8., 10.,  9.,  8.,  8. /
      data xgammadat3     / 40.1, 77.3, 101.1, 173.6, 361.7 / 
      data xgammastat3    / 8.4, 5.3, 4.3, 3.9, 2.5 /
      data xgammatotp3   / 17., 11., 14., 14., 11. /
      data xgammatotm3   / 18., 13., 14., 11., 12. /
      data xgammaescalep3 /  7.,  8., 11., 12.,  7. /
      data xgammaescalem3 /  8.,  9., 11.,  8.,  7. /
      data xgammadat4     / 2.34, 9.83, 19.7, 28.7, 78.1 / 
      data xgammastat4    / 27.5, 12.1, 8.5, 8.0, 4.9 /
      data xgammatotp4   / 34., 17., 14., 15., 13. /
      data xgammatotm4   / 31., 18., 15., 16., 12. /
      data xgammaescalep4 / 16.,  9., 10., 11., 10. /
      data xgammaescalem4 /  9., 10., 11., 10.,  8. /
      real xgamma_zero(n_xgammabins)
      data xgamma_zero / n_xgammabins*0. /

c --  xproton cross sections (TABLE 5)
c     1: xgamma<0.8
c     2: xgamma>0.8
      integer n_xpbins
      parameter (n_xpbins=5)
      real xpbins(n_xpbins+1)
      real xpdat1(n_xpbins),  xpdat2(n_xpbins)
      real xpstat1(n_xpbins), xpstat2(n_xpbins)
      real xptotp1(n_xpbins), xptotp2(n_xpbins)
      real xpescalep1(n_xpbins), xpescalep2(n_xpbins)
      real xptotm1(n_xpbins), xptotm2(n_xpbins)
      real xpescalem1(n_xpbins), xpescalem2(n_xpbins)
      real xperr1(n_xpbins), xperr2(n_xpbins)
      data xpbins     / 0.05, 0.10, 0.15, 0.22, 0.32, 0.6 /
      data xpdat1     / 288.0, 352.1, 298.6, 121.8,  7.86 /
      data xpstat1    /  5.3, 4.8, 4.4, 5.6,11.8  /
      data xptotp1   / 15., 13.,  9., 19., 17. /
      data xptotm1   / 17., 11., 15., 12., 19. /
      data xpescalep1 /  8.,  9.,  5., 17., 11. /
      data xpescalem1 / 10.,  5., 12.,  9., 13. /
      data xpdat2     / 530.0, 384.4, 232.1, 83.7, 7.4 /
      data xpstat2    / 3.5, 4.3, 4.7, 6.5, 12.7 /
      data xptotp2   / 12., 12., 11., 13., 19. /
      data xptotm2   / 14., 14., 12., 13., 18. /
      data xpescalep2 /  7.,  8.,  8., 10., 12. /
      data xpescalem2 /  9.,  9.,  8.,  9., 11. /
      real xp_zero(n_xpbins)
      data xp_zero / n_xpbins*0. /

c --  cos(theta*) cross sections (TABLE 7)
c     1: xgamma<0.8
c     2: xgamma>0.8
c     3: xgamma<0.8, mjj>65GeV
c     4: xgamma>0.8, mjj>65GeV
      integer n_ctbins
      parameter (n_ctbins=8)
      real ctbins(n_ctbins+1)
      real ctdat1(n_ctbins), ctdat2(n_ctbins)
      real ctstat1(n_ctbins), ctstat2(n_ctbins)
      real cterr1(n_ctbins), cterr2(n_ctbins)
      real cttotp1(n_ctbins), cttotp2(n_ctbins)
      real ctescalep1(n_ctbins), ctescalep2(n_ctbins)
      real cttotm1(n_ctbins), cttotm2(n_ctbins)
      real ctescalem1(n_ctbins), ctescalem2(n_ctbins)
      real ctdat3(n_ctbins), ctdat4(n_ctbins)
      real ctstat3(n_ctbins), ctstat4(n_ctbins)
      real cterr3(n_ctbins), cterr4(n_ctbins)
      real cttotp3(n_ctbins), cttotp4(n_ctbins)
      real ctescalep3(n_ctbins), ctescalep4(n_ctbins)
      real cttotm3(n_ctbins), cttotm4(n_ctbins)
      real ctescalem3(n_ctbins), ctescalem4(n_ctbins)
      data ctbins  / 0.0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.85 /
      data ctdat1  / 102.0, 98.3, 98.0, 89.0, 95.6, 86.6, 71.3, 33.8 /
      data ctstat1 / 6.1, 6.3, 6.4, 6.4, 6.5, 6.8, 7.5, 8.8 /
      data cttotp1   / 13., 11., 16., 15., 18., 15., 14., 14. /
      data cttotm1   / 13., 14., 15., 13., 14., 17., 14., 16. /
      data ctescalep1 / 10.,  6., 14., 11., 14.,  9., 10.,  9. /
      data ctescalem1 /  8., 10., 12.,  8.,  5., 11., 10., 11. /
      data ctdat2  / 100.1, 108.6, 115.6, 106.1, 95.7, 95.0, 86.3, 49.5/
      data ctstat2 / 5.6, 5.5, 5.4, 5.5, 5.7, 5.9, 6.3, 7.0 /
      data cttotp2   / 12., 11., 14., 10., 14., 12., 25., 14. /
      data cttotm2   / 13., 12., 13., 13., 14., 13., 23., 13. /
      data ctescalep2 /  7.,  8., 10.,  5.,  9.,  7., 12., 10. /
      data ctescalem2 /  8.,  9.,  7.,  8.,  7.,  8.,  7.,  7. /
      data ctdat3  / 10.1, 12.0, 12.6, 14.3, 21.0, 30.9, 37.9, 30.4 /
      data ctstat3 / 17.0, 16.4, 16.3, 15.9, 12.8, 11.3, 10.3, 9.4 /
      data cttotp3   / 21., 19., 19., 22., 16., 16., 18., 17. /
      data cttotm3   / 21., 21., 20., 21., 17., 14., 19., 14. /
      data ctescalep3 / 10.,  7.,  7., 13.,  8., 10., 13., 12. /
      data ctescalem3 / 10., 11.,  9., 11.,  9.,  5., 14.,  8. /
      data ctdat4  / 24.9, 25.6, 27.6, 30.5, 30.3, 43.4, 64.2, 47.0 /
      data ctstat4 / 11.7, 11.9, 11.3, 11.0, 10.9, 9.2, 7.7, 7.4 /
      data cttotp4   / 15., 15., 16., 15., 17., 15., 19., 14. /
      data cttotm4   / 16., 16., 16., 16., 16., 15., 19., 13. /
      data ctescalep4 /  7.,  7., 10.,  8., 10.,  9.,  6., 10. /
      data ctescalem4 /  8.,  8.,  8.,  9.,  7.,  9.,  7.,  7. /
      real ct_zero(n_ctbins)
      data ct_zero / n_ctbins*0. /

      real xp, xgam
      REAL costheta, deltaeta, mjj, etabar, etmean, etmax

      INTEGER chjet, iproc, iflag
      SAVE chjet
C     --- choose same jet finder as in the paper --- KTCLUS
      DATA chjet/3/
      INTEGER hzflag
      
      REAL lumnb

      LOGICAL parton_showers, lp, first
      INTEGER LENOCC      
      DATA lp / .false./

      CHARACTER*8 xxxx
      DATA xxxx /'d01225'/

****** set the jet cone radius.
****** CALL hzjetrad(1,coner) sets the radius to coner
****** CALL hzjetrad(2,coner) sets coner to the radius, or -1. 
******  check if the radius has been set eleswhere
      CALL hzjetrad(2,coner)
******  if not set it to the value used in the paper.
      IF (coner.LT.0.0) THEN
         coner=1.0
      ENDIF

****** Determine the process type (single/double resolved etc)
      iproc=(mod(iflag,10000)/1000)
      IF ((iproc.LT.0).OR.(iproc.GT.2)) THEN
         WRITE(HZUNIT,*) xxxx,': illegal IPROC:',iproc
         RETURN
      ENDIF

****** choose jet finder (only necessary if using jets!)
      IF ((MOD(iflag,100)/10.GT.0).AND.MOD(iflag,10).eq.1) THEN
         chjet=INT(MOD(iflag,100)/10)
      ENDIF

****** Decide if we are running on parton showers or final state particles.
      IF (MOD(iflag,100000)/10000.GT.0) THEN
****** use a different paw directory for parton showers.
         xxxx = 'PS'//xxxx
****** tell jet finder that we running on parton showers 
         chjet=-1*ABS(chjet)
      ENDIF
******************************************************************************
********************************  Initialise ********************************* 
      IF (MOD(iflag,10).EQ.1) THEN

C     *** Initialisation run ***
C     *** Create directories ***
         IF (iproc.le.1) THEN
            CALL HCDIR('//HISTO',' ')
            CALL HMDIR(xxxx,'S')
            CALL HCDIR('//PAWC',' ')
            CALL HMDIR(xxxx,'S')
            
c     Book the M_jj plot.
            CALL HBOOKB(-11,'Data: mjj'
     &           ,n_mjjbins,mjjbins,0.)
c     Book the ET(mean) plot.
            CALL HBOOKB(-12,'Data: ET(mean)'
     &           ,n_etmeanbins,etmeanbins,0.)
c     Book the ET(max) plot.
            CALL HBOOKB(-13,'Data: ET(max)'
     &           ,n_etmaxbins,etmaxbins,0.)
c     Book the etabar plot.
            CALL HBOOKB(-14,'Data: etabar, 0.1<y<0.5, 25<ET(max)<35 GeV'
     &           ,n_etabarbins,etabarbins,0.)
            CALL HBOOKB(-15,'Data: etabar, 0.1<y<0.5, 35<ET(max)<80 GeV'
     &           ,n_etabarbins,etabarbins,0.)
            CALL HBOOKB(-16,'Data: etabar, 0.5<y<0.9, 25<ET(max)<35 GeV'
     &           ,n_etabarbins,etabarbins,0.)
            CALL HBOOKB(-17,'Data: etabar, 0.5<y<0.9, 35<ET(max)<80 GeV'
     &           ,n_etabarbins,etabarbins,0.)
c     Book the xgamma and xp plot.
            CALL HBOOKB(-18,'Data: xgamma, xp<0.1'
     &           ,n_xgammabins,xgammabins,0.)
            CALL HBOOKB(-19,'Data: xgamma, xp>0.1'
     &           ,n_xgammabins,xgammabins,0.)
            CALL HBOOKB(-20,'Data: xp, xgamma<0.8'
     &           ,n_xpbins,xpbins,0.)
            CALL HBOOKB(-21,'Data: xp, xgamma>0.8'
     &           ,n_xpbins,xpbins,0.)
            CALL HBOOKB(-22,'Data: xgamma, 25<ET(max)<35 GeV'
     &           ,n_xgammabins,xgammabins,0.)
            CALL HBOOKB(-23,'Data: xgamma, 35<ET(max)<80 GeV'
     &           ,n_xgammabins,xgammabins,0.)
c     Book the costheta* plots.
            CALL HBOOKB(-24,'Data: cos(theta*), xgamma<0.8'
     &           ,n_ctbins,ctbins,0.)
            CALL HBOOKB(-25,'Data: cos(theta*), xgamma<0.8'
     &           ,n_ctbins,ctbins,0.)
            CALL HBOOKB(-26,'Data: cos(theta*), xgamma<0.8, M_jj>65 GeV'
     &           ,n_ctbins,ctbins,0.)
            CALL HBOOKB(-27,'Data: cos(theta*), xgamma<0.8, M_jj>65 GeV'
     &           ,n_ctbins,ctbins,0.)
c
c --  Convert errors from percentage into pb.
c --  Remove energy scale uncertainty from total systematic error for now and 
c --  assume it is a ~10% normalisation uncertainty.  (MW, 12/07/02)
c
            do i_bin = 1, n_mjjbins
               mjjerr(i_bin) = sqrt(
     +                            (0.25/10000.)*mjjdat(i_bin)**2
     +             *(sqrt(mjjtotp(i_bin)**2-mjjescalep(i_bin)**2)
     +             + sqrt(mjjtotm(i_bin)**2-mjjescalem(i_bin)**2))**2)
            end do
            do i_bin = 1, n_etmeanbins
               etmeanerr(i_bin) = sqrt(
     +                          (0.25/10000.)*etmeandat(i_bin)**2
     +        *(sqrt(etmeantotp(i_bin)**2-etmeanescalep(i_bin)**2)
     +        + sqrt(etmeantotm(i_bin)**2-etmeanescalem(i_bin)**2))**2)
            end do
            do i_bin = 1, n_etmaxbins
               etmaxerr(i_bin) = sqrt(
     +                         (0.25/10000.)*etmaxdat(i_bin)**2
     +        *(sqrt(etmaxtotp(i_bin)**2-etmaxescalep(i_bin)**2)
     +        + sqrt(etmaxtotm(i_bin)**2-etmaxescalem(i_bin)**2))**2)
            end do
            do i_bin = 1, n_etabarbins
               etabarerr1(i_bin) = sqrt(
     +                         (0.25/10000.)*etabardat1(i_bin)**2
     +      *(sqrt(etabartotp1(i_bin)**2-etabarescalep1(i_bin)**2)
     +      + sqrt(etabartotm1(i_bin)**2-etabarescalem1(i_bin)**2))**2)
               etabarerr2(i_bin) = sqrt(
     +                         (0.25/10000.)*etabardat2(i_bin)**2
     +      *(sqrt(etabartotp2(i_bin)**2-etabarescalep2(i_bin)**2)
     +      + sqrt(etabartotm2(i_bin)**2-etabarescalem2(i_bin)**2))**2)
               etabarerr3(i_bin) = sqrt(
     +                         (0.25/10000.)*etabardat3(i_bin)**2
     +      *(sqrt(etabartotp3(i_bin)**2-etabarescalep3(i_bin)**2)
     +      + sqrt(etabartotm3(i_bin)**2-etabarescalem3(i_bin)**2))**2)
               etabarerr4(i_bin) = sqrt(
     +                         (0.25/10000.)*etabardat4(i_bin)**2
     +      *(sqrt(etabartotp4(i_bin)**2-etabarescalep4(i_bin)**2)
     +      + sqrt(etabartotm4(i_bin)**2-etabarescalem4(i_bin)**2))**2)
            end do
            do i_bin = 1, n_xgammabins
               xgammaerr1(i_bin) = sqrt(
     +                         (0.25/10000.)*xgammadat1(i_bin)**2
     +      *(sqrt(xgammatotp1(i_bin)**2-xgammaescalep1(i_bin)**2)
     +      + sqrt(xgammatotm1(i_bin)**2-xgammaescalem1(i_bin)**2))**2)
               xgammaerr2(i_bin) = sqrt(
     +                         (0.25/10000.)*xgammadat2(i_bin)**2
     +      *(sqrt(xgammatotp2(i_bin)**2-xgammaescalep2(i_bin)**2)
     +      + sqrt(xgammatotm2(i_bin)**2-xgammaescalem2(i_bin)**2))**2)
               xgammaerr3(i_bin) = sqrt(
     +                         (0.25/10000.)*xgammadat3(i_bin)**2
     +      *(sqrt(xgammatotp3(i_bin)**2-xgammaescalep3(i_bin)**2)
     +      + sqrt(xgammatotm3(i_bin)**2-xgammaescalem3(i_bin)**2))**2)
               xgammaerr4(i_bin) = sqrt(
     +                         (0.25/10000.)*xgammadat4(i_bin)**2
     +      *(sqrt(xgammatotp4(i_bin)**2-xgammaescalep4(i_bin)**2)
     +      + sqrt(xgammatotm4(i_bin)**2-xgammaescalem4(i_bin)**2))**2)
            end do
            do i_bin = 1, n_xpbins
               xperr1(i_bin) = sqrt(
     +                     (0.25/10000.)*xpdat1(i_bin)**2
     +      *(sqrt(xptotp1(i_bin)**2-xpescalep1(i_bin)**2)
     +      + sqrt(xptotm1(i_bin)**2-xpescalem1(i_bin)**2))**2)
               xperr2(i_bin) = sqrt(
     +                     (0.25/10000.)*xpdat2(i_bin)**2
     +      *(sqrt(xptotp2(i_bin)**2-xpescalep2(i_bin)**2)
     +      + sqrt(xptotm2(i_bin)**2-xpescalem2(i_bin)**2))**2)
            end do
            do i_bin = 1, n_ctbins
               cterr1(i_bin) = sqrt(
     +                     (0.25/10000.)*ctdat1(i_bin)**2
     +      *(sqrt(cttotp1(i_bin)**2-ctescalep1(i_bin)**2)
     +      + sqrt(cttotm1(i_bin)**2-ctescalem1(i_bin)**2))**2)
               cterr2(i_bin) = sqrt(
     +                     (0.25/10000.)*ctdat2(i_bin)**2
     +      *(sqrt(cttotp2(i_bin)**2-ctescalep2(i_bin)**2)
     +      + sqrt(cttotm2(i_bin)**2-ctescalem2(i_bin)**2))**2)
               cterr3(i_bin) = sqrt(
     +                     (0.25/10000.)*ctdat3(i_bin)**2
     +      *(sqrt(cttotp3(i_bin)**2-ctescalep3(i_bin)**2)
     +      + sqrt(cttotm3(i_bin)**2-ctescalem3(i_bin)**2))**2)
               cterr4(i_bin) = sqrt(
     +                     (0.25/10000.)*ctdat4(i_bin)**2
     +      *(sqrt(cttotp4(i_bin)**2-ctescalep4(i_bin)**2)
     +      + sqrt(cttotm4(i_bin)**2-ctescalem4(i_bin)**2))**2)
            end do

            CALL HPAK( -11,mjjdat)
            CALL HPAKE(-11,mjjerr)
            CALL HPAK( -12,etmeandat)
            CALL HPAKE(-12,etmeanerr)
            CALL HPAK( -13,etmaxdat)
            CALL HPAKE(-13,etmaxerr)
            CALL HPAK( -14,etabardat1)
            CALL HPAKE(-14,etabarerr1)
            CALL HPAK( -15,etabardat2)
            CALL HPAKE(-15,etabarerr2)
            CALL HPAK( -16,etabardat3)
            CALL HPAKE(-16,etabarerr3)
            CALL HPAK( -17,etabardat4)
            CALL HPAKE(-17,etabarerr4)
            CALL HPAK( -18,xgammadat1)
            CALL HPAKE(-18,xgammaerr1)
            CALL HPAK( -19,xgammadat2)
            CALL HPAKE(-19,xgammaerr2)
            CALL HPAK( -20,xpdat1)
            CALL HPAKE(-20,xperr1)
            CALL HPAK( -21,xpdat2)
            CALL HPAKE(-21,xperr2)
            CALL HPAK( -22,xgammadat3)
            CALL HPAKE(-22,xgammaerr3)
            CALL HPAK( -23,xgammadat4)
            CALL HPAKE(-23,xgammaerr4)
            CALL HPAK( -24,ctdat1)
            CALL HPAKE(-24,cterr1)
            CALL HPAK( -25,ctdat2)
            CALL HPAKE(-25,cterr2)
            CALL HPAK( -26,ctdat3)
            CALL HPAKE(-26,cterr3)
            CALL HPAK( -27,ctdat4)
            CALL HPAKE(-27,cterr4)


         endif

         CALL HCDIR('//HISTO/'//xxxx,' ')
         CALL HCDIR('//PAWC/'//xxxx,' ')
         
c     Book the M_jj plot.
         CALL HBOOKB(iproc*100+11,'MC: mjj'
     &           ,n_mjjbins,mjjbins,0.)
c     Book the ET(mean) plot.
         CALL HBOOKB(iproc*100+12,'MC: ET(mean)'
     &           ,n_etmeanbins,etmeanbins,0.)
c     Book the ET(max) plot.
         CALL HBOOKB(iproc*100+13,'MC: ET(max)'
     &           ,n_etmaxbins,etmaxbins,0.)
c     Book the etabar plot.
         CALL HBOOKB(iproc*100+14,'MC:etabar,0.1<y<0.5,25<ET(max)<35GeV'
     &           ,n_etabarbins,etabarbins,0.)
         CALL HBOOKB(iproc*100+15,'MC:etabar,0.1<y<0.5,35<ET(max)<80GeV'
     &           ,n_etabarbins,etabarbins,0.)
         CALL HBOOKB(iproc*100+16,'MC:etabar,0.5<y<0.9,25<ET(max)<35GeV'
     &           ,n_etabarbins,etabarbins,0.)
         CALL HBOOKB(iproc*100+17,'MC:etabar,0.5<y<0.9,35<ET(max)<80GeV'
     &           ,n_etabarbins,etabarbins,0.)
c     Book the xgamma and xp plot.
         CALL HBOOKB(iproc*100+18,'MC: xgamma, xp<0.1'
     &           ,n_xgammabins,xgammabins,0.)
         CALL HBOOKB(iproc*100+19,'MC: xgamma, xp>0.1'
     &           ,n_xgammabins,xgammabins,0.)
         CALL HBOOKB(iproc*100+20,'MC: xp, xgamma<0.8'
     &           ,n_xpbins,xpbins,0.)
         CALL HBOOKB(iproc*100+21,'MC: xp, xgamma>0.8'
     &           ,n_xpbins,xpbins,0.)
         CALL HBOOKB(iproc*100+22,'MC: xgamma, 25<ET(max)<35 GeV'
     &           ,n_xgammabins,xgammabins,0.)
         CALL HBOOKB(iproc*100+23,'MC: xgamma, 35<ET(max)<80 GeV'
     &           ,n_xgammabins,xgammabins,0.)
c     Book the costheta* plots.
         CALL HBOOKB(iproc*100+24,'MC: cos(theta*), xgamma<0.8'
     &           ,n_ctbins,ctbins,0.)
         CALL HBOOKB(iproc*100+25,'MC: cos(theta*), xgamma<0.8'
     &           ,n_ctbins,ctbins,0.)
         CALL HBOOKB(iproc*100+26,'MC: cos(theta*),xg<0.8,M_jj>65 GeV'
     &           ,n_ctbins,ctbins,0.)
         CALL HBOOKB(iproc*100+27,'MC: cos(theta*),xg<0.8,M_jj>65 GeV'
     &           ,n_ctbins,ctbins,0.)

         CALL HIDOPT(0,'stat')
         CALL HBARX(0)
         
         CALL HZJTNAME(chjet,jetf)
         
         WRITE(6,*)'**********************************************'
         WRITE(6,*)'* HZ01225 called, histograms will be output. *'
         WRITE(6,*)'*     Jet finder selected : ',jetf,'           *'
         WRITE(6,1001)'*        with cone radius : ',CONER,'   *'
         WRITE(6,*)'**********************************************'

 1001    FORMAT(A29,F5.2,A13)

      ELSE IF (mod(iflag,10).eq.2) THEN
C     *** Filling runs ***
         
C     *** Change directory to our graphs ***
         CALL HCDIR('//PAWC/'//xxxx,' ')

         IF (gen(1:3).EQ.'HO1') THEN

            DO i_plot=11,27
               CALL HZSNLO(i_plot,i_plot+200,i_plot+100)
            ENDDO
            iproc = 1

         ENDIF

         q2=hzphokin(1)
         IF (q2.eq.-1) THEN
            PRINT*,'HZ01225: HZPHOKIN returns error for Q2'
         ELSEIF (q2.lt.0) THEN
            q2=abs(q2)
         ENDIF
         ybj=hzphokin(3)
         IF (ybj.eq.-1) THEN
            PRINT*,'HZ01225: HZPHOKIN returns error for ybj'
         ENDIF
         
C     *** Fill histograms ***
         
C     All events must pass the y cut and the Q2 cut.
         IF ((ybj.ge.ybjcut(1)).and.(ybj.le.ybjcut(3))
     &        .and.(q2.lt.q2cut(2))) Then
            
c     Get the initla state electron energy.
            hzflag=HZIBEAM(myip,myil)
            IF (hzflag.ge.0) Then
               elecE=abs(PHEP(4,myil))
            ELSE
               PRINT*,'HZ01225: Electron not found. E=0.001'
               PRINT*,'         event will be rejected'
               RETURN
            ENDIF
            
c     Find jets
            CALL HZJTFIND(chjet,CONER,NJET,Jets)
            
            IF (lp) THEN
               WRITE(*,*) 'Njet=',NJET
            ENDIF

            DO i_jet=1,2
               et(i_jet)=0.0
            ENDDO

c     If there aren't at least 2 jets, don't bother doing anything else.
            IF (njet.GE.2) THEN

               i_jet=0
               DO j_jet = 1,njet
c     Find the two highest ET jets in the rapidity interval.
c     Assumes jets are ordered in ET.
                  IF ( jets(j_jet,1).gt.rapcut(1).and.jets(j_jet,1).lt
     &                 .rapcut(2)) THEN
                     i_jet=i_jet+1
                     IF (i_jet.LE.2) THEN
                        Et(i_jet)=Jets(j_jet,3)
                        rap(i_jet)=Jets(j_jet,1)
                        phi(i_jet)=Jets(j_jet,2)
                     ENDIF

                  ENDIF
               ENDDO

c     All events must satisfy at least the lowest ET cut.
               IF (et(2).gt.etcut(1).AND.et(1).gt.etcut(2)) THEN
                  
c     Calculate quantities
                  xgam = (Et(1)*exp(-1.*rap(1))+Et(2)*exp(-1.*rap(2)))
     &                 / (2.0*ybj*elecE)
                  xp   = (Et(1)*exp(rap(1))+Et(2)*exp(rap(2)))
     &                 / (1640.)
                  deltaeta = abs(rap(1)-rap(2))
                  etabar   = (rap(1)+rap(2))/2.0
                  costheta = abs(tanh(deltaeta/2))
                  etmax    = real(et(1))
                  etmean   = (et(1)+et(2))/2.0
c     TODO: is phi wrapping dealt with ok here??
                  mjj = sqrt(2.0*et(1)*et(2)*(cosh(deltaeta)
     +              -cos(phi(1)-phi(2))))

c     Fill mjj, etmean, etmax
                  call hfill(iproc*100+11,mjj,0.,wtx)
                  call hfill(iproc*100+12,etmean,0.,wtx)
                  call hfill(iproc*100+13,etmax,0.,wtx)
c     Fill etabar
                  if (ybj.lt.ybjcut(2).and.et(1).lt.etcut(3)) then
                     call hfill(iproc*100+14,etabar,0.,wtx)
                  end if
                  if (ybj.lt.ybjcut(2).and.et(1).gt.etcut(3)
     .                                .and.et(1).lt.etcut(4)) then
                     call hfill(iproc*100+15,etabar,0.,wtx)
                  end if
                  if (ybj.gt.ybjcut(2).and.et(1).lt.etcut(3)) then
                     call hfill(iproc*100+16,etabar,0.,wtx)
                  end if
                  if (ybj.gt.ybjcut(2).and.et(1).gt.etcut(3)
     .                                .and.et(1).lt.etcut(4)) then
                     call hfill(iproc*100+17,etabar,0.,wtx)
                  end if
c     Fill xgamma with xp cuts
                  if (xp.lt.xpcut) then
                     call hfill(iproc*100+18,real(xgam),0.,wtx)
                  else
                     call hfill(iproc*100+19,real(xgam),0.,wtx)
                  end if
c     Fill xp with xgamma cuts
                  if (xgam.lt.xgamcut) then
                     call hfill(iproc*100+20,real(xp),0.,wtx)
                  else
                     call hfill(iproc*100+21,real(xp),0.,wtx)
                  end if
c     Fill xgamma with ET cuts
                  if (et(1).lt.etcut(3)) then
                     call hfill(iproc*100+22,real(xgam),0.,wtx)
                  end if
                  if (et(1).gt.etcut(3).and.et(1).lt.etcut(4)) then
                     call hfill(iproc*100+23,real(xgam),0.,wtx)
                  end if
c      Fill cos(theta*)
                  if (xgam.lt.xgamcut) then
                     call hfill(iproc*100+24,real(costheta),0.,wtx)
                     if (mjj.gt.mjjcut) then
                        call hfill(iproc*100+26,real(costheta),0.,wtx)
                     end if
                  else
                     call hfill(iproc*100+25,real(costheta),0.,wtx)
                     if (mjj.gt.mjjcut) then
                        call hfill(iproc*100+27,real(costheta),0.,wtx)
                     end if
                  end if
                  
                  IF (lp) THEN
                     WRITE(*,*) 'xgamma,wtx=',xgam,wtx
                  ENDIF
                  
               end if

            end if

         end if

      ELSE IF (mod(iflag,10).eq.3) THEN
C     *** Termination run ***
         if (iproc.eq.2.or.iproc.eq.0) then
            write(hzunit,*) 'HZ01225: Finishing off'
         endif

C     *** Change directory ***
         CALL HCDIR('//PAWC/'//xxxx,' ')
         
C     *** Finish off histograms ***
         
         IF (Xsec.eq.0) THEN
            PRINT*,'HZ01225: termination called with zero cross section'
            PRINT*,'          cross section graph meaningless'
            PRINT*,'          in process :',iproc*1000
            Xsec=1
         ENDIF
         IF (Ntot.eq.0) THEN
            PRINT*,'HZ01225: termination called with no total events'
            PRINT*,'          cross section graph meaningless'
            PRINT*,'          in process :',iproc*1000
            Ntot=1
         ENDIF
         
C     --- store Xsec and Ntot for both direct and resolved events.
         lumnb = ntot/(xsec*1000.)

         IF (gen(1:3).NE.'HO1') THEN
               
C     --- normalise resolved/direct component histograms
            DO i_plot=11,27
               CALL HZHINRM(100*iproc+i_plot,0,lumnb,1)
               IF (iproc.eq.2) THEN
C     --- now calculate cross-section graphs
                  CALL HOPERA(100+i_plot,'+e',200+i_plot,i_plot
     &                 ,1.,1.)
               ENDIF
            ENDDO

         ELSE IF (iproc.eq.2) THEN

c     For NLO stuff, only need to take the bin width and a factor of
c     1000 and 0.5 into account. However, we must also deal with the
c     final round of integration first.
            DO i_plot=11,27
               CALL HZSNLO(i_plot,i_plot+200,i_plot+100)
               CALL HOPERA(i_plot,'*e',50+i_plot,i_plot,1000.,1.)
            ENDDO
            
         ENDIF      
         
      ELSE
C     *** End ***
         PRINT*,'HZ01225:Please run routine with iflag set to 1,2 or 3'
         PRINT*,'        with +1000 or +2000 for DIR or RES events.'
      ENDIF

      RETURN
      END











