        Subroutine HZ95219(iflag)
*****************************************************************************
* This photoproduction routine has to be run twice with the following
* code additions:
* 	+1000 for the DIRECT component run.
*	+2000 for the RESOLVED component run.
* for all three phases (iflag=1,2,3)
*
*      +10000 to run on parton showers instead of final state particles.
*
* iflag = 1,2 or 3 depending on whether it is the initialization,
*               processing or termination phase (respectively)
*
* Output graphs:
*---------------
* DATA
* -1        d(sigma)/d(Et),  -1<eta<2 -stat.errors
* -2        d(sigma)/d(Et),  -1<eta<1
* -3        d(sigma)/d(eta), Et>7  GeV
* -4        d(sigma)/d(eta), Et>11 GeV
* -5        d(sigma)/d(eta), Et>15 GeV
* -6        <Et_outside the jets>/d(eta)/d(phi) vs x_gamma
*
* -11...-16: same as -1..-6 but with bin-by-bin systematic errors
* -21...-26: same as -1..-6 but with full systematic errors
*
* Monte-Carlo
*  1        d(sigma)/d(Et),  -1<eta<2
*  2        d(sigma)/d(Et),  -1<eta<1
*  3        d(sigma)/d(eta), Et>7  GeV
*  4        d(sigma)/d(eta), Et>11 GeV
*  5        d(sigma)/d(eta), Et>15 GeV
*  6        <Et_outside the jets>/d(eta)/d(phi) vs x_gamma
*               These graphs will be
*               meaningless unless Xsec and Ntot are set before
*               calling the termination routine.
*               (Xsec - total cross section returned by MC)
*               (Ntot - number of events passed to this routine)
*
*  101        d(sigma)/d(Et),  -1<eta<2
*  102        d(sigma)/d(Et),  -1<eta<1
*  103        d(sigma)/d(eta), Et>7  GeV        (DIRECT component)
*  104        d(sigma)/d(eta), Et>11 GeV
*  105        d(sigma)/d(eta), Et>15 GeV
*  106        sigma*(Et_outside the jets)/d(eta)/d(phi) vs xgamma
*  107        sigma vs xgamma
*
*  201        d(sigma)/d(Et),  -1<eta<2
*  202        d(sigma)/d(Et),  -1<eta<1
*  203        d(sigma)/d(eta), Et>7  GeV        (RESOLVED component)
*  204        d(sigma)/d(eta), Et>11 GeV
*  205        d(sigma)/d(eta), Et>15 GeV
*  206        sigma*(Et_outside the jets)/d(eta)/d(phi) vs xgamma
*  207        sigma vs xgamma
*
*                                               (DIRECT+RESOLVED)
*  306        sigma*(Et_outside the jets)/d(eta)/d(phi) vs xgamma
*  307        sigma vs xgamma
*
* Cuts :        Q2 < 0.01
*               0.25< y_bj <0.7
*               Depending on graph Et > 7, 11, 15
*                       and -1 < eta < 2, 1
*
* Recommended value for Ptmin is 2 GeV (to be set in MC set up)
*
* Author : Armen Bunyatyan (bunar@mail.desy.de)
*          modified into separate direct and resolved components by R.Taylor
*          modified Apr.2005 - add the transverse energy density outside
*                              of jets (Fig.4)
*                              IMPORTANT NOTE ! There is no table with  data
*                              points - here the values are extracted by eye
*               
*          Fixed to work with weighted event. J.Butterworth
*
* Reference : DESY-95-219
*             Z.Phys. C70(1996) 17 [Figure 7, Figure 4]
*             hep-ex/9511012
*
*****************************************************************************
*
* HERA Tuning defined commons

      IMPLICIT NONE

#include "hepevtp.inc"
#include "heracmn.inc"
#include "hzfunc.inc"
   
      INTEGER I
      Integer nbin1,nbin2,nbin3,nbin4,nbin5
      REAL xbins6(10)
      REAL xbins1(10)
      REAL pt1eta(9),pt1cr(9),pt1cre(9)
      REAL pt1cresys(9),hi1band(9)
      REAL pttemp1(9)
      REAL xbins2(8)
      REAL pt2eta(7),pt2cr(7),pt2cre(7)
      REAL pt2cresys(7),hi2band(7)
      REAL pttemp2(7)
      REAL xbins3(7)
      REAL pt3eta(6 ),pt3cr(6 ),pt3cre(6 )
      REAL pt3cresys(6 ),hi3band(6 )
      REAL pttemp3(6)
      REAL xbins4(6)
      REAL pt4eta(5),pt4cr(5),pt4cre(5)
      REAL pt4cresys(5),hi4band(5)
      REAL pttemp4(5)
      
      INTEGER iflag,iproc,intiflag,K
      DOUBLE PRECISION Q2,ybj
      
      REAL JET1(10,3)
      REAL ETALM,ETINI,RJET,ETBIN,ETMIN,ETMAX,ANORM(2)
      INTEGER NETA,NPHI,NJET1,NGOODJ,KL1,IER,J

* A.B. new stuff needed for Et outside the jets
      INTEGER ngoodj2
      real etj(4),etaj(4),etajcms(4),phij(4),xgamma
      integer itj
      real Eebeam,Epbeam,boost
      DATA Eebeam,Epbeam /26.7,820./
      real coef
      integer ITRK,ICOD,ISTA
      real PX,PY,PZ,E,ET,P,THETA,ETA,ETACMS,PHI
      real Etoutside
      real PI  
      DATA PI/3.141593/
      real deta1,deta2,dphi1,dphi2,dr1,dr2
      real area,etat,phit
      integer i1,i2,nevt

*     
      DATA nbin1,nbin2,nbin3,nbin4,nbin5 /9,7,6,5,4/
      
C     *** Data for Et.gt.7 & -1<eta<2
C     *** Data points for Et.gt.7 & -1<eta<2
      
      DATA xbins1/7.,9.,11.,13.,15.,17.,19.,21.,25.,29./
      DATA pt1eta/8.,10.,12.,14.,16.,18.,20.,23.,27./
      DATA pt1cr/20.8, 5.5, 1.74, 0.803, 0.283, 0.153, 0.0715,
     &     0.0223, 0.0172/
      DATA pt1cre/0.56, 0.26, 0.12, 0.079, 0.044, 0.036,
     &     0.021, 0.0081, 0.0063/
      DATA pt1cresys/4.4, 1.2, 0.37, 0.17, 0.059, 0.032,
     &     0.015, 0.0047, 0.0036/
      DATA hi1band/5.4, 1.4, 0.45, 0.21, 0.074, 0.040,
     &     0.019, 0.0058, 0.0045/
      
C     *** Data for Et.gt.7 & -1<eta<1
C     *** Data points for Et.gt.7   & -1<eta<1
      DATA xbins2/7., 9., 11., 13., 15., 17., 19., 21./
      DATA pt2eta/8., 10., 12., 14., 16., 18., 20./
      DATA pt2cr/10.3, 2.76, 0.787, 0.322, 0.141, 0.0672, 0.0263/
      DATA pt2cre/0.39, 0.19, 0.078, 0.049, 0.030, 0.021, 0.012/
      DATA pt2cresys/2.2, 0.58, 0.17, 0.067, 0.030, 0.014, 0.0055/
      DATA hi2band/2.7, 0.72, 0.20, 0.084, 0.037, 0.017, 0.0068/
      
      
C     *** Data for Et.gt.7 GeV
C     *** Data points for Et.gt.7 GeV
      DATA xbins3/-1.0, -0.5, 0., 0.5,  1.0, 1.5, 2.0/
      DATA pt3eta /-0.75, -0.25, 0.25, 0.75,  1.25, 1.75/
      DATA pt3cr  /  5.9,  13.2, 17.8, 21.6,  24.8, 30.1/
      DATA pt3cre / 0.64,  0.86,  1.1,  1.1,   1.2,  1.3/
      DATA pt3cresys/ 1.3, 2.8, 3.7, 4.5, 5.2, 6.3/
      DATA hi3band/1.5, 3.4, 4.6, 5.6, 6.5, 7.8/
C     *** Data for Et.gt.11 GeV
C     *** Data points for Et.gt.11 GeV
      DATA xbins4 / -0.5, 0., 0.5,  1.0, 1.5, 2.0/
      DATA pt4eta / -0.25, 0.25, 0.75,  1.25, 1.75/
      DATA pt4cr  / 1.23, 1.85, 2.36,  3.30, 3.27/
      dATA pt4cre /  0.20, 0.24, 0.30, 0.35, 0.33 /
      DATA pt4cresys/ 0.26, 0.39, 0.50, 0.69, 0.69/
      DATA hi4band/0.32, 0.48, 0.61, 0.86, 0.85/
C     *** Data for Et.gt.15 GeV
      REAL xbins5(5)
      REAL pt5eta(4),pt5cr(4),pt5cre(4)
      REAL pt5cresys(4),hi5band(4)
      REAL pttemp5(4)
      
C     *** Data points for Et.gt.15 GeV
      DATA xbins5 /  0., 0.5,  1.0, 1.5, 2.0/
      DATA pt5eta /  0.25, 0.75,  1.25, 1.75/
      DATA pt5cr  /  0.50, 0.48, 0.67, 0.65 /
      DATA pt5cre /   0.12, 0.12, 0.15, 0.14 /
      DATA pt5cresys/  0.11, 0.10, 0.14, 0.14/
*     DATA hi5band/4*0.0 /
*** missing the band.
C* Okt 2000 from S. Ferron >
      DATA hi5band/0.13, 0.13, 0.17, 0.17/
C<
C *** Data for Transverse energy density outside the jets
      REAL xbinse(6)
      REAL efl(5),eflcr(5),eflcre(5)
      REAL eflcresys(5),efltemp(5)
*
C *** Data points
      DATA xbinse  /  0., 0.1, 0.2, 0.4, 0.7, 1.0 /
      DATA eflcr    /  1.06, 1.04, 0.805, 0.5, 0.435/
      DATA eflcre  /  0.03, 0.025, 0.035, 0.031, 0.031 /
      DATA eflcresys /  0.177, 0.175, 0.136, 0.091, 0.080 /
        
*     
      LOGICAL parton_showers
      
      parton_showers=.FALSE.
      intiflag=iflag
      IF (intiflag.gt.10000) THEN
         parton_showers=.TRUE.
         intiflag=MOD(intiflag,10000)
      ENDIF
      
C     --- choose direct/resolved
C     --- recommend 1 - DIRECT, 2 - RESOLVED
      IF (intiflag.gt.1000) THEN
         iproc=INT(intiflag/1000)
         intiflag=MOD(intiflag,1000)
      ENDIF
      IF ((iproc.gt.2).or.(iproc.lt.1)) THEN
         PRINT*,'HZ95219 : Badly called routine'
         PRINT*,'          please set intiflag +1000 or +2000'
      ENDIF
      
      IF (intiflag.eq.1) THEN
C     *** Initialisation run ***
      write(6,*) ' hz95219, hannes mod version '
      
         
         PRINT*,"**********************************************"
         PRINT*,"* HZ95219 called, histograms will be output. *"
         PRINT*,"**********************************************"
         
         IF (iproc.eq.1) THEN
            IF (parton_showers) THEN
               CALL HCDIR('//PAWC',' ')
               CALL HMDIR('psd95219','S')
               CALL HCDIR('//HISTO',' ')
               CALL HMDIR('psd95219','S')
            ELSE
               CALL HCDIR('//PAWC',' ')
               CALL HMDIR('d95219','S')
               CALL HCDIR('//HISTO',' ')
               CALL HMDIR('d95219','S')
            ENDIF
         
            CALL HBOOKB(50,'Temp',9,xbins1,0.)
            
*     -1<eta<2
            CALL HBOOKB(-1
     &      ,'Data-d(sigma)/d(Et) (nb) -1.lt.eta.lt.2-stat.errors'
     &           ,9,xbins1 ,0.)
            CALL HPAK(-1,PT1CR)
            CALL HPAKE(-1,PT1CRE)
            
            
            CALL HBOOKB(-11,
     &      'Data-d(sigma)/d(Et) (nb) -1.lt.eta.lt.2-stat.+syst.errors'
     &           ,9,xbins1 ,0.)
            do i=1,nbin1
               pttemp1(i)=sqrt(PT1CRE(i)**2+pt1cresys(i)**2)
            enddo
            CALL HPAK(-11,PT1CR)
            CALL HPAKE(-11,PTTemp1)
            
            
            CALL HBOOKB(-21,
     &      'Data-d(sigma)/d(Et) (nb) -1.lt.eta.lt.2-full errors'
     &           ,9,xbins1 ,0.)
            do i=1,nbin1
               pttemp1(i)=sqrt(PT1CRE(i)**2+pt1cresys(i)**2
     &              +hi1band(i)**2)
            enddo
            CALL HPAK(-21,PT1CR)
            CALL HPAKE(-21,PTTEMP1)
            
            
*     -1<eta<1
            
C     --- Original routine contained a scaling of 0.1 on this data (in
c     order
C     --- to match with the published graph). I've (RT) deleted this 20
c     /8/98.
C     --- [Also changed weighting in MC histograms from 0.05 to 0.5].
            CALL HBOOKB(-2,
     &           'Data-d(sigma)/d(Et) (nb) -1.lt.eta.lt.1-stat.errors'
     &           ,7,xbins2 ,0)
            CALL HPAK(-2,PT2CR)
            CALL HPAKE(-2,PT2CRE)
            
            CALL HBOOKB(-12,
     &      'Data-d(sigma)/d(Et) (nb) -1.lt.eta.lt.1-stat.+syst.errors'
     &           ,7,xbins2 ,0.)
            CALL HPAK(-12,PT2CR)
            do i=1,nbin2
               pttemp2(i)=sqrt(PT2CRE(i)**2+pt2cresys(i)**2)
            enddo
            CALL HPAKE(-12,PTTEMP2)
            
            CALL HBOOKB(-22,
     &      'Data-d(sigma)/d(Et) (nb) -1.lt.eta.lt.1-full errors'
     &           ,7,xbins2 ,0.)
            CALL HPAK(-22,PT2CR)
            do i=1,nbin2
               pttemp2(i)=sqrt(PT2CRE(i)**2+pt2cresys(i)**2
     &              +hi2band(i)**2)
            enddo
            CALL HPAKE(-22,PTTEMP2)
            
*     ET>7
            CALL HBOOKB(-3,
     &      'Data-d(sigma)/d(eta) (nb) Et.gt.7 GeV-stat.errors'
     &           ,6,xbins3 ,0.)
            CALL HPAK(-3,PT3CR)
            CALL HPAKE(-3,PT3CRE)
            
            CALL HBOOKB(-13,
     &      'Data-d(sigma)/d(eta) (nb) Et.gt.7 GeV-stat+syst.errors'
     &           ,6,xbins3 ,0.)
            CALL HPAK(-13,PT3CR)
            do i=1,nbin3
               pttemp3(i)=sqrt(PT3CRE(i)**2+pt3cresys(i)**2)
            enddo
            CALL HPAKE(-13,PTTEMP3)
            
            CALL HBOOKB(-23,
     &      'Data-d(sigma)/d(eta) (nb) Et.gt.7 GeV-full errors'
     &           ,6,xbins3 ,0.)
            CALL HPAK(-23,PT3CR)
            do i=1,nbin3
               pttemp3(i)=sqrt(PT3CRE(i)**2+pt3cresys(i)**2
     &              +hi3band(i)**2)
            enddo
            CALL HPAKE(-23,PTTEMP3)
            
*     ET>11
            CALL HBOOKB(-4,
     &      'Data-d(sigma)/d(eta) (nb) Et.gt.11 GeV-stat.errors'
     &           ,5,xbins4 ,0.)
            CALL HPAK(-4,PT4CR)
            CALL HPAKE(-4,PT4CRE)
            
            CALL HBOOKB(-14,
     &      'Data-d(sigma)/d(eta) (nb) Et.gt.11 GeV-stat+syst.errors'
     &           ,5,xbins4 ,0.)
            
            CALL HPAK(-14,PT4CR)
            do i=1,nbin4
               pttemp4(i)=sqrt(PT4CRE(i)**2+pt4cresys(i)**2)
            enddo
            CALL HPAKE(-14,PTTEMP4)
            
            CALL HBOOKB(-24,
     &      'Data-d(sigma)/d(eta) (nb) Et.gt.11 GeV-full errors'
     &           ,5,xbins4 ,0.)
            CALL HPAK(-24,PT4CR)
            do i=1,nbin4
               pttemp4(i)=sqrt(PT4CRE(i)**2+pt4cresys(i)**2
     &              +hi4band(i)**2)
            enddo
            CALL HPAKE(-24,PTTEMP4)
            
*     ET>15
            CALL HBOOKB(-5,
     &      'Data-d(sigma)/d(eta) (nb) Et.gt.15 GeV-stat.errors'
     &           ,4,xbins5 ,0.)
            CALL HPAK(-5,PT5CR)
            CALL HPAKE(-5,PT5CRE)
            
            CALL HBOOKB(-15,
     &      'Data-d(sigma)/d(eta) (nb) Et.gt.15 GeV-stat+syst.errors'
     &           ,4,xbins5 ,0.)
            CALL HPAK(-15,PT5CR)
            do i=1,nbin5
               pttemp5(i)=sqrt(PT5CRE(i)**2+pt5cresys(i)**2)
            enddo
            CALL HPAKE(-15,PTTEMP5)
            
            CALL HBOOKB(-25,
     &      'Data-d(sigma)/d(eta) (nb) Et.gt.15 GeV-full errors'
     &           ,4,xbins5 ,0.)
            CALL HPAK(-25,PT5CR)
            do i=1,nbin5
               pttemp5(i)=sqrt(PT5CRE(i)**2+pt5cresys(i)**2
     &              +hi5band(i)**2)
            enddo
            CALL HPAKE(-25,PTTEMP5)

*    ET outside the jets
           CALL HBOOKB(-6,
     &    'Data-<Et>/d(eta)d(phi) vs xgamma'   ,5,xbinse ,0.)
           CALL HPAK(-6,EFLCR)
           CALL HPAKE(-6,eflcre)
 
           CALL HBOOKB(-16,
     &    'Data-Et/d(eta)d(phi)vs xgamma'  ,5,xbinse ,0.)
           CALL HPAK(-16,EFLCR)
           do i=1,5
             efltemp(i)=sqrt(eflCRE(i)**2+eflcresys(i)**2)
           enddo
           CALL HPAKE(-16,efltEMP)
            

*     Monte-Carlo
            
            CALL HBOOKB(1,'Monte-Carlo d(sigma)/dEt (nb) -1.lt.eta.lt.2'
     &           ,9,xbins1 ,0.)
            CALL HBOOKB(2
     &           ,'Monte-Carlo d(sigma)/dEt  (nb) -1.lt.eta.lt.1',7
     &           ,xbins2 ,0.)
            CALL HBOOKB(3,'Monte-Carlo d(sigma)/d(eta) (nb) Et.gt.7 GeV'
     &           ,6,xbins3 ,0.)
            CALL HBOOKB(4
     &           ,'Monte-Carlo d(sigma)/d(eta) (nb) Et.gt.11 GeV',5
     &           ,xbins4 ,0.)
            CALL HBOOKB(5
     &           ,'Monte-Carlo d(sigma)/d(eta) (nb) Et.gt.15 GeV',4
     &           ,xbins5 ,0.)
            CALL HBOOKB(6,'Monte-Carlo d(Etoutside)/d(xg) (GeV)'
     &          ,5,xbinse ,0.)
         ENDIF

         IF (iproc.eq.2) THEN
            IF (parton_showers) THEN
               CALL HCDIR('//HISTO/psd95219',' ')
               CALL HCDIR('//PAWC',' ')
               CALL HMDIR('psd95219','S')
               CALL HCDIR('//PAWC/psd95219',' ')
            ELSE
               CALL HCDIR('//HISTO/d95219',' ')
               CALL HCDIR('//PAWC',' ')
               CALL HMDIR('d95219','S')
               CALL HCDIR('//PAWC/d95219',' ')
            ENDIF
         ENDIF
         
         
         CALL HBOOKB(100*iproc+1,'MC d(sigma)/d(Et) -1.lt.eta.lt.2'
     &        ,9,xbins1 ,0.)
         CALL HBOOKB(100*iproc+2,'MC d(sigma)/d(Et) -1.lt.eta.lt.1'
     &        ,7,xbins2 ,0.)
         CALL HBOOKB(100*iproc+3,'MC d(sigma)/d(eta) Et.gt.7 GeV'
     &        ,6,xbins3 ,0.)
         CALL HBOOKB(100*iproc+4,'MC d(sigma)/d(eta) Et.gt.11 GeV'
     &        ,5,xbins4 ,0.)
         CALL HBOOKB(100*iproc+5,'MC d(sigma)/d(eta) Et.gt.15 GeV'
     &        ,4,xbins5 ,0.)
         CALL HBOOKB(100*iproc+6,'Monte-Carlo d(Etoutise)/d(xg) (GeV)'
     &        ,5,xbinse ,0.)
         CALL HBOOKB(100*iproc+7,'Monte-Carlo d(Etoutise)/d(xg) (GeV)'
     &        ,5,xbinse ,0.)

         
         ETALM = 3.0
         NETA = 30
         NPHI = 24
         ETINI = 0.1
         RJET = 1.00001
         ETBIN = 2.
         ETMIN = 7.0
         ETMAX=49.
         
         CALL HIDOPT(0,'stat')
         CALL HBARX(0)

*********************************************************         
      ELSE IF (intiflag.eq.2) THEN
C     *** Filling runs ***
         
         CALL VZERO(jet1,30)
         njet1=0
         ngoodj=0
         ngoodj2=0
* Energy outside of jets
         call vzero(etj,4)
         call vzero(etaj,4)
         call vzero(etajcms,4)
         call vzero(phij,4)   
         itj=0
         xgamma=0.
         EToutside=0.
         COEF=1.

         IF (parton_showers) THEN
            CALL H1GPCONE(ETALM,NETA,NPHI,ETINI,ETMIN,ETBIN,ETMAX,
     +           -1.0*RJET, NJET1,JET1)
         ELSE
            CALL H1GPCONE(ETALM,NETA,NPHI,ETINI,ETMIN,ETBIN,ETMAX,
     +           RJET, NJET1,JET1)
         ENDIF
         
C     --- Original version did not include internal cuts on Q2 and y_bj
C     --- Added below by Russell Taylor (21/8/98)
         Q2=HZPHOKIN(1)
         Q2=ABS(Q2)
         ybj=HZPHOKIN(3)
         
         ngoodj=0
         IF ((ybj.GE.0.25).AND.(ybj.LE.0.7).AND.(Q2.LT.0.01)) THEN
            DO 654 KL1=1,NJET1
C     PRINT '(2X,'' JETS 1=ET/ETA,PHI='',3F7.3)',
C     +         (JET1(KL1,J),J=1,3)
               IF(JET1(KL1,2).GT.2.5.OR.JET1(KL1,2).LE.-1.0 ) GOTO 654
               IF(jet1(kl1,1).LT.ETMIN) GOTO 654
               ngoodj2=ngoodj2+1
               if(ngoodj2.le.4) etj (ngoodj2)=jet1(kl1,1)
               if(ngoodj2.le.4) etaj(ngoodj2)=jet1(kl1,2)
               if(ngoodj2.le.4) phij(ngoodj2)=jet1(kl1,3)
               if(JET1(KL1,2).LE.2..AND.JET1(KL1,2).GE.-1.0 ) THEN
                  ngoodj=ngoodj+1
                  IF (parton_showers) THEN
                     CALL HCDIR('//PAWC/psd95219',' ')
                  ELSE
                     CALL HCDIR('//PAWC/d95219',' ')
                  ENDIF               
                  if(wtx.eq.0.) wtx=1.
                  CALL HFILL(100*iproc+1,JET1(KL1,1),0.,wtx)
                  IF(JET1(KL1,2).LE.1.)
     +                 CALL HFILL(100*iproc+2,JET1(KL1,1),0,wtx)
                  IF(JET1(KL1,1).GE.7.) CALL HFILL(100*iproc+3,JET1(KL1
     &                 ,2),0.,wtx)
                  IF(JET1(KL1,1).GE.11.) CALL HFILL(100*iproc+4,JET1(KL1
     &                 ,2),0.,wtx)
                  IF(JET1(KL1,1).GE.15.) CALL HFILL(100*iproc+5,JET1(KL1
     &                 ,2),0.,wtx)
               ENDIF
 654        CONTINUE

* rapidity -1<eta*<1 in gamma-p corresponds to
* eta*=eta-0.5 ln(Ep/Eg)
           boost=-0.5*log(Epbeam/Eebeam/ybj)
           if(ngoodj2.ge.2.and.abs(etaj(1)-etaj(2)).lt.1.2) then
               xgamma=etj(1)*exp(-etaj(1))+etj(2)*exp(-etaj(2))
               xgamma=xgamma/2./Eebeam/ybj
           endif
* find energy outside of jets
        
           if(xgamma.gt.0.) then
             etajcms(1)=etaj(1)+boost
             etajcms(2)=etaj(2)+boost
* 
* Is Z axis in the proton direction?
             DO ITRK=1,NHEP
               if(IDHEP(itrk).eq.2212) then
                  IF(PHEP(3,itrk).lt.0.) COEF=-1.
                  go to 20
               endif
             ENDDO 
20           continue
             DO 100 ITRK = 1, NHEP
               PX   = PHEP(1,itrk)
               PY   = PHEP(2,itrk)
               PZ   = PHEP(3,itrk)*COEF
               E    = PHEP(4,itrk)
               ICOD = IDHEP(itrk)
               ISTA = ISTHEP(itrk)
C              neutrino
               IF(ICOD.EQ.12 .OR. ICOD.EQ.14 .OR. ICOD.EQ.16) 
     *         GO TO 100
               IF(ISTA.NE.1) GO TO 100
               P  = SQRT(PX**2 + PY**2 + PZ**2)
               IF(ABS(P).LE.1.E-8 ) GO TO 100
               THETA = ACOS (PZ/P )
               IF(THETA.LT.1.E-8) GO TO 100
               IF(ABS(THETA-PI).LT.1.E-6) GO TO 100
               ETA = -ALOG(TAN(THETA/2.))
               ETACMS=ETA+boost
c -1<eta*<1
               if(abs(etacms).gt.1.) go to 100
               PHI   = ATAN2(PY,PX)
               IF(PHI.LT.0.) PHI = 2 * PI + PHI
               ET = E*SIN(THETA) 
               deta1=abs(ETA-etaj(1))
               deta2=abs(ETA-etaj(2))
               dphi1=abs(PHI-phij(1))
               dphi2=abs(PHI-phij(2))
               if(dphi1.gt.2.*PI) dphi1=-2.*PI+dphi1
               if(dphi2.gt.2.*PI) dphi2=-2.*PI+dphi2
               if(dphi1.gt.PI) dphi1=2.*PI-dphi1
               if(dphi2.gt.PI) dphi2=2.*PI-dphi2
               dr1=sqrt(deta1**2+dphi1**2)
               dr2=sqrt(deta2**2+dphi2**2)
               if(dr1.gt.1.3.and.dr2.gt.1.3) then
c calculate total et
                  EToutside=Etoutside+Et
               endif
100          CONTINUE

* calculate the area outside the jets, use grid 50*50 (not very precise)
             NEVT=0
             do i1=1,50
             do i2=1,50
               etat=float(i1) / 50.*2. -1.
               phit=float(i2) / 50.* 2.*PI               
               deta1=abs(etat-etajcms(1))
               deta2=abs(etat-etajcms(2))
               dphi1=abs(phit-phij(1))
               dphi2=abs(phit-phij(2))
               if(dphi1.gt.2.*PI) dphi1=-2.*PI+dphi1
               if(dphi2.gt.2.*PI) dphi2=-2.*PI+dphi2
               if(dphi1.gt.PI) dphi1=2.*PI-dphi1
               if(dphi2.gt.PI) dphi2=2.*PI-dphi2
               dr1=sqrt(deta1**2+dphi1**2)
               dr2=sqrt(deta2**2+dphi2**2)
               if(dr1.gt.1.3.and.dr2.gt.1.3) then
                 NEVT=NEVT+1
               endif
             enddo
             enddo
             area=2.*2.*PI * NEVT/2500. 
             EToutside=EToutside/area
             CALL HFILL(100*iproc+6,xgamma,0.,EToutside*wtx)
             CALL HFILL(100*iproc+7,xgamma,0.,wtx)
             
           endif  ! xgamma

         ENDIF                  !Q2 and y_bj cuts         
*************************************************************
      ELSE IF (intiflag.eq.3) THEN
         
C     --- The following lines allow for variable bin widths on MC
c     histograms
C     --- 1, 101 and 201. Added by Russell Taylor (21/8/98)
         IF (iproc.eq.1) THEN
            IF (parton_showers) THEN              
               CALL HCDIR('//PAWC/psd95219',' ')
            ELSE
               CALL HCDIR('//PAWC/d95219',' ')
            ENDIF
            DO K=1,9
               xbins6(K)=1./(xbins1(K+1)-xbins1(K))
            ENDDO
            CALL HPAK(50,xbins6)
         ENDIF 
         
         IF (Xsec.eq.0) THEN
	    PRINT*,'HZ95219: termination called with zero cross section'
	    PRINT*,'          cross section graph meaningless'
	    PRINT*,'	      in process :',iproc*1000
	    Xsec=1
         ENDIF
         IF (Ntot.eq.0) THEN
	    PRINT*,'HZ95219: termination called with no total events'
	    PRINT*,'          cross section graph meaningless'
	    PRINT*,'	      in process :',iproc*1000
	    Ntot=1
         ENDIF
         ANORM(iproc)=0.
chju         if(Ntot.gt.0) ANORM(iproc)=Xsec/Ntot
         if(Ntot.gt.0) ANORM(iproc)=Xsec/1000./Ntot
        WRITE(6,*)  'Hz95219: Ntot,Xsec,GEN= ',Ntot,Xsec/1000.
     &  ,' nb  ',GEN
        WRITE(6,*)  'Hz95219: normalization factor=',ANORM(iproc)
         
         IF (parton_showers) THEN              
            CALL HCDIR('//PAWC/psd95219',' ')
         ELSE
            CALL HCDIR('//PAWC/d95219',' ')
         ENDIF

         IF (iproc.eq.1) THEN
            call hzhinrm(101, 0, 1/ANORM(1), 1)           
            call hzhinrm(102, 0, 1/ANORM(1), 1)           
            call hzhinrm(103, 0, 1/ANORM(1), 1)           
            call hzhinrm(104, 0, 1/ANORM(1), 1)           
            call hzhinrm(105, 0, 1/ANORM(1), 1)           
c            call hzhinrm(106, 0, 1/ANORM(1), 1)           
c            call hzhinrm(107, 0, 1/ANORM(1), 1)           
c            CALL HOPERA(101,'+e',101,101,ANORM(1),0.)
c            CALL HOPERA(102,'+e',102,102,ANORM(1),0.)
c            CALL HOPERA(103,'+e',103,103,ANORM(1),0.)
c            CALL HOPERA(104,'+e',104,104,ANORM(1),0.)
c            CALL HOPERA(105,'+e',105,105,ANORM(1),0.)
            CALL HOPERA(101,'+e',101,1,1.,0.)
            CALL HOPERA(102,'+e',102,2,1.,0.)
            CALL HOPERA(103,'+e',103,3,1.,0.)
            CALL HOPERA(104,'+e',104,4,1.,0.)
            CALL HOPERA(105,'+e',105,5,1.,0.)
            CALL HOPERA(106,'+e',106,306,1.,0.)
            CALL HOPERA(107,'+e',107,307,1.,0.)
            CALL HOPERA(306,'/e',307,6,1.,1.)
         ELSEIF (iproc.eq.2) THEN
            call hrin(50,99999,0)
            call hrin(101,99999,0)
            call hrin(102,99999,0)
            call hrin(103,99999,0)
            call hrin(104,99999,0)
            call hrin(105,99999,0)
            call hrin(106,99999,0)
            call hrin(107,99999,0)
            call hzhinrm(201, 0, 1/ANORM(2), 1)           
            call hzhinrm(202, 0, 1/ANORM(2), 1)           
            call hzhinrm(203, 0, 1/ANORM(2), 1)           
            call hzhinrm(204, 0, 1/ANORM(2), 1)           
            call hzhinrm(205, 0, 1/ANORM(2), 1)           
            call hzhinrm(206, 0, 1/ANORM(2), 1)           
            call hzhinrm(207, 0, 1/ANORM(2), 1)           
            CALL HOPERA(101,'+e',201,1,1.,1.)
            CALL HOPERA(102,'+e',202,2,1.,1.)
            CALL HOPERA(103,'+e',203,3,1.,1.)
            CALL HOPERA(104,'+e',204,4,1.,1.)
            CALL HOPERA(105,'+e',205,5,1.,1.)
            CALL HOPERA(106,'+e',206,306,1.,1.)
            CALL HOPERA(107,'+e',207,307,1.,1.)
            CALL HOPERA(306,'/e',307,6,1.,1.)
         ENDIF
         
      ELSE
         WRITE(6,*) 'Hz95219: Unknown flag',iflag
      ENDIF
      RETURN
      END
