      Subroutine HZ96094(iflag)
*****************************************************************************
* This photoproduction routine has to be run twice with the following
* code additions:
*       +1000 for the DIRECT component run.
*       +2000 for the RESOLVED component run.
*       +0 for both together
* for all three phases (iflag=1,2,3)
*
* iflag = 1,2 or 3 depending on wether it is the initialization,
*               processing or termination phase (respectively)
*
*      +10000 to run on parton showers instead of final state particles.
*
* The default jetfinder is EUCELL
* To change jetfinder use these values to call the initialisation phase.
* 1 + 10 * (jetfinder number)
*
* This routine produces two Monte Carlo graphs.
*               10 d\sigma/d|cos(theta*)| DIRECT
*               20 d\sigma/d|cos(theta*)| RESOLVED
*
*               -10 and -20 are the equivalent data graphs (stat. errors)
*               -11 and -21 include full stat+sys errors
*
* Cuts :        Q2 < 4 GeV^2
*               0.25 < y_jb < 0.8
*               Et > 6 GeV
*               M_jj > 23 GeV
*               |eta_bar| < 0.5
*
* Recommended value for Ptmin is 2.5 GeV (to be set in MC set up)
*
* Author : Mark Hayes (mhayes@zow.desy.de)
*
* Reference : DESY-96-094
*             Phys. Lett. B384 (1996) 401-413.
*
*
*****************************************************************************
*
* HERA Tuning defined commons

      IMPLICIT NONE

#include "hepevtp.inc"
#include "heracmn.inc"
#include "hzfunc.inc"
#include "hzjetcmn.inc"

c     *** Data for DIRECT
      REAL cs(10),sta(10),syshi(10),syslo(10)
      DATA cs/0.80,0.83,0.98,0.90,1.26,1.50,1.41,2.70,3.81,5.99/
      DATA sta/0.12,.13,.15,.14,.19,.18,.17,.28,.33,.48/
      DATA syshi/.06,.07,.02,.02,.15,.08,.18,.36,.14,.81/
      DATA syslo/.09,.13,.13,.08,.16,.19,.08,.35,.29,.40/
c     *** Data for RESOLVED
      REAL cs2(10),sta2(10),syshi2(10),syslo2(10)
      DATA cs2/0.21,0.23,0.23,0.28,0.27,0.42,0.77,1.13,2.03,4.31/
      DATA sta2/.08,.12,.10,.09,.10,.11,.17,.21,.25,.43/
      DATA syshi2/.06,.09,.04,.13,.10,.11,.08,.16,.36,.47/
      DATA syslo2/.08,.12,.07,.02,.06,.04,.08,.26,.19,.39/
      
C     --- cuts arrays
      DOUBLE PRECISION ybjcut(2),q2cut(2)
      DOUBLE PRECISION rapcut(2),Etcut(4)
C     --- photoproduction cuts
      DATA ybjcut/0.25,0.8/
      DATA q2cut/0.0,4/
      DATA Etcut/6.0,6.0,6.0,6.0/
      DATA rapcut/-3.8,4.1/
      Integer chjet, i
      SAVE chjet
C     --- choose same jet finder as in the paper --- EUCELL
      DATA chjet/1/
      CHARACTER*6 jetf
      
C     --- information returned by jet finder
      INTEGER NJET
c      DOUBLE PRECISION Jets(50,8)
      DOUBLE PRECISION CONER
      SAVE CONER
      
c     ---
      DOUBLE PRECISION elecE
      INTEGER myil,myip,loop
      DOUBLE PRECISION deltaeta,etabar,xgam,costh,mjj
      DOUBLE PRECISION rap(2),Et(2),phi(2)
      DOUBLE PRECISION ybj,q2
      
      INTEGER iproc, iflag
      INTEGER hzflag
      
      REAL pttemp(12), lumnb
      INTEGER ivec,jvec
*     REAL sqrt
      
      LOGICAL parton_showers

      Character*8 xxxx
      DATA xxxx /'d96094'/
      
*     Determine the process type.
      iproc=(mod(iflag,10000)/1000)
      if ((iproc.lt.0).or.(iproc.gt.2)) then
         write(HZUNIT,*) 'HZ',xxxx,': illegal IPROC:',iproc
         return
      endif

*     --- choose jet finder
      IF ((MOD(iflag,100)/10.gt.0).and.MOD(iflag,10).eq.1) THEN
         chjet=INT(MOD(iflag,100)/10)
      ENDIF

*     Decide whether we are running on parton showers or final state particles.
      IF (MOD(iflag,100000)/10000.gt.0) THEN
         parton_showers=.TRUE.
*     use a different paw directory for parton showers.
         chjet=-1*ABS(chjet)
         xxxx = 'PS'//xxxx
      ENDIF

      IF (MOD(iflag,10).eq.1) then
*     Initialisation: The following MUST always be done
*     (i) make subdirectory in PAWC
*     - use the name as the xxxxxx in HZAxxxxxx subroutine
*     (i) make subdirectory in o/p file
         Call hcdir('//PAWC',' ')
         if (iproc.LE.1) call hmdir(xxxx,'S')
         Call hcdir('//HISTO',' ')
         if (iproc.LE.1) call hmdir(xxxx,'S')
         
         CALL HCDIR('//PAWC/'//xxxx,' ')
         CALL HCDIR('//HISTO/'//xxxx,' ')
         
         if (iproc.le.1) then
C     --- create proper cross-section data
            CALL HBOOK1(-10,'Data cos(theta) DIRECT'
     &           ,10 ,0.000 ,0.850 ,0.)
            CALL HBOOK1(-20,'Data cos(theta) RESOLVED'
     &           ,10 ,0.000 ,0.850 ,0.)
            
            
            CALL HPAK(-10,cs)
            CALL HPAKE(-10,sta)
            CALL HPAK(-20,cs2)
            CALL HPAKE(-20,sta2)

            CALL HBOOK1(-11,'Data full errors (nb) x_gam ge 0.75'
     &           ,10 ,0.000 ,0.850 ,0.)
            CALL HBOOK1(-21,'Data full errors (nb) x_gam lt 0.75'
     &           ,10 ,0.000 ,0.850 ,0.)
            
            CALL HPAK(-11,cs)
            DO ivec=1,10
               pttemp(ivec)=sqrt(sta(ivec)**2+syslo(ivec)**2)
            ENDDO
            CALL HPAKE(-11,pttemp)
            CALL HPAK(-21,cs2)
            DO ivec=1,10
               pttemp(ivec)=sqrt(sta2(ivec)**2+syslo2(ivec)**2)
            ENDDO
            CALL HPAKE(-21,pttemp)

         endif
*     
*     book your MC histograms            
         CALL HBOOK1(100*iproc+10,'Monte Carlo cos(theta) DIRECT' ,10 ,0
     $        .000 ,0.850 ,0.)
         CALL HBOOK1(100*iproc+20,'Monte Carlo cos(theta) RESOLVED' ,10
     $        ,0.000 ,0.850 ,0.)

         CALL HIDOPT(0,'stat')
         CALL HBARX(0)
         
C     --- standard cone radius is 1.0
         CALL HZJETRAD(2,CONER)
         IF (CONER.lt.0.0) THEN
            CONER=1.0
         ENDIF
         CALL HZJTNAME(chjet,jetf)
         
         WRITE(6,*)'**********************************************'
         WRITE(6,*)'* HZ96094 called, histograms will be output. *'
         WRITE(6,*)'*     Jet finder selected : ',jetf,'           *'
         WRITE(6,1001)'*        with cone radius : ',CONER,'   *'
         WRITE(6,*)'**********************************************'
         
 1001    FORMAT(A29,F5.2,A13)

      ELSE IF (MOD(iflag,10).eq.2) THEN
C     *** Filling runs ***
         
C     *** Change directory to our graphs ***
         CALL HCDIR('//PAWC/'//xxxx,' ')
         
         q2=hzphokin(1)
         IF (q2.eq.-1) THEN
            PRINT*,'HZ96094: HZPHOKIN returns error for Q2'
         ELSEIF (q2.lt.0) THEN
            q2=abs(q2)
         ENDIF
         ybj=hzphokin(3)
         IF (ybj.eq.-1) THEN
            PRINT*,'HZ96094: HZPHOKIN returns error for ybj'
         ENDIF
         
C     *** Fill our histogram ***
         
         IF ((ybj.ge.ybjcut(1)).and.(ybj.le.ybjcut(2))
     &        .and.(q2.lt.q2cut(2))) Then
            
            elecE=27.5
            hzflag=HZIBEAM(myip,myil)
            IF (hzflag.ge.0) Then
               elecE=abs(PHEP(4,myil))
            ELSE
               PRINT*,'HZ96094: Electron not found. E=0.001'
               PRINT*,'         event will be rejected'
               elecE=0.001
            ENDIF
            
            CALL hzjtfind(chjet,CONER,NJET,Jets)
            
            DO i=1,2
               et(i)=0.0
            ENDDO

c     Make sure we find the highest ET jets which are within the
c     rapidity interval.
            IF (NJET.ge.2) THEN
               i=0
               DO loop=1,njet
c     Search jets in the rapidity interval.
                  IF ( jets(loop,1).gt.rapcut(1).and.jets(loop,1).lt
     &                 .rapcut(2) ) THEN
                     i=i+1
                     IF (i.LE.2) THEN
                        Et(i)=Jets(loop,3)
                        rap(i)=Jets(loop,1)
                        phi(i)=Jets(loop,2)
                     ENDIF
                  ENDIF
               ENDDO
               
               deltaeta=abs(rap(1)-rap(2))
               etabar=(rap(1)+rap(2))/2
               xgam=(Et(1)*exp(-1*rap(1))+Et(2)*exp(-1*rap(2)))
     +              /(2*ybj*elecE)
               costh=abs(tanh(deltaeta/2))
               mjj=sqrt(2*et(1)*et(2)*(cosh(rap(1)-rap(2))
     +              -cos(phi(1)-phi(2))))
               
               IF (Et(2).gt.Etcut(1).and.Mjj.gt.23
     +              .and.abs(etabar).lt.0.5) THEN
                  IF (xgam.gt.0.75) THEN
                     CALL HFILL(INT(iproc*100+10), REAL(costh) , 0. ,wtx
     &                    )
                  ELSE
                     CALL HFILL(INT(iproc*100+20), REAL(costh) , 0. ,wtx
     $                    )
                  ENDIF
               ENDIF
            ENDIF
            
         ENDIF                  ! Q2 & y cuts
         
      ELSE IF (MOD(iflag,10).eq.3) THEN
C     *** Termination run ***
         IF (iproc.eq.0.or.iproc.eq.2) THEN
            WRITE(HZUNIT,*) 'HZ96094: Finishing off.'
         ENDIF

C     *** Change directory ***
         CALL HCDIR('//PAWC/'//xxxx,' ')

C     *** Finish off histograms ***
         
         IF (Xsec.eq.0) THEN
            PRINT*,'HZ96094: termination called with zero cross section'
            PRINT*,'          cross section graph meaningless'
            PRINT*,'          in process :',iproc*1000
            Xsec=1
         ENDIF
         IF (Ntot.eq.0) THEN
            PRINT*,'HZ96094: termination called with no total events'
            PRINT*,'          cross section graph meaningless'
            PRINT*,'          in process :',iproc*1000
            Ntot=1
         ENDIF
         
C     --- only finally
            
C     --- normalise resolved/direct component histograms
C     --- added 20/8/98 by Russell Taylor
         lumnb = ntot/xsec
         call hzhinrm(iproc*100+10,0,lumnb,1)
         call hzhinrm(iproc*100+20,0,lumnb,1)
            
         IF (iproc.eq.2) THEN
C     --- now calculate cross-section graphs 10,20
            CALL HOPERA(110,'+e',210,10,1.,1.)
            CALL HOPERA(120,'+e',220,20,1.,1.)

         ENDIF
         
      ELSE
C     *** End ***
         PRINT*,'HZ96094:Please run routine with iflag set to 1,2 or 3'
         PRINT*,'        with +1000 or +2000 for DIR or RES events.'
      ENDIF
      
      RETURN
      END
