        SUBROUTINE HZ97164(IFLAG)
****************************************************************************
*
* Purpose: Produces histograms for the double-differential di-jet cross
*          section in photoproduction, as a function of the momentum
*          fraction of the parton in the photon as reconstructed from the
*          two highest transverse energy final state jets, and of the
*          logarithm of the square of the mean transverse energy of these
*          jets:
*
*          d^2 sigma(ep->2 jets + X)/(dx_gamma*dlog_10(E_T(jet)^2))
*
*          Event selection cuts : Q2 < 4 GeV^2
*                                 0.2 < y <0.83
*                                 0 < 1/2*(eta1+eta2) < 2
*                                 |eta1-eta2| < 1
*                                 |ET1-ET2|/(ET1+ET2) < 0.25
*
*           with:   Q2 = photon virtuality
*                   y  = E(photon)/E(beam) = normalized photon energy
*            eta1,eta2 = pseudorapidities of the two highest transverse energy
*                        jets in HERA laboratory frame
*            ET1,ET2   = transverse energies of these two jets
*            E_T(jet)  = mean transverse energy of jets = (ET1+ET2)/2
*            x_gamma   = (ET1*exp(-eta1)+ET2*exp(-eta2))/(2*E(beam)*y)
*
*
* Reference : DESY-97-164
*             Eur. Phys. J. C 1 (1998) 97-107
*             Figure 2 and Table 1
*
* Arguments:  iflag=1 initialisation/booking of histograms
*             iflag=2 event processing/filling of MC histograms
*             iflag=3 termination/final normalisation
*                     (the variables Xsec (total cross section) and
*                      Ntot (total number of events) have to be set before
*                      calling the termination routine in order to get a
*                      correct normalisation for the MC histograms)
*
*             This photoproduction routine has to be run twice with the 
*             following code additions:
* 	              +1000 for the DIRECT component run.
*	              +2000 for the RESOLVED component run.
*                     +0 for both
*             for all three phases (iflag=1,2,3)
*
* written by: Hartmut Rick (Hartmut.Rick@desy.de) on 04/02/98
*     modified for split resolved and direct components by Russell Taylor
****************************************************************************
*
* Output graphs:
*---------------
* DATA
*
* histograms -1..-7 contain the measured di-jet cross section data,
* d^2 sigma/(dx_gamma dlog10(ET^2))
* errors are statistical + uncorrelated systematic
* -1        0.1 < x_gamma < 0.2
* -2        0.2 < x_gamma < 0.3
* -3        0.3 < x_gamma < 0.4
* -4        0.4 < x_gamma < 0.5
* -5        0.5 < x_gamma < 0.6
* -6        0.6 < x_gamma < 0.75
* -7        0.75 < x_gamma
*
* histograms -11..-16 contain the same data as a function of x_gamma
* -11       2.00 < log10(ET^2/GeV^2) < 2.15    ( 10.0 GeV < ET < 11.9 GeV )
* -12       2.15 < log10(ET^2/GeV^2) < 2.30    ( 11.9 GeV < ET < 14.1 GeV )
* -13       2.30 < log10(ET^2/GeV^2) < 2.50    ( 14.1 GeV < ET < 17.8 GeV )
* -14       2.50 < log10(ET^2/GeV^2) < 2.70    ( 17.8 GeV < ET < 22.4 GeV )
* -15       2.70 < log10(ET^2/GeV^2) < 3.00    ( 22.4 GeV < ET < 31.6 GeV )
* -16       3.00 < log10(ET^2/GeV^2) < 3.40    ( 31.6 GeV < ET < 50.1 GeV )
*
*
* Monte-Carlo
* d^2 sigma/(dx_gamma dlog10(ET^2))
*  1        0.1 < x_gamma < 0.2
*  2        0.2 < x_gamma < 0.3
*  3        0.3 < x_gamma < 0.4
*  4        0.4 < x_gamma < 0.5
*  5        0.5 < x_gamma < 0.6
*  6        0.6 < x_gamma < 0.75
*  7        0.75 < x_gamma
*               These graphs will be
*               meaningless unless Xsec and Ntot are set before
*               calling the termination routine.
*               (Xsec - total cross section returned by MC)
*               (Ntot - number of events passed to this routine)
*
* d^2 sigma/(dx_gamma dlog10(ET^2)) plotted as a function of x_gamma
* 11       2.00 < log10(ET^2/GeV^2) < 2.15    ( 10.0 GeV < ET < 11.9 GeV )
* 12       2.15 < log10(ET^2/GeV^2) < 2.30    ( 11.9 GeV < ET < 14.1 GeV )
* 13       2.30 < log10(ET^2/GeV^2) < 2.50    ( 14.1 GeV < ET < 17.8 GeV )
* 14       2.50 < log10(ET^2/GeV^2) < 2.70    ( 17.8 GeV < ET < 22.4 GeV )
* 15       2.70 < log10(ET^2/GeV^2) < 3.00    ( 22.4 GeV < ET < 31.6 GeV )
* 16       3.00 < log10(ET^2/GeV^2) < 3.40    ( 31.6 GeV < ET < 50.1 GeV )
*               The same remark about Xsec and Ntot applies as above
*
*****************************************************************************
        IMPLICIT NONE

#include "hepevtp.inc"
#include "heracmn.inc"
#include "hzfunc.inc"

        INTEGER NPTBIN,NXGBIN
        PARAMETER (NPTBIN=6,NXGBIN=7)
        INTEGER NBIN(NPTBIN+10)
        REAL XBIN(NXGBIN+1),PTBIN(NPTBIN+1)
        REAL XSDI(NXGBIN*NPTBIN),XERR(NXGBIN*NPTBIN)

        INTEGER I,J,IP,IL,NJET1
        INTEGER IFLAG,IFFLAG
        REAL TMP(10),TMPE(10),AJET1(10,3)
        REAL EBEAM,Q2,Y,ETA1,ETA2,ET1,ET2,ETJET
        REAL ET2LOG,XGAMMA,WBIN,ANORM(2)
        SAVE EBEAM

        CHARACTER *80 HISTNAME

        REAL RAPMAX,ETMIN,ETSMIN,RJET
        INTEGER NRAPB,NAZMB
        PARAMETER(RAPMAX=5.203263,NRAPB=106,NAZMB=64,ETMIN=0.1,
     +            ETSMIN=5.,RJET=0.7)

C       binning definition
        DATA NBIN /2,3,4,4,4,5,6,0,0,0,7,7,6,5,2,1/
        DATA XBIN /0.1,0.2,0.3,0.4,0.5,0.6,0.75,1.001/
        DATA PTBIN /2.,2.15,2.3,2.5,2.7,3.,3.4/

C       di-jet cross section data
        DATA XSDI /7.42,2.62,0.00,0.00,0.00,0.00,
     +             6.31,2.83,1.23,0.00,0.00,0.00,
     +             5.06,3.00,1.27,0.30,0.00,0.00,
     +             3.81,2.19,1.16,0.46,0.00,0.00,
     +             4.05,2.71,1.27,0.60,0.00,0.00,
     +             5.11,4.15,2.00,0.75,0.27,0.00,
     +             4.32,3.43,2.50,1.25,0.54,0.09/

C       di-jet cross section errors
        DATA XERR /0.87,0.32,1.00,1.00,1.00,1.00,
     +             0.74,0.35,0.16,1.00,1.00,1.00,
     +             0.60,0.37,0.16,0.04,1.00,1.00,
     +             0.46,0.26,0.15,0.07,1.00,1.00,
     +             0.48,0.33,0.16,0.09,1.00,1.00,
     +             0.64,0.49,0.24,0.10,0.05,1.00,
     +             0.62,0.40,0.30,0.16,0.07,0.02/

        INTEGER iproc
        REAL lumnb

        Character*6 xxxx
        DATA xxxx /'d97164'/
        
*     Determine the process type.
        iproc=(mod(iflag,10000)/1000)
        if ((iproc.lt.0).or.(iproc.gt.2)) then
           write(HZUNIT,*) 'HZ',xxxx,': illegal IPROC:',iproc
           return
        endif
        

        IF (MOD(iflag,10).eq.1) then
*     
*     book your MC histograms

C *** Initialisation run ***

           PRINT*,"**********************************************"
           PRINT*,"* HZ97164 initialisation, booking histograms *"
           PRINT*,"**********************************************"
           
           
 27        FORMAT ('DATA d^2![s]/dx?[g]!/dlog?10!(E?T!^2!), ',
     +          F4.2,'"l#x?[g]!"l#',F4.2)
 28        FORMAT ('DATA d^2![s]/dx?[g]!/dlog?10!(E?T!^2!), ',
     +          F4.2,'"l#log?10!(E?T!^2!)"l#',F4.2)
 127       FORMAT ('MC d^2![s]/dx?[g]!/dlog?10!(E?T!^2!), ',
     +          F4.2,'"l#x?[g]!"l#',F4.2)
 128       FORMAT ('MC d^2![s]/dx?[g]!/dlog?10!(E?T!^2!), ',
     +          F4.2,'"l#log?10!(E?T!^2!)"l#',F4.2)
 129       FORMAT ('MC X-sec, ',
     +          F4.2,'"l#x?[g]!"l#',F4.2)
 130       FORMAT ('MC X-sec, ',
     +          F4.2,'"l#log?10!(E?T!^2!)"l#',F4.2)
           
           IF (iproc.le.1) THEN
              CALL HCDIR('//HISTO',' ')
              CALL HMDIR(''//xxxx,'S')
              CALL HCDIR('//PAWC',' ')
              CALL HMDIR(''//xxxx,'S')
              
              DO I=1,NXGBIN
                 WRITE (HISTNAME,27) XBIN(I),XBIN(I+1)
                 CALL HBOOKB(-I,HISTNAME,NBIN(I),PTBIN,0.)
c                 WRITE (HISTNAME,127) XBIN(I),XBIN(I+1)
c                 CALL HBOOKB(I,HISTNAME,NBIN(I),PTBIN,0.)
                 DO J=1,NBIN(I)
                    TMP(J)=XSDI((I-1)*NPTBIN+J)
                    TMPE(J)=XERR((I-1)*NPTBIN+J)
                 END DO
                 CALL HPAK(-I,TMP)
                 CALL HPAKE(-I,TMPE)
              END DO
              
              DO J=1,NPTBIN
                 WRITE (HISTNAME,28) PTBIN(J),PTBIN(J+1)
                 CALL HBOOKB(-J-10,HISTNAME,NBIN(J+10),
     +                XBIN(1+NXGBIN-NBIN(J+10)),0.)
                 WRITE (HISTNAME,128) PTBIN(J),PTBIN(J+1)
c                 CALL HBOOKB(J+10,HISTNAME,NBIN(J+10),
c     +                XBIN(1+NXGBIN-NBIN(J+10)),0.)
                 DO I=1+NXGBIN-NBIN(J+10),NXGBIN
                    TMP(I+NBIN(J+10)-NXGBIN)=XSDI((I-1)*NPTBIN+J)
                    TMPE(I+NBIN(J+10)-NXGBIN)=XERR((I-1)*NPTBIN+J)
                 END DO
                 CALL HPAK(-J-10,TMP)
                 CALL HPAKE(-J-10,TMPE)
              END DO
           ENDIF

           CALL HCDIR('//HISTO/'//xxxx,' ')
           CALL HCDIR('//PAWC/'//xxxx,' ')

           DO I=1,NXGBIN
              WRITE (HISTNAME,129) XBIN(I),XBIN(I+1)
              CALL HBOOKB(I+100*iproc,HISTNAME,NBIN(I),PTBIN,0.)
              CALL HBARX(I+100*iproc)
           END DO
           
           DO J=1,NPTBIN
              WRITE (HISTNAME,130) PTBIN(J),PTBIN(J+1)
              CALL HBOOKB(J+10+100*iproc,HISTNAME,NBIN(J+10),
     +             XBIN(1+NXGBIN-NBIN(J+10)),0.)
              CALL HBARX(J+10+100*iproc)
           END DO
           
*     try to find electron beam energy
           IF FLAG=HZIBEAM(IP,IL)
           IF (IFFLAG.EQ.0.OR.IFFLAG.EQ.1) THEN
              EBEAM=PHEP(4,IL)
              IF (ABS(EBEAM-27.55).GT.0.5) THEN
                 PRINT *,'HZ97164 Warning: wrong electron beam energy'
              END IF
           ELSE
              EBEAM=27.55
           END IF
           
           CALL HIDOPT(0,'stat')

C==================================================================

        ELSE IF (MOD(iflag,10).EQ.2) THEN
C     *** Event loop, fill MC histograms ***
           CALL HCDIR('//PAWC/'//xxxx,' ')
           
           CALL VZERO(AJET1,30)
           NJET1=0
           CALL H1QGCONE(RAPMAX,NRAPB,NAZMB,ETMIN,ETSMIN,RJET,
     +          NJET1,AJET1)
*     
*     test kinematic range
           Q2=REAL(HZPHOKIN(1))
           Y=REAL(HZPHOKIN(3))

           IF (Q2.GT.4.) GOTO 65
           IF (Y.LT.0.2.OR.Y.GT.0.83) GOTO 65
*     
*     at least two jets required
           IF (NJET1.LT.2) GOTO 65
*     
*     pseudorapidity range of jets
           ETA1=AJET1(1,2)
           ETA2=AJET1(2,2)

           IF (ABS(ETA1-ETA2).GT.1.) GOTO 65
           IF (ETA1+ETA2.LT.0..OR.ETA1+ETA2.GT.4.) GOTO 65
*     
*     jet transverse energies
           ET1=AJET1(1,1)
           ET2=AJET1(2,1)
           ETJET=(ET1+ET2)/2

           IF (ABS(ET1-ET2)/ETJET.GT.0.5) GOTO 65
           ET2LOG=2.*LOG10(ETJET)
           XGAMMA=(ET1*EXP(-ETA1)+ET2*EXP(-ETA2))/(2.*Y*EBEAM)
*
*     bin width
           WBIN=WTX
*
*     find ET bin
           DO J=1,NPTBIN
              IF (PTBIN(J).LE.ET2LOG.AND.ET2LOG.LT.PTBIN(J+1)) GOTO 63
           END DO
*
 63        CONTINUE
           IF (J.GT.NPTBIN) GOTO 65
           WBIN=WBIN/(PTBIN(J+1)-PTBIN(J))
*     
*     find x_gamma bin
           DO I=1,NXGBIN
              IF (XBIN(I).LE.XGAMMA.AND.XGAMMA.LT.XBIN(I+1)) GOTO 64
           END DO
*     
 64        CONTINUE
           IF (I.GT.NXGBIN) GOTO 65
           WBIN=WBIN/(XBIN(I+1)-XBIN(I))

*     
*     fill histograms
           CALL HFILL (I+100*iproc,ET2LOG,0.,WBIN)
           CALL HFILL (J+10+100*iproc,XGAMMA,0.,WBIN)
*     
 65        CONTINUE
           
           
        ELSE IF (MOD(iflag,10).eq.3) THEN
C     *** Termination, fix normalisation of MC histograms ***

           IF (iproc.eq.0.or.iproc.eq.2) THEN
              write(hzunit,*) 'HZ97164: Finishing off'
           endif
           
           CALL HCDIR('//PAWC/'//xxxx,' ')
           
           IF (Xsec.eq.0) THEN
            PRINT*,'HZ97164: termination with zero cross section'
            PRINT*,'          cross section graph meaningless'
            PRINT*,'	      in process :',iproc*1000
            Xsec=1
           ENDIF
           IF (Ntot.eq.0) THEN
              PRINT*,'HZ97164: termination with no total events'
              PRINT*,'          cross section graph meaningless'
              PRINT*,'	      in process :',iproc*1000
	    Ntot=1
	  ENDIF

          lumnb=ntot/xsec

C          PRINT*,ANORM(iproc)

          DO I=1,NXGBIN
             call hzhnorm(i+100*iproc,0,lumnb,1)
          END DO

          DO J=1,NPTBIN
             call hzhnorm(j+10+100*iproc,0,lumnb,1)
          END DO

          if (iproc.eq.2) then
             DO I=1,NXGBIN
                CALL HOPERA(I+100,'+E',I+200,I,1.,1.)
             enddo
             DO J=1,NPTBIN                
                CALL HOPERA(J+110,'+E',J+210,J+10,1.,1.)
             enddo

          endif


*
        ELSE
          WRITE(6,*) 'HZ97164: Unknown flag',iflag
        ENDIF
        RETURN
        END
