      Subroutine HZ97191(iflag)
c     ---------------------------------------------------------
c     Jet shapes in photoproduction (ZEUS data)
c     
c     This routine has to be run twice with the following
c     code additions:
c     +1000 for the DIRECT component run.
c     +2000 for the RESOLVED component run.
c     +0 for both together.
c     for all three phases (iflag=1,2,3)
c
c     Previous versions of this routine were utterly bug ridden.
c     Hopefully this one is less so. However, there is one caveat: the
c     error treatment is only approximately correct when the numbers of
c     events generated for direct and resolved are in approximate
c     accord with their cross section ratios. If not, you'll get either
c     spuriously large or spuriously small error bars on the combined
c     plots (although the individual plots for resolved and direct
c     should be correct). Since the experimental errors are so highly
c     correlated you shouldn't be taking any chi2 seriously from these
c     plots anyway!
c     
c     Apart from that, this routine now deals with weighted events
c     properly.
c
c     iflag = 1,2 or 3 depending on whether it is the initialization,
c               processing or termination phase (respectively)
c
c     The default jetfinder is PXCONE
c     To change jetfinder use these values to call the initialisation
c     phase.
c     1 + 10 c (jetfinder number)
c
c     This routine produces sixteen Monte Carlo graphs.
c     for inclusive jet production: (jet profiles)
c           10  |  14 < ET <= 17
c           11  |  17 < ET <= 21
c           12  |  21 < ET <= 25
c           13  |  25 < ET <= 29
c           20  |  -1 < rap < 0
c           21  |   0 < rap < 1
c           22  |   1 < rap < 1.5
c           23  | 1.5 < rap < 2
c           15  |  r=0.5 ET
c           25  |  r=0.5 rap
c     for dijet events: (jet profiles)
c           30  |  -1 < rap < 0
c           31  |   0 < rap < 1
c           32  |   1 < rap < 1.5
c           33  | 1.5 < rap < 2
c           40  | xg > 0.75 and -1 < rap < 0
c           41  | xg < 0.75 and  0 < rap < 1
c
c     Cuts :        Q2 < 4 GeV^2
c                   0.2 < y_jb < 0.85
c                   Et > 14 GeV
c                   -1 <eta1,eta2 <2
c
c     Authors : Mark Hayes, Jon Butterworth 
c
c     Reference : DESY-97-191, hep-ex/9710002
c
c     ------------------------------------------------------
 
      IMPLICIT NONE

#include "hepevtp.inc"
#include "heracmn.inc"
#include "hzfunc.inc" 
#include "hzjetcmn.inc"
 
      INTEGER nbins
      PARAMETER(nbins=10)

c     INCLUSIVE jet results
c     *** a is -1<eta<0, b is 0<eta<1, c is 1<eta<1.5, d is 1.5<eta<2
c     *** in bins of eta
      REAL cs1a(nbins),sta1a(nbins)
      DATA cs1a/0.,0.573,0.710,0.794,0.855,0.899,0.934,0.960,0.981,1.0/
      DATA sta1a/0.,0.008,0.006,0.005,0.004,0.003,0.002,0.001,0.001,0.0/
      REAL cs1b(nbins),sta1b(nbins)
      DATA cs1b/0.,0.528,0.672,0.763,0.829,0.879,0.918,0.951,0.977,1.0/
      DATA sta1b/0.,0.005,0.004,0.003,0.003,0.002,0.001,0.001,0.001,0.0/
      REAL cs1c(nbins),sta1c(nbins)
      DATA cs1c/0.,0.446,0.597,0.709,0.788,0.847,0.896,0.937,0.971,1.0/
      DATA sta1c/0.,0.007,0.007,0.006,0.005,0.004,0.003,0.002,0.001,0.0/
      REAL cs1d(nbins),sta1d(nbins)
      DATA cs1d/0.,0.381,0.533,0.647,0.734,0.807,0.865,0.914,0.960,1.0/
      DATA sta1d/0.,0.006,0.006,0.005,0.004,0.003,0.003,0.002,0.001,0.0/
c     *** a 14<et<17, b is 17<et<21, c is 21<et<25, d is 25<et<29
c     *** in bins of et
      REAL cs2a(nbins),sta2a(nbins)
      DATA cs2a/0.,0.446,0.599,0.707,0.786,0.846,0.895,0.935,0.971,1.0/
      DATA sta2a/0.,0.004,0.004,0.003,0.002,0.002,0.001,0.001,0.001,0.0/
      REAL cs2b(nbins),sta2b(nbins)
      DATA cs2b/0.,0.521,0.665,0.752,0.820,0.872,0.914,0.946,0.975,1.0/
      DATA sta2b/0.,0.006,0.006,0.005,0.004,0.003,0.002,0.001,0.001,0.0/
      REAL cs2c(nbins),sta2c(nbins)
      DATA cs2c/0.,0.584,0.722,0.806,0.859,0.902,0.934,0.960,0.981,1.0/
      DATA sta2c/0.,0.011,0.010,0.008,0.006,0.005,0.003,0.002,0.001,0.0/
      REAL cs2d(nbins),sta2d(nbins)
      DATA cs2d/0.,0.611,0.736,0.822,0.875,0.917,0.947,0.968,0.985,1.0/
      DATA sta2d/0.,0.018,0.015,0.012,0.009,0.006,0.004,0.003,0.002,0.0/
c     *** in eta r=0.5
      REAL cs3(4),sta3(4),xbins3(5)
      DATA xbins3/-1.0,0.0,1.0,1.5,2.0/
      DATA cs3/0.855,0.829,0.788,0.734/
      DATA sta3/0.004,0.003,0.005,0.004/
c     *** in et r=0.5
      REAL cs4(4),sta4(4),xbins4(5)
      DATA xbins4/14.0,17.0,21.0,25.0,29.0/
      DATA cs4/0.786,0.820,0.859,0.875/
      DATA sta4/0.002,0.004,0.006,0.009/
c     *** DIJET results
c     *** a is -1<eta<0, b is 0<eta<1, c is 1<eta<1.5, d is 1.5<eta<2
c     *** in bins of eta
      REAL cs5a(nbins),sta5a(nbins)
      DATA cs5a/0.,0.611,0.747,0.822,0.877,0.914,0.946,0.967,0.985,1.0/
      DATA sta5a/0.,0.013,0.010,0.009,0.007,0.005,0.003,0.002,0.001,0.0/
      REAL cs5b(nbins),sta5b(nbins)
      DATA cs5b/0.,0.568,0.713,0.799,0.859,0.904,0.937,0.963,0.984,1.0/
      DATA sta5b/0.,0.007,0.006,0.005,0.004,0.003,0.002,0.001,0.001,0.0/
      REAL cs5c(nbins),sta5c(nbins)
      DATA cs5c/0.,0.521,0.666,0.767,0.835,0.888,0.929,0.957,0.980,1.0/
      DATA sta5c/0.,0.012,0.010,0.008,0.007,0.005,0.003,0.002,0.001,0.0/
      REAL cs5d(nbins),sta5d(nbins)
      DATA cs5d/0.,0.487,0.628,0.733,0.803,0.862,0.908,0.942,0.975,1.0/
      DATA sta5d/0.,0.010,0.009,0.008,0.006,0.004,0.003,0.002,0.001,0.0/
c     *** a is xg<0.75 b is xg>0.75
c     *** in bin -1<eta<2, ET>14
      REAL cs6a(nbins),sta6a(nbins)
      DATA cs6a/0.,0.494,0.634,0.736,0.807,0.865,0.911,0.947,0.976,1.0/
      DATA sta6a/0.,0.008,0.007,0.006,0.005,0.004,0.003,0.002,0.001,0.0/
      REAL cs6b(nbins),sta6b(nbins)
      DATA cs6b/0.,0.591,0.726,0.809,0.865,0.909,0.942,0.965,0.984,1.0/
      DATA sta6b/0.,0.006,0.005,0.004,0.003,0.002,0.002,0.001,0.001,0.0/
      Integer chjet
      SAVE chjet
C     --- choose same jet finder as in the paper --- PXCONE (should be
c     pucell but it doesn't keep track of particle/jet mapping, and
c     pxcone is almost the same.
      DATA chjet/2/
      CHARACTER*6 jetf
      
C     --- information returned by jet finder
      INTEGER NJET, ierr, ir
      DOUBLE PRECISION CONER
      SAVE CONER

C     --- cuts arrays
      DOUBLE PRECISION ybjcut(2),q2cut(2)
      DOUBLE PRECISION rapcut(2),Etcut(5)
C     --- photoproduction cuts
      DATA ybjcut/0.2,0.85/
      DATA q2cut/0.0,4/
      DATA Etcut/14.0,17.0,21.0,25.0,29.0/
      DATA rapcut/-1.0,2.0/
      
c     ---
      INTEGER ijet
      INTEGER K
      DOUBLE PRECISION elecE
      INTEGER myil,myip,loop,i,j,id
      DOUBLE PRECISION xgam
      REAL distr2
      DOUBLE PRECISION px,py,pz,ptsq,ppsq,pet,pphi,prap

c     Local jet variables.
      DOUBLE PRECISION phi(maxhzjets),rap(maxhzjets),Et(maxhzjets)
      INTEGER idjet(maxhzjets)

c     Local jet shape variables.
      DOUBLE PRECISION ddumA(MAXHZJETS,8)
      DOUBLE PRECISION djshpRho(nbins,MAXHZJETS)
      DOUBLE PRECISION djshpPsi(nbins,MAXHZJETS)
      DOUBLE PRECISION drpsi(nbins)

      DOUBLE PRECISION ybj,q2
      REAL dirw,resw,cont(2,10:41),tot,nwgt(2)
      INTEGER iproc, iflag
      INTEGER hzflag
      SAVE cont

      DOUBLE PRECISION mhxsec(2), mhntot(2)
      REAL pttemp(12)
      SAVE mhxsec, mhntot
      INTEGER ivec,jvec
      REAL HI

c *** values of r/R for psi (histo filling)
      Data drpsi / 0.10D0, 0.20D0, 0.30D0, 0.40D0, 0.50D0,
     .             0.60D0, 0.70D0, 0.80D0, 0.90D0, 1.00D0 /

      CHARACTER*6 xxxx
      DATA xxxx /'d97191'/

****** set the jet cone radius. (only necessary if using jets!)
****** CALL hzjetrad(1,coner) sets the radius to coner
****** CALL hzjetrad(2,coner) sets coner to the radius, or -1. 
******  check if the radius has been set eleswhere
      CALL hzjetrad(2,coner)
******  if not set it to the value used in the paper.
      IF (coner.LT.0.0) THEN
	      coner=1.0
      ENDIF

****** Determine the process type (single/double resolved etc)
      iproc=(mod(iflag,10000)/1000)
      IF ((iproc.LT.0).OR.(iproc.GT.2)) THEN
         WRITE(HZUNIT,*) xxxx,': illegal IPROC:',iproc
         RETURN
      ENDIF

****** choose jet finder
      IF ((MOD(iflag,100)/10.GT.0).AND.MOD(iflag,10).eq.1) THEN
         chjet=INT(MOD(iflag,100)/10)
      ENDIF

******************************************************************************
********************************  Initialise ********************************* 
      IF (MOD(iflag,10).EQ.1) THEN

C     *** Initialisation ***
C     *** Create directories ***
         IF (iproc.le.1) THEN
            CALL HCDIR('//HISTO',' ')
            CALL HMDIR(xxxx,'S')
            CALL HCDIR('//PAWC',' ')
            CALL HMDIR(xxxx,'S')
 
            
C     --- create measured data plots.
            CALL HBOOK1(-10,'r (14"l#E?t!"l#17)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-11,'r (17"l#E?t!"l#21)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-12,'r (21"l#E?t!"l#25)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-13,'r (25"l#E?t!"l#29)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-20,'r (-1"l#[c]"l#0)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-21,'r (0"l#[c]"l#1)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-22,'r (1"l#[c]"l#1.5)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-23,'r (1.5"l#[c]"l#2)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOKB(-15,'(r=0.5) E?t!'
     +           ,4, xbins4, 0.)
            CALL HBOOKB(-25,'(r=0.5) [c]'
     +           ,4, xbins3, 0.)
            CALL HBOOK1(-30,'DIJET r (-1"l#[c]"l#0)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-31,'DIJET r (0"l#[c]"l#1)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-32,'DIJET r (1"l#[c]"l#1.5)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-33,'DIJET r (1.5"l#[c]"l#2)'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-40,'DIJET DIR r'
     +           ,nbins, 0.05, 1.05, 0.)
            CALL HBOOK1(-41,'DIJET RES r'
     +           ,nbins, 0.05, 1.05, 0.)
 
            CALL HPAK(-10,cs2a)
            CALL HPAKE(-10,sta2a)
            CALL HPAK(-11,cs2b)
            CALL HPAKE(-11,sta2b)
            CALL HPAK(-12,cs2c)
            CALL HPAKE(-12,sta2c)
            CALL HPAK(-13,cs2d)
            CALL HPAKE(-13,sta2d)
            CALL HPAK(-20,cs1a)
            CALL HPAKE(-20,sta1a)
            CALL HPAK(-21,cs1b)
            CALL HPAKE(-21,sta1b)
            CALL HPAK(-22,cs1c)
            CALL HPAKE(-22,sta1c)
            CALL HPAK(-23,cs1d)
            CALL HPAKE(-23,sta1d)
            CALL HPAK(-15,cs4)
            CALL HPAKE(-15,sta4)
            CALL HPAK(-25,cs3)
            CALL HPAKE(-25,sta3)
            CALL HPAK(-30,cs5a)
            CALL HPAKE(-30,sta5a)
            CALL HPAK(-31,cs5b)
            CALL HPAKE(-31,sta5b)
            CALL HPAK(-32,cs5c)
            CALL HPAKE(-32,sta5c)
            CALL HPAK(-33,cs5d)
            CALL HPAKE(-33,sta5d)
            CALL HPAK(-40,cs6b)
            CALL HPAKE(-40,sta6b)
            CALL HPAK(-41,cs6a)
            CALL HPAKE(-41,sta6a)

         ENDIF
         
         CALL HCDIR('//HISTO/'//xxxx,' ')
         CALL HCDIR('//PAWC/'//xxxx,' ')
         CALL HBOOK1(100*iproc+10,'MC r 14.lt.ET.le.17' ,nbins, 0.05, 1
     $        .05, 0.)
         CALL HBOOK1(100*iproc+11,'MC r 17.lt.ET.le.21' ,nbins, 0.05, 1
     $        .05, 0.)
         CALL HBOOK1(100*iproc+12,'MC r 21.lt.ET.le.25' ,nbins, 0.05, 1
     $        .05, 0.)
         CALL HBOOK1(100*iproc+13,'MC r 25.lt.ET.le.29' ,nbins, 0.05, 1
     $        .05, 0.)
         CALL HBOOK1(100*iproc+20,'MC r -1.lt.rap.lt.0' ,nbins, 0.05, 1
     $        .05, 0.)
         CALL HBOOK1(100*iproc+21,'MC r 0.lt.rap.lt.1' ,nbins, 0.05, 1
     $        .05, 0.)
         CALL HBOOK1(100*iproc+22,'MC r 1.lt.rap.lt.1.5' ,nbins, 0.05, 1
     $        .05, 0.)
         CALL HBOOK1(100*iproc+23,'MC r 1.5.lt.rap.lt.2' ,nbins, 0.05, 1
     $        .05, 0.)
         CALL HBOOKB(100*iproc+15,'MC r=0.5 ET' ,4, xbins4, 0.)
         CALL HBOOKB(100*iproc+25,'MC r=0.5 [c]' ,4, xbins3, 0.)
         CALL HBOOK1(100*iproc+30,'MC DIJET r -1.lt.rap.lt.0' ,nbins, 0
     $        .05, 1.05, 0.)
         CALL HBOOK1(100*iproc+31,'MC DIJET r 0.lt.rap.lt.1' ,nbins, 0
     $        .05, 1.05, 0.)
         CALL HBOOK1(100*iproc+32,'MC DIJET r 1.lt.rap.lt.1.5' ,nbins, 0
     $        .05, 1.05, 0.)
         CALL HBOOK1(100*iproc+33,'MC DIJET r 1.5.lt.rap.lt.2' ,nbins, 0
     $        .05, 1.05, 0.)
         CALL HBOOK1(100*iproc+40,'MC DIJET DIR r -1.lt.rap.lt.0' ,nbins
     $        , 0.05, 1.05, 0.)
         CALL HBOOK1(100*iproc+41,'MC DIJET RES r 0.lt.rap.lt.1' ,nbins,
     $        0.05, 1.05, 0.)

         CALL HBARX(0)
         CALL HBARY(0)
         CALL HBAR2(0)
         CALL HIDOPT(0,'stat')

         DO i=10,41
            cont(iproc,i)=0.
         ENDDO

C --- standard cone radius is 1.0
         CALL HZJETRAD(2,CONER)
         IF (CONER.lt.0.0) THEN
            CONER=1.0
         ENDIF
         CALL HZJTNAME(chjet,jetf)
         
         WRITE(6,*)'**********************************************'
         WRITE(6,*)'* HZ97191 called, histograms will be output. *'
         WRITE(6,*)'*     Jet finder selected : ',jetf,'           *'
         WRITE(6,1001)'*        with cone radius : ',CONER,'   *'
         WRITE(6,*)'**********************************************'
         
 1001    FORMAT(A29,F5.2,A13)
         
      ELSE IF (MOD(iflag,10).eq.2) THEN
C     *** Filling ***
         
C     *** Change directory to our graphs ***
         CALL HCDIR('//PAWC/'//xxxx,' ')
         
         q2=hzphokin(1)
         IF (q2.eq.-1) THEN
            PRINT*,'HZ97191: HZPHOKIN returns error for Q2'
         ELSEIF (q2.lt.0) THEN
            q2=abs(q2)
         ENDIF
         ybj=hzphokin(3)
         IF (ybj.eq.-1) THEN
            PRINT*,'HZ97191: HZPHOKIN returns error for ybj'
         ENDIF
         
C     *** Fill our histogram ***
         
         IF ((ybj.ge.ybjcut(1)).and.(ybj.le.ybjcut(2))
     &        .and.(q2.lt.q2cut(2))) Then
            
            hzflag=HZIBEAM(myip,myil)
            IF (hzflag.ge.0) Then
               elecE=abs(PHEP(4,myil))
            ELSE
               PRINT*,'HZ97191: Electron not found. E=0.001'
               PRINT*,'         event will be rejected'
               elecE=0.001
            ENDIF
            
c     Find the jets
            CALL HZJTFIND(chjet,coner,njet,jets)
c     Calculate the shapes.
            CALL HZJETSHP(1, coneR, djshpRho, djshpPsi, ierr) 
            IF (ierr.ne.0) THEN
               WRITE(6,*) 'HZ97191: error in HzJetshp !'
               RETURN
            ENDIF
            
            DO i=1,2
               et(i)=0.0
            ENDDO
            
c     identify the jets we care about.
c     (jets are already ordered in ET).
            ijet=0
            DO loop=1,njet
c     define rapidity window.
               IF (jets(loop,1).GE.rapcut(1).AND.jets(loop,1).le
     &              .rapcut(2)) THEN
                  IF (jets(loop,3).gt.etcut(1)) THEN
                     IF (ijet.LT.maxhzjets) THEN
                        ijet=ijet+1
                        et(ijet)=jets(loop,3)
                        rap(ijet)=jets(loop,1)
                        phi(ijet)=jets(loop,2)
                        idjet(ijet)=loop
                     ELSE
                        write(*,*) 'HZ97191: Too many jets.'
                     ENDIF 
                  ENDIF
               ENDIF
            ENDDO

c     the local arrays now contain et ordered list of jets within the
c     rapidity window.

c     if this is a dijet event, calculate xgamma
            IF (ijet.ge.2) THEN
               xgam=(Et(1)*exp(-1*rap(1))+Et(2)*exp(-1*rap(2)))
     +              /(2*ybj*elecE)
            ENDIF
            
c     loop over the jets
            DO loop=1,ijet
               
c     Inclusive jets, find out which histograms this belongs to.
c     By ET
               IF (et(loop).gt.etcut(1).and.Et(loop).lt.etcut(2
     &              )) THEN
                  DO ir=1,10
                     CALL HZMEANHI(iproc*100+10,drpsi(ir),djshppsi(ir
     &                    ,idjet(loop)),wtx)
                  ENDDO
                  cont(iproc,10)=cont(iproc,10)+wtx
                  
               ELSEIF (et(loop).gt.etcut(2).and.Et(loop).lt.etcut(3
     &                 )) THEN
                  DO ir=1,10
                     CALL HZMEANHI(iproc*100+11,drpsi(ir),djshppsi(ir
     &                    ,idjet(loop)),wtx)
                  ENDDO
                  cont(iproc,11)=cont(iproc,11)+wtx
                  
               ELSEIF (et(loop).gt.etcut(3).and.Et(loop).lt.etcut(4
     &                 )) THEN
                  DO ir=1,10
                     CALL HZMEANHI(iproc*100+12,drpsi(ir),djshppsi(ir
     &                    ,idjet(loop)),wtx)
                  ENDDO
                  cont(iproc,12)=cont(iproc,12)+wtx
                  
               ELSEIF (et(loop).gt.etcut(4).and.Et(loop).lt.etcut(5
     &                 )) THEN
                  DO ir=1,10
                     CALL HZMEANHI(iproc*100+13,drpsi(ir),djshppsi(ir
     &                    ,idjet(loop)),wtx)
                  ENDDO
                  cont(iproc,13)=cont(iproc,13)+wtx
                  
               ENDIF
               
c     By eta
               IF (rap(loop).gt.-1.0.and.rap(loop).lt.0.0) THEN
                  DO ir=1,10
                     CALL HZMEANHI(iproc*100+20,drpsi(ir),djshppsi(ir
     &                    ,idjet(loop)),wtx)
                  ENDDO
                  cont(iproc,20)=cont(iproc,20)+wtx
                  
               ELSEIF (rap(loop).gt.0.0.and.rap(loop).lt.1.0) THEN
                  DO ir=1,10
                     CALL HZMEANHI(iproc*100+21,drpsi(ir),djshppsi(ir
     &                    ,idjet(loop)),wtx)
                  ENDDO
                  cont(iproc,21)=cont(iproc,21)+wtx
                  
               ELSEIF (rap(loop).gt.1.0.and.rap(loop).lt.1.5) THEN
                  DO ir=1,10
                     CALL HZMEANHI(iproc*100+22,drpsi(ir),djshppsi(ir
     &                    ,idjet(loop)),wtx)
                  ENDDO
                  cont(iproc,22)=cont(iproc,22)+wtx
                  
               ELSEIF (rap(loop).gt.1.5.and.rap(loop).lt.2.0) THEN
                  DO ir=1,10
                     CALL HZMEANHI(iproc*100+23,drpsi(ir),djshppsi(ir
     &                    ,idjet(loop)),wtx)
                  ENDDO
                  cont(iproc,23)=cont(iproc,23)+wtx

               ENDIF
               
c     Are there two jets?
               IF (ijet.GE.2) THEN
                  
c     All dijet events
c     By eta
                  IF (rap(loop).gt.-1.0.and.rap(loop).lt.0.0) THEN
                     DO ir=1,10
                        CALL HZMEANHI(iproc*100+30,drpsi(ir),djshppsi(ir
     &                       ,idjet(loop)),wtx)
                     ENDDO
                     cont(iproc,30)=cont(iproc,30)+wtx
                     
                  ELSEIF (rap(loop).gt.0.0.and.rap(loop).lt.1.0) THEN
                     DO ir=1,10
                        CALL HZMEANHI(iproc*100+31,drpsi(ir),djshppsi(ir
     &                       ,idjet(loop)),wtx)
                     ENDDO
                     cont(iproc,31)=cont(iproc,31)+wtx
                     
                  ELSEIF (rap(loop).gt.1.0.and.rap(loop).lt.1.5) THEN
                     DO ir=1,10
                        CALL HZMEANHI(iproc*100+32,drpsi(ir),djshppsi(ir
     &                       ,idjet(loop)),wtx)
                     ENDDO
                     cont(iproc,32)=cont(iproc,32)+wtx
                     
                  ELSEIF (rap(loop).gt.1.5.and.rap(loop).lt.2.0) THEN
                     DO ir=1,10
                        CALL HZMEANHI(iproc*100+33,drpsi(ir),djshppsi(ir
     &                       ,idjet(loop)),wtx)
                     ENDDO
                     cont(iproc,33)=cont(iproc,33)+wtx
                     
                  ENDIF
                  
c     xgamma bins
                  IF (xgam.gt.0.75) THEN
                     DO ir=1,10
                        CALL HZMEANHI(iproc*100+40,drpsi(ir)
     &                       ,djshppsi(ir,idjet(loop)),wtx)
                     ENDDO
                     cont(iproc,40)=cont(iproc,40)+wtx
                  ELSE
                     DO ir=1,10
                        CALL HZMEANHI(iproc*100+41,drpsi(ir)
     &                       ,djshppsi(ir,idjet(loop)),wtx)
                     ENDDO
                     cont(iproc,41)=cont(iproc,41)+wtx
                     
                  ENDIF         ! which xgamma bin
               ENDIF            ! DIJET event
               
            ENDDO               ! loop over jets
         ENDIF                  ! Q2 & y cuts
         
      ELSE IF (MOD(iflag,10).eq.3) THEN
C     *** Termination run ***
         IF (iproc.NE.1) THEN
            WRITE(HZUNIT,*) 'HZ97191: finishing off'
         ENDIF

C     *** Change directory ***
         CALL HCDIR('//PAWC/'//xxxx,' ')
C     *** Finish off histograms ***
         IF (Ntot.eq.0) THEN
            PRINT*,'HZ97191: termination called with no total events'
            PRINT*,'          in process :',iproc*1000
            Ntot=1
         ENDIF

         IF (iproc.gt.0) THEN
            mhXsec(iproc)=Xsec
            mhntot(iproc)=Ntot
         ENDIF
         
c     For iproc=0 (simultaneous run) we don't need any of this.
         
         IF (iproc.eq.2) THEN
C     --- only finally
 
            WRITE(*,*)
     &           'If this number is very different from one,',
     &           'your errors on the jet shapes are unreliable: '
     &           ,(mhxsec(1)*mhntot(2))/(mhntot(1)*mhxsec(2))

            WRITE(*,*) mhxsec(1),mhxsec(2),mhntot(1),mhntot(2)

            DO i=1,4
               DO loop=0,3
                  IF (i.ne.4.or.loop.lt.2) THEN
                     
c     I think what we need to do here is add the resolved & direct
c     relative weighted by their cross sections * number of entries /
c     number generated

                     id = i*10+loop

                     dirw = mhxsec(1)
                     resw = mhxsec(2)

                     DO j=1,2
                        IF (mhntot(j).EQ.0) THEN
                           nwgt(j)=0
                        ELSE
                           nwgt(j)=1./mhntot(j)
                        ENDIF
                     ENDDO

                     IF (nwgt(1)+nwgt(2).GT.0) THEN
                        dirw = dirw*nwgt(1)
                        resw = resw*nwgt(2)
                     ENDIF
     
                     dirw=dirw*cont(1,id)
                     resw=resw*cont(2,id)

                     tot = cont(1,id)*nwgt(1)*mhxsec(1)+cont(2,id)
     &                    *nwgt(2)*mhxsec(2)

                     IF (tot.EQ.0) THEN
                        tot=1.0
                        dirw=0.
                        resw=0.
                     ENDIF

c                     write(*,*) 'id,tot,cont(1,id),cont(2,id),resw,dirw'
c     &                    ,id,tot,cont(1,id),cont(2,id),resw,dirw

                     CALL HOPERA(100+id,'+e',200+id,id,dirw/tot,resw/tot
     &                    )

                  ENDIF         !only graphs 40,41 (no 42,43)
               ENDDO            !loop
            ENDDO               !i
         ENDIF
         
      ELSE
C     *** End ***
         PRINT*,'HZ97191:Please run routine with iflag set to 1,2 or 3'
         PRINT*,'        with +1000 or +2000 for DIR or RES events.'
      ENDIF
      
      RETURN
      END









