*****************************************************************************
	Subroutine HZ98038(imode)
*****************************************************************************
* Running: Ee=27.5 (positrons), Ep=820, no polarization
*
* purpose: produce histograms for:
*
*          jet shape variables in lab frame:  differential jetshp rho,
*          ---------------------------------  integrated jetshp psi
*
*          jetfinder PXCONE with cone radius = 1 is used
*
*          event selection:
*          i)     Q**2 > 100 GeV**2
*          for NC events:
*          NCii)  energy of scattered lepton > 10 GeV
*          NCiii) y < 0.95
*          NCiv)  for eta(lepton) > 2: Et of scattered lepton > 20 GeV
*          for CC events:
*          CCii)  pt of neutrino > 11 GeV
*
*          jet selection:
*          Ji)    Et(jet) > 14 GeV
*          Jii)  -1 < eta(jet) < 2
*
*
* note:    CC event processing not implemented yet !
*
* produced histos:
*          - figure number is that one from the paper,
*          - number in parentheses is number of produced MC histogram
*          - ZEUS data histograms have corresponding negative numbers plus
*            offset=-100 for statistical errors only,
*            offset=-300 for total up error,
*            offset=-400 for total down error
*
*          note: chi**2 is calculated using only statistical errors for
*                ZEUS data
*
*          FIG. 1: NC - DIFFERENTIAL JET SHAPES (et > 14 GeV, Q2>100 GeV2)
*          (11:) -1<eta<0, (12:) 0<eta<1, (13:) 1<eta<1.5, (14:) 1.5<eta<2
*
*          FIG. 2: NC - DIFFERENTIAL JET SHAPES (-1<eta<2, Q2>100 GeV2)
*          (21:) 14<et<21, (22:) 21<et<29, (23:) 29<et<37, (24:) 37<et<45
*
*          FIG. 3: NC - INTEGRATED JET SHAPES at r/R=0.5 (Q2>100 GeV2)
*          (31:) as a function of eta (ET > 14 GeV)
*          (32:) as a function of ET
*
*          FIG. 4: CC -  DIFFERENTIAL JET SHAPES (-1<eta<2, Q2>100 GeV2)
*          (41:) 14<et<21, (42:) 21<et<29, (43:) 29<et<37, (44:) 37<et<45
*
*          FIG. 5: CC - INTEGRATED JET SHAPES at r/R=0.5 (Q2>100 GeV2)
*          (51:) as a function of eta (ET > 14 GeV)
*          (52:) as a function of ET
*
*          FIG. 6: RATIO OF CC TO NC DIFFERENTIAL JET SHAPES
*          (61:) 14<Et<21, (62:) 21<Et<29, (63:) 29<Et<37, (64:) 37<Et<45
*          note: only histos with ZEUS data, no MC histos for FIG.6
*                are produced
*
*          FIG. 7: NC - INTEGRATED JET SHAPE
*          (Q2>100 GeV2, Et>14 GeV, -1<eta<2)
*
*          FIG. 9: INTEGRATED JET SHAPES IN NC AND CC DIS
*          (Q2 > 100 GeV2, 37<Et<45 GeV)
*
*
* arguments:  iflag=1 initialisation
*             iflag=1002 NC event filling
*                  =2002 CC event filling
*             iflag=3 termination
*
*             note: call this routine only with iflag=1 and iflag=3
*                   only once
*
* comments:   - be careful with (Snowmass) convention with massive hadrons
*             (Et not exactly equal to pt); this subroutine uses the pt-scheme
*             - with the definition of the integrated jet shape psi in
*             the paper DESY-98-038, psi(r/R=1) is identical equal to 1
*
* structure:  called subroutines and functions:
*             from hbook lib:  hcdir,hmdir,hbookb,hbook1,
*                              hpak,hpake,hfill
*             from HzTool lib: HzDiskin,HzIdelec,(HzIdntro,)
*                              HzPt, HzJtfind, HzJetshp, HzMeanHi
*             and some subroutines contained in this file
*
* written by: Andreas von Manteuffel
*
* reference:  DESY-98-038
*
**********************************************************************

      IMPLICIT NONE

****************************************************************
*     DECLARATIONS for HzTool stuff
****************************************************************
*
* HERA Tuning defined commons

#include "hepevtp.inc"
#include "heracmn.inc"
#include "hzfunc.inc"
#include "hzjetcmn.inc"

****************************************************************
*     DECLARATIONS for ZEUS histos
****************************************************************

      Real rhnc11(10), rhnc11a(10), rhnc11tu(10), rhnc11td(10)	
      Real rhnc12(10), rhnc12a(10), rhnc12tu(10), rhnc12td(10)	
      Real rhnc13(10), rhnc13a(10), rhnc13tu(10), rhnc13td(10)	
      Real rhnc14(10), rhnc14a(10), rhnc14tu(10), rhnc14td(10)	

      Real rhnc21(10), rhnc21a(10), rhnc21tu(10), rhnc21td(10)
      Real rhnc22(10), rhnc22a(10), rhnc22tu(10), rhnc22td(10)	
      Real rhnc23(10), rhnc23a(10), rhnc23tu(10), rhnc23td(10)	
      Real rhnc24(10), rhnc24a(10), rhnc24tu(10), rhnc24td(10)	

      Real eta3bins(5), eta3(4)
      Real psta3(4), psta3a(4), psta3tu(4), psta3td(4)
      Real et3bins(5), et3(4)
      Real pset3(4), pset3a(4), pset3tu(4), pset3td(4)

      Real rhcc41(10), rhcc41a(10), rhcc41tu(10), rhcc41td(10)
      Real rhcc42(10), rhcc42a(10), rhcc42tu(10), rhcc42td(10)	
      Real rhcc43(10), rhcc43a(10), rhcc43tu(10), rhcc43td(10)	
      Real rhcc44(10), rhcc44a(10), rhcc44tu(10), rhcc44td(10)	

      Real eta5bins(5), eta5(4)
      Real psta5(4), psta5a(4), psta5tu(4), psta5td(4)
      Real et5bins(5), et5(4)
      Real pset5(4), pset5a(4), pset5tu(4), pset5td(4)

      Real rhrt61(10), rhrt61a(10), rhrt61tu(10), rhrt61td(10)
      Real rhrt62(10), rhrt62a(10), rhrt62tu(10), rhrt62td(10)	
      Real rhrt63(10), rhrt63a(10), rhrt63tu(10), rhrt63td(10)	
      Real rhrt64(10), rhrt64a(10), rhrt64tu(10), rhrt64td(10)	

      Real psnc7(10), psnc7a(10), psnc7tu(10), psnc7td(10)
      Real psnc9(10), psnc9a(10), psnc9tu(10), psnc9td(10)
      Real pscc9(10), pscc9a(10), pscc9tu(10), pscc9td(10)

* save contents
      Save eta3bins, eta3, et3bins, et3
      Save eta5bins, eta5, et5bins, et5


****************************************************************
*        ZEUS DATA
****************************************************************

c *** note: variable names for ZEUS histos:
c     4 alphanum. digits for histo type,
c     1 digit for figure no. in the paper,
c    (1 digit for histo no. in figure,)
c     suffix: no suffix -> ordinate value
c             a         -> statistic. error
c             tu        -> total error up
c             td        -> total error down


c *** FIG. 1: NC - DIFFERENTIAL JET SHAPES (et > 14 GeV, Q2>100 GeV2)
c *** (11:) -1<eta<0, (12:) 0<eta<1, (13:) 1<eta<1.5, (14:) 1.5<eta<2
*
      Data rhnc11   / 3.923, 2.623, 1.269, 0.768, 0.481,
     .                0.322, 0.275, 0.203, 0.157, 0.119 /
      Data rhnc11a  / 0.111, 0.055, 0.031, 0.024, 0.019,
     .                0.014, 0.013, 0.010, 0.009, 0.007 /
      Data rhnc11tu / 0.208, 0.056, 0.046, 0.048, 0.024,
     .                0.025, 0.017, 0.013, 0.011, 0.009 /
      Data rhnc11td / 0.208, 0.092, 0.032, 0.028, 0.020,
     .                0.018, 0.023, 0.011, 0.010, 0.008 /

      Data rhnc12   / 4.033, 2.625, 1.244, 0.704, 0.452,
     .                0.338, 0.254, 0.195, 0.156, 0.120 /
      Data rhnc12a  / 0.065, 0.032, 0.018, 0.013, 0.010,
     .                0.009, 0.007, 0.006, 0.004, 0.004 /
      Data rhnc12tu / 0.106, 0.035, 0.024, 0.038, 0.022,
     .                0.017, 0.012, 0.010, 0.007, 0.007 /
      Data rhnc12td / 0.150, 0.035, 0.020, 0.016, 0.013,
     .                0.016, 0.009, 0.006, 0.006, 0.005 /

      Data rhnc13   / 3.861, 2.552, 1.280, 0.743, 0.488,
     .                0.316, 0.238, 0.179, 0.153, 0.133 /
      Data rhnc13a  / 0.085, 0.037, 0.022, 0.017, 0.013,
     .                0.010, 0.008, 0.006, 0.005, 0.005 /
      Data rhnc13tu / 0.138, 0.061, 0.028, 0.030, 0.018,
     .                0.015, 0.017, 0.014, 0.006, 0.006 /
      Data rhnc13td / 0.124, 0.045, 0.027, 0.021, 0.015,
     .                0.012, 0.009, 0.007, 0.006, 0.009 /

      Data rhnc14   / 3.828, 2.533, 1.270, 0.688, 0.477,
     .                0.317, 0.257, 0.198, 0.156, 0.124 /
      Data rhnc14a  / 0.081, 0.038, 0.018, 0.013, 0.010,
     .                0.008, 0.007, 0.006, 0.005, 0.004 /
      Data rhnc14tu / 0.120, 0.074, 0.048, 0.045, 0.030,
     .                0.023, 0.017, 0.007, 0.012, 0.005 /
      Data rhnc14td / 0.104, 0.045, 0.022, 0.015, 0.012,
     .                0.011, 0.008, 0.007, 0.006, 0.006 /

c *** FIG. 2: NC - DIFFERENTIAL JET SHAPES (-1<eta<2, Q2>100 GeV2)
c *** (21:) 14<et<21, (22:) 21<et<29, (23:) 29<et<37, (24:) 37<et<45
*
      Data rhnc21   / 3.629, 2.667, 1.352, 0.772, 0.511,
     .                0.354, 0.281, 0.211, 0.170, 0.135 /
      Data rhnc21a  / 0.047, 0.024, 0.013, 0.010, 0.008,
     .                0.006, 0.005, 0.004, 0.003, 0.003 /
      Data rhnc21tu / 0.135, 0.027, 0.020, 0.033, 0.015,
     .                0.017, 0.012, 0.008, 0.007, 0.005 /
      Data rhnc21td / 0.134, 0.049, 0.017, 0.014, 0.011,
     .                0.013, 0.008, 0.005, 0.005, 0.005 /

      Data rhnc22   / 4.479, 2.528, 1.089, 0.620, 0.394,
     .                0.268, 0.206, 0.161, 0.128, 0.104 /
      Data rhnc22a  / 0.097, 0.041, 0.021, 0.016, 0.013,
     .                0.010, 0.008, 0.007, 0.006, 0.005 /
      Data rhnc22tu / 0.116, 0.107, 0.057, 0.038, 0.036,
     .                0.014, 0.011, 0.009, 0.007, 0.006 /
      Data rhnc22td / 0.142, 0.046, 0.030, 0.023, 0.015,
     .                0.010, 0.009, 0.008, 0.006, 0.008 /

      Data rhnc23   / 4.849, 2.209, 1.031, 0.545, 0.353,
     .                0.279, 0.178, 0.150, 0.128, 0.095 /
      Data rhnc23a  / 0.162, 0.065, 0.034, 0.025, 0.024,
     .                0.018, 0.012, 0.010, 0.010, 0.007 /
      Data rhnc23tu / 0.216, 0.153, 0.037, 0.056, 0.040,
     .                0.019, 0.014, 0.012, 0.013, 0.010 /
      Data rhnc23td / 0.228, 0.068, 0.034, 0.029, 0.025,
     .                0.045, 0.013, 0.011, 0.022, 0.007 /

      Data rhnc24   / 5.526, 1.932, 0.915, 0.473, 0.284,
     .                0.183, 0.125, 0.100, 0.072, 0.088 /
      Data rhnc24a  / 0.337, 0.097, 0.061, 0.038, 0.031,
     .                0.024, 0.015, 0.011, 0.009, 0.015 /
      Data rhnc24tu / 0.337, 0.243, 0.213, 0.095, 0.061,
     .                0.039, 0.036, 0.029, 0.024, 0.015 /
      Data rhnc24td / 0.600, 0.098, 0.062, 0.038, 0.031,
     .                0.024, 0.019, 0.011, 0.009, 0.020 /

c *** FIG. 3: NC - INTEGRATED JET SHAPES at r/R=0.5 (Q2>100 GeV2)
*
c *** (31:) as a function of eta (ET > 14 GeV)
      Data eta3bins / -1.0, 0.0, 1.0, 1.5, 2.0 /
      Data eta3     / -0.50, 0.50, 1.25, 1.75 /
      Data psta3    / 0.894, 0.895, 0.900, 0.894 /
      Data psta3a   / 0.004, 0.002, 0.004, 0.003 /
      Data psta3tu  / 0.006, 0.004, 0.005, 0.005 /
      Data psta3td  / 0.008, 0.005, 0.005, 0.005 /

c *** (32:) as a function of ET
      Data et3bins  / 14.0, 21.0, 29.0, 37.0, 45.0 /
      Data et3      / 16.7, 24.2, 32.2, 40.4 /
      Data pset3    / 0.886, 0.915, 0.915, 0.944 /
      Data pset3a   / 0.002, 0.003, 0.005, 0.007 /
      Data pset3tu  / 0.004, 0.005, 0.012, 0.008 /
      Data pset3td  / 0.005, 0.005, 0.006, 0.010 /

c *** FIG. 4: CC -  DIFFERENTIAL JET SHAPES (-1<eta<2, Q2>100 GeV2)
c *** (41:) 14<et<21, (42:) 21<et<29, (43:) 29<et<37, (44:) 37<et<45
*
      Data rhcc41   / 3.733, 2.819, 1.190, 0.718, 0.524,
     .                0.402, 0.231, 0.178, 0.189, 0.093 /
      Data rhcc41a  / 0.369, 0.214, 0.094, 0.085, 0.063,
     .                0.062, 0.043, 0.035, 0.031, 0.026 /
      Data rhcc41tu / 0.374, 0.215, 0.119, 0.086, 0.064,
     .                0.063, 0.047, 0.035, 0.032, 0.026 /
      Data rhcc41td / 0.386, 0.215, 0.094, 0.085, 0.064,
     .                0.062, 0.044, 0.036, 0.032, 0.026 /

      Data rhcc42   / 4.344, 2.856, 0.907, 0.537, 0.352,
     .                0.271, 0.208, 0.146, 0.171, 0.087 /
      Data rhcc42a  / 0.451, 0.208, 0.106, 0.062, 0.059,
     .                0.046, 0.045, 0.024, 0.032, 0.022 /
      Data rhcc42tu / 0.457, 0.234, 0.112, 0.073, 0.077,
     .                0.047, 0.046, 0.024, 0.033, 0.023 /
      Data rhcc42td / 0.482, 0.208, 0.106, 0.063, 0.060,
     .                0.046, 0.046, 0.026, 0.032, 0.022 /

      Data rhcc43   / 4.255, 2.198, 0.980, 0.588, 0.381,
     .                0.295, 0.210, 0.179, 0.113, 0.090 /
      Data rhcc43a  / 0.530, 0.193, 0.103, 0.061, 0.051,
     .                0.048, 0.041, 0.056, 0.019, 0.019 /
      Data rhcc43tu / 0.618, 0.206, 0.130, 0.065, 0.055,
     .                0.056, 0.042, 0.056, 0.019, 0.019 /
      Data rhcc43td / 0.540, 0.195, 0.104, 0.066, 0.052,
     .                0.048, 0.052, 0.083, 0.022, 0.022 /

      Data rhcc44   / 6.057, 1.959, 0.723, 0.401, 0.239,
     .                0.218, 0.159, 0.126, 0.041, 0.050 /
      Data rhcc44a  / 0.596, 0.208, 0.080, 0.056, 0.051,
     .                0.058, 0.049, 0.055, 0.010, 0.011 /
      Data rhcc44tu / 0.616, 0.210, 0.085, 0.130, 0.114,
     .                0.089, 0.059, 0.116, 0.032, 0.023 /
      Data rhcc44td / 0.801, 0.250, 0.080, 0.057, 0.051,
     .                0.058, 0.050, 0.055, 0.011, 0.011 /


c *** FIG. 5: CC - INTEGRATED JET SHAPES at r/R=0.5 (Q2>100 GeV2)
*
c *** (51:) as a function of eta (ET > 14 GeV)
      Data eta5bins / -1.0, 0.0, 1.0, 1.5, 2.0 /
      Data eta5     / -0.50, 0.50, 1.25, 1.75 /
      Data psta5    / 0.916, 0.918, 0.900, 0.889 /
      Data psta5a   / 0.013, 0.011, 0.021, 0.028 /
      Data psta5tu  / 0.013, 0.011, 0.021, 0.028 /
      Data psta5td  / 0.014, 0.011, 0.021, 0.028 /

c *** (52:) as a function of ET
      Data et5bins  / 14.0, 21.0, 29.0, 37.0, 45.0 /
      Data et5      / 17.4, 24.7, 32.7, 40.7 /
      Data pset5    / 0.891, 0.910, 0.904, 0.940 /
      Data pset5a   / 0.018, 0.015, 0.019, 0.022 /
      Data pset5tu  / 0.019, 0.016, 0.026, 0.022 /
      Data pset5td  / 0.019, 0.016, 0.019, 0.037 /

c *** FIG. 6: RATIO OF CC TO NC DIFFERENTIAL JET SHAPES
c *** (61:) 14<Et<21, (62:) 21<Et<29, (63:) 29<Et<37, (64:) 37<Et<45
*
      Data rhrt61   / 1.029, 1.057, 0.880, 0.930, 1.025,
     .                1.136, 0.820, 0.844, 1.109, 0.689 /
      Data rhrt61a  / 0.105, 0.083, 0.073, 0.113, 0.128,
     .                0.179, 0.159, 0.169, 0.192, 0.194 /
      Data rhrt61tu / 0.105, 0.085, 0.090, 0.113, 0.128,
     .                0.181, 0.167, 0.169, 0.193, 0.196 /
      Data rhrt61td / 0.110, 0.083, 0.073, 0.114, 0.132,
     .                0.180, 0.159, 0.181, 0.196, 0.194 /

      Data rhrt62   / 0.970, 1.130, 0.833, 0.866, 0.893,
     .                1.009, 1.011, 0.908, 1.334, 0.834 /
      Data rhrt62a  / 0.106, 0.089, 0.102, 0.107, 0.158,
     .                0.183, 0.231, 0.162, 0.268, 0.224 /
      Data rhrt62tu / 0.106, 0.089, 0.102, 0.108, 0.164,
     .                0.183, 0.232, 0.162, 0.269, 0.240 /
      Data rhrt62td / 0.108, 0.089, 0.102, 0.107, 0.158,
     .                0.183, 0.232, 0.169, 0.269, 0.224 /

      Data rhrt63   / 0.878, 0.995, 0.951, 1.080, 1.080,
     .                1.054, 1.177, 1.197, 0.878, 0.947 /
      Data rhrt63a  / 0.117, 0.100, 0.116, 0.141, 0.183,
     .                0.205, 0.269, 0.400, 0.187, 0.234 /
      Data rhrt63tu / 0.126, 0.100, 0.134, 0.143, 0.183,
     .                0.351, 0.270, 0.401, 0.198, 0.234 /
      Data rhrt63td / 0.117, 0.104, 0.117, 0.188, 0.187,
     .                0.205, 0.314, 0.569, 0.188, 0.276 /

      Data rhrt64   / 1.096, 1.014, 0.790, 0.847, 0.843,
     .                1.187, 1.269, 1.261, 0.567, 0.568 /
      Data rhrt64a  / 0.137, 0.134, 0.121, 0.165, 0.225,
     .                0.406, 0.466, 0.621, 0.182, 0.181 /
      Data rhrt64tu / 0.142, 0.134, 0.121, 0.182, 0.285,
     .                0.432, 0.474, 0.823, 0.269, 0.414 /
      Data rhrt64td / 0.137, 0.216, 0.171, 0.167, 0.227,
     .                0.406, 0.470, 0.621, 0.186, 0.182 /

c *** FIG. 7: NC - INTEGRATED JET SHAPE
c *** (Q2>100 GeV2, Et>14 GeV, -1<eta<2)
*
      Data psnc7    / 0.0000, 0.6520, 0.7780, 0.8490, 0.8960,
     .                0.9280, 0.9530, 0.9720, 0.9880, 1.0000 /
      Data psnc7a   / 0.0000, 0.0035, 0.0027, 0.0021, 0.0016,
     .                0.0012, 0.0008, 0.0005, 0.0003, 0.0000 /
      Data psnc7tu  / 0.0000, 0.0092, 0.0066, 0.0047, 0.0036,
     .                0.0022, 0.0015, 0.0010, 0.0005, 0.0000 /
      Data psnc7td  / 0.0000, 0.0085, 0.0062, 0.0041, 0.0029,
     .                0.0020, 0.0013, 0.0008, 0.0004, 0.0000 /

c *** FIG. 9: INTEGRATED JET SHAPES IN NC AND CC DIS
c *** (Q2 > 100 GeV2, 37<Et<45 GeV)
*
c *** NEUTRAL CURRENT
      Data psnc9    / 0.553, 0.759, 0.864, 0.916, 0.944,
     .                0.961, 0.974, 0.984, 0.991, 1.000 /
      Data psnc9a   / 0.034, 0.022, 0.015, 0.011, 0.007,
     .                0.005, 0.004, 0.003, 0.002, 0.000 /
      Data psnc9tu  / 0.034, 0.023, 0.015, 0.011, 0.008,
     .                0.005, 0.004, 0.003, 0.003, 0.000 /
      Data psnc9td  / 0.060, 0.034, 0.020, 0.015, 0.010,
     .                0.007, 0.004, 0.003, 0.002, 0.000 /

c *** CHARGED CURRENT
      Data pscc9    / 0.606, 0.808, 0.878, 0.917, 0.940,
     .                0.963, 0.980, 0.993, 0.995, 1.000 /
      Data pscc9a   / 0.060, 0.041, 0.031, 0.027, 0.022,
     .                0.015, 0.009, 0.002, 0.001, 0.000 /
      Data pscc9tu  / 0.062, 0.041, 0.031, 0.027, 0.022,
     .                0.015, 0.009, 0.002, 0.001, 0.000 /
      Data pscc9td  / 0.080, 0.072, 0.064, 0.050, 0.037,
     .                0.028, 0.022, 0.007, 0.003, 0.000 /


****************************************************************
*     DECLARATIONS for MC histos
****************************************************************

* argument
      Integer imode

* function declaration
      Integer getBinNo

* other variables
      Logical levtype, lNC, lCC, lfirst, linit
      Parameter(lNC=.true., lCC=.false.)
      Integer iflag, iHistId, ierr, ievtp, ibin, ivartp
      Integer ilepton, idum, ijetfid, ijt, ieta, iEt, ihad, ir
      Character*6 cxxxx
      Character*80 chtitl
      Double Precision drrho(10), drpsi(10)
      Double Precision dQ2, dy
      Double Precision deta, dEt, dpt, dconeR, dEtJet, detaJet
      Double Precision ddumA(MAXHZJETS,8)
      Double Precision djshpRho(10,MAXHZJETS)
      Double Precision djshpPsi(10,MAXHZJETS)

* save contents
      Save lfirst, linit, cxxxx, drrho, drpsi

* settings
      Data lfirst /.true./
      Data linit /.false./
      Data cxxxx /'98038'/

c *** values of r/R for rho (histo filling)
      Data drrho / 0.05D0, 0.15D0, 0.25D0, 0.35D0, 0.45D0,
     .             0.55D0, 0.65D0, 0.75D0, 0.85D0, 0.95D0 /

c *** values of r/R for psi (histo filling)
      Data drpsi / 0.10D0, 0.20D0, 0.30D0, 0.40D0, 0.50D0,
     .             0.60D0, 0.70D0, 0.80D0, 0.90D0, 1.00D0 /



*********************************************************************
*     GET MODE
*********************************************************************

*     get iflag: init=1, evt.process.=2, final=3
      iflag = mod(imode,1000)

      if (iflag.eq.2) then
*     get event type: NC or CC
       ievtp = int(imode/1000)
       if (ievtp.eq.1) then
	 levtype = lNC
       elseif (ievtp.eq.2) then
	 write(6,*)'Hz'//cxxxx,
     .   ' sorry, CC event processing not implemented yet !!!'
	 levtype = lCC
	 return
       else
	 ievtp = 2
	 levtype = lNC
	 if (lfirst) then
	  write(6,*)'Hz'//cxxxx,' WARNING: bad routine call !!!'
	  write(6,*)'Please use argument 1002 for NC event processing'
	  write(6,*)'                 or 2002 for CC event processing.'
	  write(6,*)'Currently assuming NC event processing !'
	  lfirst = .false.
	 endif
       endif
      endif


      if (iflag.eq.1) then
*********************************************************************
*
*                      Initialization
*
*********************************************************************

* check if routine is initialized
         if (linit) then
	  write(6,*)'Hz'//cxxxx,'ERROR: '//
     .      'initialization step should be called only once.'
          goto 9999
         endif

*
*
*      Initialisation: The following MUST always be done
*      (i) make subdirectory in PAWC
*       - use the name as the xxxxxx in HZxxxxxx subroutine
*      (ii) make subdirectory in o/p file
*

         call hcdir('//PAWC',' ')
         call hmdir(cxxxx,'S')
         call hcdir('//HISTO',' ')
         call hmdir(cxxxx,'S')

c --- hello world !

	 WRITE(6,*)'***************************************************'
	 WRITE(6,*)'Hz'//cxxxx//' called'
     	 WRITE(6,*)'***************************************************'

c --- build up ZEUS histos and prepare MC histos
	
	 write(chtitl,*) 'rho(r/R) (NC, -1.lt.eta.lt.0)'
	 call ZSrho(11,chtitl,rhnc11,rhnc11a,rhnc11tu,rhnc11td)
	 call MCrho(11,chtitl)
	 write(chtitl,*) 'rho(r/R) (NC, 0.lt.eta.lt.1)'
	 call ZSrho(12,chtitl,rhnc12,rhnc12a,rhnc12tu,rhnc12td)
	 call MCrho(12,chtitl)
	 write(chtitl,*) 'rho(r/R) (NC, 1.lt.eta.lt.1.5)'
	 call ZSrho(13,chtitl,rhnc13,rhnc13a,rhnc13tu,rhnc13td)
	 call MCrho(13,chtitl)
	 write(chtitl,*) 'rho(r/R) (NC, 1.5.lt.eta.lt.2)'
	 call ZSrho(14,chtitl,rhnc14,rhnc14a,rhnc14tu,rhnc14td)
	 call MCrho(14,chtitl)

	 write(chtitl,*) 'rho(r/R) (NC, 14.lt.Et.lt.21)'
	 call ZSrho(21,chtitl,rhnc21,rhnc21a,rhnc21tu,rhnc21td)
	 call MCrho(21,chtitl)
	 write(chtitl,*) 'rho(r/R) (NC, 21.lt.Et.lt.29)'
	 call ZSrho(22,chtitl,rhnc22,rhnc22a,rhnc22tu,rhnc22td)
	 call MCrho(22,chtitl)
	 write(chtitl,*) 'rho(r/R) (NC, 29.lt.Et.lt.37)'
	 call ZSrho(23,chtitl,rhnc23,rhnc23a,rhnc23tu,rhnc23td)
	 call MCrho(23,chtitl)
	 write(chtitl,*) 'rho(r/R) (NC, 37.lt.Et.lt.45)'
	 call ZSrho(24,chtitl,rhnc24,rhnc24a,rhnc24tu,rhnc24td)
	 call MCrho(24,chtitl)

	 write(chtitl,*) 'Psi(0.5) vs. eta (NC, Et.gt.14)'
	 call ZSpsifxd(31,chtitl,4,eta3bins,
     .                 psta3,psta3a,psta3tu,psta3td)
	 call MCpsifxd(31,chtitl,4,eta3bins)
	 write(chtitl,*) 'Psi(0.5) vs. Et (NC)'
	 call ZSpsifxd(32,chtitl,4,et3bins,
     .                 pset3,pset3a,pset3tu,pset3td)
	 call MCpsifxd(32,chtitl,4,et3bins)

	 write(chtitl,*) 'rho(r/R) (CC, 14.lt.Et.lt.21)'
	 call ZSrho(41,chtitl,rhcc41,rhcc41a,rhcc41tu,rhcc41td)
	 call MCrho(41,chtitl)
	 write(chtitl,*) 'rho(r/R) (CC, 21.lt.Et.lt.29)'
	 call ZSrho(42,chtitl,rhcc42,rhcc42a,rhcc42tu,rhcc42td)
	 call MCrho(42,chtitl)
	 write(chtitl,*) 'rho(r/R) (CC, 29.lt.Et.lt.37)'
	 call ZSrho(43,chtitl,rhcc43,rhcc43a,rhcc43tu,rhcc43td)
	 call MCrho(43,chtitl)
	 write(chtitl,*) 'rho(r/R) (CC, 37.lt.Et.lt.45)'
	 call ZSrho(44,chtitl,rhcc44,rhcc44a,rhcc44tu,rhcc44td)
	 call MCrho(44,chtitl)

	 write(chtitl,*) 'Psi(0.5) vs. eta (CC, Et.gt.14)'
	 call ZSpsifxd(51,chtitl,4,eta5bins,
     .                 psta5,psta5a,psta5tu,psta5td)
	 call MCpsifxd(51,chtitl,4,eta5bins)
	 write(chtitl,*) 'Psi(0.5) vs. Et (CC)'
	 call ZSpsifxd(52,chtitl,4,et5bins,
     .                 pset5,pset5a,pset5tu,pset5td)
	 call MCpsifxd(52,chtitl,4,et5bins)

	 write(chtitl,*) 'ratio rho(CC)/rho(NC) (r/R) (14.lt.Et.lt.21)'
	 call ZSrho(61,chtitl,rhrt61,rhrt61a,rhrt61tu,rhrt61td)
	 write(chtitl,*) 'ratio rho(CC)/rho(NC) (r/R) (21.lt.Et.lt.29)'
	 call ZSrho(62,chtitl,rhrt62,rhrt62a,rhrt62tu,rhrt62td)
	 write(chtitl,*) 'ratio rho(CC)/rho(NC) (r/R) (29.lt.Et.lt.37)'
	 call ZSrho(63,chtitl,rhrt63,rhrt63a,rhrt63tu,rhrt63td)
	 write(chtitl,*) 'ratio rho(CC)/rho(NC) (r/R) (37.lt.Et.lt.45)'
	 call ZSrho(64,chtitl,rhrt64,rhrt64a,rhrt64tu,rhrt64td)

	 write(chtitl,*) 'Psi(r/R) (NC, Et.gt.14)'
	 call ZSpsi(71,chtitl,psnc7,psnc7a,psnc7tu,psnc7td)
	 call MCpsi(71,chtitl)

	 write(chtitl,*) 'Psi(r/R) (NC, 37.lt.Et.lt.45)'
	 call ZSpsi(91,chtitl,psnc9,psnc9a,psnc9tu,psnc9td)
	 call MCpsi(91,chtitl)

	 write(chtitl,*) 'Psi(r/R) (CC, 37.lt.Et.lt.45)'
	 call ZSpsi(92,chtitl,pscc9,pscc9a,pscc9tu,pscc9td)
	 call MCpsi(92,chtitl)

* prepare control histo
         write(chtitl,*) 'dn/dQ2 in lab. fr. - control plot'
         call hbook1(1, chtitl, 100, 0., 10000., 0.)

* set flag
         linit = .true.


      else if (iflag.eq.2) then
*********************************************************************
*
*                      Event Processing
*
*********************************************************************

* check if routine is initialized
         if (.not.linit) then
	  write(6,*)'Hz'//cxxxx,'ERROR: '//
     .      'event processing step called without initialization !!!'
	  write(6,*)'Please use argument 1 for initialization step.'
          goto 9999
         endif


*      Filling: The following MUST always be done
*      (i) move to the correct sub-directory in PAWC
*
         call hcdir('//PAWC/'//cxxxx,' ')

****************************************************
* Part A: KINEMATIC CUTS
****************************************************

* get Q2
         dQ2 = HzDiskin(1)
         if (dQ2.le.0.D0) then
            write(6,*) 'HZ'//cxxxx,' unphysical Q2 !'
            goto 9990
         endif

*     fill control histo: Q2 distribution
         call hfill(1, real(dQ2), 0., 1.)

* CUT (i): Q2 > 100 GeV
*---------
         if (dQ2.le.100.D0) goto 9990

* different cuts for NC and CC
	 if (levtype.eqv.lNC) then
c-------------------------------------------------------NC

* detect scattered lepton
	    ilepton = HzIdelec(idum)
	    if (ilepton.eq.-1) then
	       write(6,*) 'Hz'//cxxxx,' lepton not found !'
	       goto 9990
	    endif

* CUT (NCii): energy of scattered lepton > 10 GeV
*------------
	    if (PHEP(4,ilepton).le.10.D0) goto 9990

* get y
	    dy = HzDiskin(3)

* CUT (NCiii):  y < 0.95
*-------------
	    if (dy.ge.0.95D0) goto 9990

* get pseudo-rapidity eta and Et of scattered lepton
         deta = HzEta(ilepton)
         dEt = HzEta(ilepton)

* CUT (NCiv):  for eta(lepton) > 2: Et of scattered lepton > 20 GeV
*------------
	    if ((deta.gt.2.D0).and.(dEt.le.20.D0)) goto 9990
	    	
	 else
c-------------------------------------------------------CC

* detect neutrino
	    ilepton = HzIdntro(idum)
	    if (ilepton.eq.-1) then
	       write(6,*) 'Hz'//cxxxx,' neutrino not found !'
	       goto 9990
	    endif

* get pt of neutrino
	    dpt=hzPt(ilepton)

* CUT (CCii):  pt of neutrino > 11 GeV
*------------
	    if (dpt.le.11.D0) goto 9990
	
	 endif


****************************************************
* Part B: JET FINDING
****************************************************

* choose PXCONE with cone radius = 1.0
	 ijetfid = 2
	 dconeR = 1.D0

* jet finding
	 NUMJETS = 0
	 call hzjtfind(ijetfid,dconeR,idum,ddumA)
	 if (NUMJETS.gt.MAXHZJETS) then
	    write(6,*)
     .	    'HZ'//cxxxx, ' ERROR: number of jets out of range !'
            goto 9990
	 endif

* anything to do ?
	 if (NUMJETS.lt.1) goto 9990

****************************************************
* Part C: CALCULATION OF JET SHAPES
****************************************************

	 call hzjetshp(1, dconeR, djshpRho, djshpPsi, ierr)
	 if (ierr.ne.0) then
	    write(6,*) 'HZ'//cxxxx, ' error in HzJetshp !'
	    goto 9990
	 endif

****************************************************
* Part D: BINNING AND HISTO FILLING
****************************************************
	 numjets=1
* loop over all jets found	
	 do 6500 ijt = 1, NUMJETS

*       get kinematic variables of current jet
	    dEtJet  = JETS(ijt,3)
	    detaJet = JETS(ijt,1)

* BINNING:
*---------
*       get Et and eta bin number (same for NC and CC)
	    iEt  = getBinNo(4,Et3bins,real(dEtJet))
	    ieta = getBinNo(4,eta3bins,real(detaJet))

* CUT (Ji): Et(jet) > 14 GeV
*----------
	    if (iEt.lt.1) goto 6500

* CUT (Jii): -1 < eta(jet) < 2
*-----------
	    if ((ieta.lt.1).or.(ieta.gt.4)) goto 6500

	    do ir = 1, 10	! loop over r/R bins

*       fill histos for integrated jet shape psi
	       if (levtype.eqv.lNC) then        ! ---NC
		  call HzMeanHi(71,drpsi(ir),djshpPsi(ir,ijt),wtx)
		  if (iEt.eq.4) then
		     call HzMeanHi(91,drpsi(ir),djshpPsi(ir,ijt),wtx)
		  endif
	       else		                ! ---CC
		  call HzMeanHi(72,drpsi(ir),djshpPsi(ir,ijt),wtx)
		  if (iEt.eq.4) then
		     call HzMeanHi(92,drpsi(ir),djshpPsi(ir,ijt),wtx)
		  endif
	       endif		! NC or CC ?

*       fill histos for differential jet shape rho
	       if (levtype.eqv.lNC) then        ! ---NC
		  call HzMeanHi(10+ieta,drrho(ir),djshpRho(ir,ijt),wtx)
		  if (iEt.ne.5) then
		    call HzMeanHi(20+iEt,drrho(ir),djshpRho(ir,ijt),wtx)
		  endif
	       else	                  	! ---CC
		  if (iEt.ne.5) then
		    call HzMeanHi(40+iEt,drrho(ir),djshpRho(ir,ijt),wtx)
		  endif
	       endif ! NC or CC ?
	    enddo ! next r/R bin

*       fill histos for jet shape psi at fixed value (psi(0.5))
	    if (levtype.eqv.lNC) then
	       call hzMeanHi(31, detaJet, djshpPsi(5,ijt), wtx)
	       call hzMeanHi(32, dEtJet, djshpPsi(5,ijt), wtx)
	    else
	       call hzMeanHi(51, detaJet, djshpPsi(5,ijt), wtx)
	       call hzMeanHi(52, dEtJet, djshpPsi(5,ijt), wtx)
	    endif

 6500	 continue ! next jet

 9990    continue


      else if(iflag.eq.3) then
*********************************************************************
*
*                      Termination
*
*********************************************************************

*      Termination: The following MUST always be done
*      (i) Move to the correct PAW subdirectory
*
         call hcdir('//PAWC/'//cxxxx,' ')

*     note: simple chi-square calculation doesn't make sense due
*           to correlations
	

      endif

 9999 continue
      RETURN
      END
