      subroutine HZH0302034(IFLAG)
*
****************************************************************************
* Purpose: produce histograms for the following distributions:
*
*      IDs 101-103
*              - Et in six bins of W_gamma-proton
*                (95-212-285 and 95-285 GeV): 21/28/35/42/52/62/75 GeV
*                three regions of W(y/p)
*
*      IDs 201-202
*              - Et for W_gamma-proton between 164 and 242 GeV in five bins
*                for Q2 <= 0.01 GeV2 (5/8/12/16/21/28) 
*                AND in six bins for Q2 <= 1 GeV2 (21/28/35/42/52/62/75) 
*                one region for W, two for Q2
*
*     IDs 301-304
*              - dsigma/deta_jet fr 95<W<285 in 6 bins (-1/0/0.5/1/1.5/2/2.5) 
*                two regions of Et jet (21<Et<75 and 21<Et<35)
*                AND in 5 bins (0/0.5/1/1.5/2/2.5) for <35Et<52
*                AND in 4 bins (0.5/1/1.5/2/2.5) for 52<Et75 GeV
*
*     ID 401-407
*             - CLOSER LOOK at W(gamma/p) and Et jet Distributions
*               dsigma/deta_jet for 21<Et jet<35 
*                  in 5 bins (0/0.5/1/1.5/2/2.5) for 95<W<212
*                  in 6 bins (-1/0/0.5/1/1.5/2/2.5) fr 212<W<285 (ID 401/402)
*
*               dsigma/deta_jet for 35<Et jet<52 
*                  in 4 bins (0.5/1/1.5/2/2.5) for 95<W<212
*                  in 5 bins (0/0.5/1/1.5/2/2.5) fr 212<W<285 (ID 403/404)
*
*               dsigma/deta_jet for 52<Et jet<75 
*                  in 4 bins (0.5/1/1.5/2/2.5) for 212<W<285 (ID 405)
*
*               dsigma/deta_jet for 5<Et jet<12 
*                  in 5 bins (-1/-0.5/0/0.5/1/1.5) for 164<W<242 (ID406)
*
*               dsigma/deta_jet for 12<Et jet<21 
*                   in 6 bins (-0.5/0/0.5/1/1.5/2/2.5) fr 164<W<242 (ID 407)
*
*     401 -   407  Eta distr. in eta bins (var. Et reg.) filled by this code
*    -401 -  -407  Eta distr. in eta bins (var. Et reg.) DATA stat. err. only
*   -1401 - -1407  Eta distr. in eta bins (var. Et reg.) DATA tot. err. only
*
*     ID 501-502
*           501 -   502  Et distr. in et bins (-1< integrated eta jet<2.5,
*                         164<Wgamma/p<242) filled by this code
*          -501 -  -502  Et distr. in et bins  (-1< integrated eta jet<2.5, 
*                         164<Wgamma/p<242) DATA stat. err. only
*         -1501 - -1502  Et distr. in et bins  (-1< integrated eta jet<2.5, 
*                         164<Wgamma/p<242) DATA tot. err. only
*
*     ID 601,602,603
*           601   Scaled gamma-p xsection at W_gp=200GeV as function of xT 
*              for |eta*| < 0.5 to  be filled by this code
*          -601   Scaled gamma-p xsection at W_gp=200GeV as function of xT 
*              for |eta*| < 0.5 to  be filled by this code DATA stat. err. only
*         -1601   Scaled gamma-p xsection at W_gp=200GeV as function of xT
*              for |eta*| < 0.5 to  be filled by this code DATA tot. err. 
*              where eta* is pseudorapidity in gamma-p CMS.
*
*              601 must be filled at W_gp = 200 GeV, i.e. in a perfect world
*              you have to run MC at fixed W, i.e. in a photon-proton mode.
*              However, HZDISKIN and other HZTool routines may not work
*              correctly in this mode. As a solution, one can run MC in the
*              ep mode and fill histo 601 in a narrow W range. The narrower the
*              region, the more precise the result but the more statistics is
*              required. The region can be set below by parameters Wmin, Wmax.
*              By default, the region is: 164 < W < 242 GeV.
*              The photon flux is recalculated for the given region, see:
*                  S. Ferron, Ph.D. thesis, sect. 1.2.3, eq. (1.45)
*                  http://www-h1.desy.de/psfiles/theses/h1th-295.ps
*              and R. Engel, Ph.D. thesis, Appendix D, eq. (D.12), (D.14)
*                  http://www-ik.fzk.de/~engel/source/th.ps.gz
*
*           603 is cross check of 601, but the flux is calculated differently.
*              In 601 an integrated value is used, while in 603 it is done
*              event-by-event.
*
*           602 is an alternative way of filling MC histo for Fig. 9,
*              which follows closely the H1 analysis procedure.
*              It is gamma-p cross section 1/2pi d^2sigma_gp/dE_Tdeta
*              for 1.5 < eta < 2.5  (in lab. frame). It is filled in normal
*              ep (variable W_gp) jobs. Later on, it must be multiplied by
*              correction factors A * <ET_jet>^3. The factors used in H1
*              analyses are saved in histos 9001 - 9007:
*
*      9001, 9011  A = correction factors calculated using PYTHIA
*      9002, 9012  A = correction factors calculated using HERWIG or PHOJET
*      9003, 9013  average transverse jet energy^3 <ET_jet> for PYTHIA
*      9004, 9014  same for HERWIG or PHOJET
*      9005, 9015  Factor H = 1 / (A * <ET_jet>^3) for PYTHIA
*      9006, 9016  same for HERWIG or PHOJET
*      9007, 9017  Average H over PYTHIA and HERWIG|PHOJET:
*                  (H (HERWIG|PHOJET) + H (PYTHIA)) / 2
*           In the published analysis this average was used. PHOJET was used
*           for the lower 3 xT bins and HERWIG for the upper 3 xT bins.
*           In both cases they were averaged with PYTHIA.
*
*           900x are filled in bins of Et, 901x in bins of xT, but have the
*           same contents for corresponding bins.
*           Thus, to compare published data with the results of running
*           at variable W, divide contents of 602 by those of 9007,
*           and put the results in bins of 601. Note, that the corr. factors
*           depend on the MC program with particular steering parameters,
*           and it may be incosistent to use them with a different MC.
*           Vice versa, multiply -601 by 9017 to get original H1 ep data
*           for 164<W_gammap<242, 1.5<eta<2.5 and Q2<0.01 for first 3 bins
*           and Q2<1 for last 3 bins. This you can compare with histo 602
*           for any MC. This is however a somewhat different distribution.
*           See example PAW macro k_hzh0302034.
*
* ERRORS: In the paper the systematic errors for the LAr energy
* scale were given separately. As it is almost symmetric, the higher 
* number was chosen as error and added quadratically to the stat. and syst.
* errors to get the total error.
*
*     ADDITIONAL HISTOGRAMS:
*     
*     As there were given additional correction factors 
*     in the paper DESY-02-225, these were also implemented in the routine.
*     
*     They are: 
*     
*     (1+Delta hadr.)= RATIO of 
*     MC with Parton Showers, Fragmentation, Underlying Event
*     MC with PS, but without Fragmentation, without Underlying Event
*
*     (1+Delta u.e.)= RATIO of 
*     MC with Parton Showers, Fragmentation, Underlying Event
*     MC with PS and with Fragmentation, without Underlying Event
*
*     (1+Delta frag.)= RATIO of 
*     MC with Parton Showers and with Fragmentation, without Underlying Event
*     MC with PS, but without Fragmentation, without Underlying Event
*
*     The actual correction factors for a specific MC generator the routine
*     has to be run twice (with different steering files) 
*     and the obtained histograms have to be divided afterwards. 
*      
*     To get some idea of the magnitude of these corrections and to have 
*     material for comparison, the allow the user to compare these ratios 
*     with some MC, there are the histograms ID 1011-4071, ID 1012-4072 and
*     ID 1013-4073 provided, that contain the correction factor for 
*     (1+delta hadr.),(1+delta u.e.) and (1+delta frag.) respectively. 
*
*          Event selection:  
*              - Q2 <= 1 GeV2 
*              - 95 < W_gamma-p < 285

*              - low Et jet: (5 < E < 21) --> scattered electron detected 
*                in Etag fiducial Vol. with 9.6 < Ee'< 19.3 GeV 
*                -1 < eta < 2.5, Q2 <= 0.01 GeV, 164 < W < 285
*
*              - high Et Jet: E > 21, Q2 <= 1 GeV, 95 < W < 285, same eta
*
*          Jet selection:
*              - incl. kT algorithm
*              - Cone algorithm with R = 1
*              - Separation parameter between jets in (eta/Phi)Space is D=1
*
*          Beams: 27.5 GeV positrons, 820 GeV protons   [1996/97 HERA running]
*
*          Reference:
*              - H1: DESY-02-225: Measurement of inclusive jet cross section 
*                                 in photoproduction at HERA
*
*          See also:
*              - subroutine HZ02079 (written by Hannes Jung)
*
*     Arguments: iflag=1000*[IPROC]+1 initialisation
*                iflag=1000*[IPROC]+2 filling
*                iflag=1000*[IPROC]+3 termination
*
* IPROC decides which process is being run
* See manual section "The analysis routines" for more details.
* NB If you do not implement all these options, change the comments to say so!
*
*     It is assumed you run either (a) with iproc = 0
*                               or (b) with iproc = 1, 2 in order.
*     This example has only 2 processes (iproc=1,2) but others may be added.
*
* Written by:  Kristin Lohwasser <lohwass@mail.desy.de>    04.08.2004
*              (summer student 2004 - supervisor: Victor Lendermann)
*
* Changed by:  Victor Lendermann <victor@mail.desy.de>     07.06.2005
* Reason:      histos 601-603 and 9001-9017 for Fig. 9
*
****************************************************************************
*
      IMPLICIT NONE
*
*****************************************
*     Sequences and HzTool functions
*****************************************
*
#include "hzfunc.inc"
#include "hzhbook.inc"
#include "hepevtp.inc"
#include "hzjetcmn.inc"
#include "heracmn.inc"
#include "hznlo.inc"
*
      Integer NLOJET
*
****************************************
*     User defined vars
****************************************
*
      Integer i, IFLAG, iproc
      Real Nevt
      Save Nevt
      Character*8 xxxx     ! hep-ex preprint number (formerly DESY number)
      Data xxxx /'h0302034'/
      real sigm
      Integer ij, nj, ihep
      Double precision pbeam(4), pgam(4), ph(5), pbr(5)
      Double precision PLAB(5,NMXHEP)
*
      Double precision pj(maxhzjets,8), pjlab(maxhzjets,8)
      Integer ierr
      Integer maxhi, maxjet, modjet, modje2
      Parameter (maxhi = 100, maxjet = 30, modjet = 3, modje2 = 4)
      Real lumnb, lumpb
      Real ptq, raplab
      Double precision rcone
      Parameter (rcone=1.d0)
*
      Real pi, rd
      Integer iel, idum, ipbeam, ilbeam
      Parameter (pi = 3.1415927, rd = 180./pi)
      Real x, y, q2, Wyp2, Wyp
      Real Ee, The, Phe, Ej, Thj, Phj, Ptj, eta, etaj, etastr, yboost
*
*     Stuff for Et jet in Et bins
*
      integer etjet, etj
      parameter (etjet = 6)
      parameter (etj = 5)
      real etjbin(etjet+1)
      data etjbin /21. , 28. , 35. , 42. , 52. , 62. , 75./
      real etbin(etj+1)
      data etbin /5. , 8. , 12. , 16. , 21. , 28./
*
*     Stuff for eta - etabins
*
      integer neta
      parameter (neta=6)
      real netab(neta+1)
      data netab /-1. , 0. , 0.5 , 1. , 1.5 , 2. , 2.5/
      real netan(neta+1)
c     to get rid of problems with normalization: shift the bins by +2
c     (bin width stays the same!)
      data netan /1. , 2. , 2.5 , 3. , 3.5 , 4. , 4.5/
*
      integer neta2
      parameter (neta2=5)
      real netab2(neta2+1)
      data netab2 /0. , 0.5 , 1. , 1.5 , 2. , 2.5/
      real netan2(neta2+1)
      data netan2 /2. , 2.5 , 3. , 3.5 , 4. , 4.5/
*
      integer neta3
      parameter (neta3=4)
      real netab3(neta3+1)
      data netab3 /0.5 , 1. , 1.5 , 2. , 2.5/
*
      integer neta4
      parameter (neta4=5)
      real netab4(neta4+1)
      data netab4 /-1. , -0.5 , 0. , 0.5 , 1. , 1.5/
      real netan4(neta4+1)
      data netan4 / 1. ,  1.5 , 2. , 2.5 , 3. , 3.5/
*
      integer neta5
      parameter (neta5=6)
      real netab5(neta5+1)
      data netab5 /-0.5 , 0. , 0.5 , 1. , 1.5 , 2. , 2.5/
      real netan5(neta5+1)
      data netan5 / 0.5 , 1. , 1.5 , 2. , 2.5 , 3. , 3.5/
*
*     Stuff for Et histograms 50x
*
      Integer net51
      Parameter (net51=4)
      Real netb51(net51+1)
      Data netb51 / 5. , 8. , 12. , 16. , 21./
*
      Integer net52
      Parameter (net52=6)
      Real netb52(net52+1)
      Data netb52 / 21. , 28. , 35. , 42. , 52. , 62. , 75./
*
*     For histogram 601 
*
      Integer net6
      Parameter (net6=6)
      Real netb6(net6+1)
      Data netb6 / 0.07 , 0.11 , 0.15 , 0.21 , 0.29 , 0.51 , 0.61 /
      Real etxbin(net6+1)
      Data etxbin /8. , 12. , 16. , 21. , 35. , 52. , 75./
*
*     selection limits
*
      Real Wyplow, Wyphigh
      Data Wyplow /95./, Wyphigh /285./
      Real q2low, q2high
      Data q2low /0.01/, q2high /1./
      Real etcut
      Data etcut /5./
      Real thetcut
      Data thetcut /156./
      Real raplow, raphigh
      Data raplow /-1./, raphigh /2.5/
*
*     selection flag
*
      Logical incljet

      save NLOJET

*     
****************************************************
*     Data points from plots
****************************************************
*     101 et backward data, stat. err. and syst. err.
      real e101(6),xse101(6),xte101(6),xLA101(6)
      data e101   / 65.4 , 14.  , 3.56 , 0.908 , 0.192 , 0.0483 /
      data xse101 /  0.6 ,  0.3 , 0.14 , 0.06  , 0.028 , 0.0121 /
      data xte101 /  1.6 ,  0.3 , 0.09 , 0.018 , 0.012 , 0.0018 /
      data xLA101 /  5.5 ,  1.4 , 0.39 , 0.107 , 0.023 , 0.0071 /
*
*     102 et central data, stat. err. and syst. err.
      real e102(6),xse102(6),xte102(6),xLA102(6)
      data e102   / 32.7 , 6.21 , 1.51 , 0.236 , 0.0360 , 0.00511 /
      data xse102 /  0.4 , 0.19 , 0.09 , 0.03  , 0.0115 , 0.00365 /
      data xte102 /  0.7 , 0.18 , 0.03 , 0.008 , 0.0009 , 0.00019 /
      data xLA102 /  3.  , 0.6  , 0.15 , 0.025 , 0.0052 , 0.00115 /
*
*     103 et central data, stat. err. and syst. err.
      real e103(6),xse103(6),xte103(6),xLA103(6)
      data e103   / 32.8 , 7.81 , 2.05 , 0.676 , 0.157 , 0.0434 /
      data xse103 /  0.4 , 0.21 , 0.11 , 0.053 , 0.026 , 0.0117 /
      data xte103 /  1.0 , 0.21 , 0.07 , 0.017 , 0.012 , 0.0018 /
      data xLA103 /  2.8 , 0.83 , 0.23 , 0.083 , 0.018 , 0.0061 /
*
*     201 et forward q2 <=0.01 data, stat. err. and syst. err.
      real e201(5),xse201(5),xte201(5),xLA201(5)
      data e201   / 24600. , 3070. , 505. , 126. , 28.3 /
      data xse201 /   200. ,   60. ,  26. ,  11. ,  6.1 /
      data xte201 /  1600. ,  230. ,  30. ,   6. ,  4.6 /
      data xLA201 /  3000. ,  520. ,  94. ,  27. , 10.1 /
*
*     202 et forward q2 <=1 data, stat. err. and syst. err.
      real e202(6),xse202(6),xte202(6),xLA202(6)
      data e202   / 30.1 , 6.74 , 1.66 , 0.417 , 0.0773 , 0.0132 /
      data xse202 /  0.4 , 0.19 , 0.10 , 0.041 , 0.0174 , 0.0059 /
      data xte202 /  0.8 , 0.18 , 0.04 , 0.013 , 0.0066 , 0.0014 /
      data xLA202 /  2.5 , 0.63 , 0.18 , 0.043 , 0.0119 , 0.0019 /
*
*     301 dsig/deta Et 21-75 data, stat. err. and sys. err.
      real e301(6),xse301(6),xte301(6),xLA301(6)
      data e301   / 37.8 , 173. , 257. , 253. , 237. , 186. /
      data xse301 /  1.2 ,   4. ,   5. ,   4. ,   4. ,   4. /
      data xte301 /  2.1 ,   4. ,   7. ,   6. ,   7. ,   4. /
      data xLA301 /  3.  ,  12. ,  23. ,  25. ,  22. ,  19. /
*
*     302 dsig/deta Et 21-35 data, stat. err. and sys. err.
      real e302(6),xse302(6),xte302(6),xLA302(6)
      data e302   / 37.6 , 166. , 241. , 233. , 220. , 174. /
      data xse302 /  1.1 ,   4. ,   4. ,   4. ,   4. ,   4. /
      data xte302 /  2.1 ,   4. ,   6. ,   6. ,   7. ,   4. /
      data xLA302 /  2.9 ,  11. ,  21. ,  23. ,  20. ,  18. /
*
*     303  dsig/deta Et 35-52 data, stat. err. and sys. err.
      real e303(5),xse303(5),xte303(5),xLA303(5)
      data e303   / 7.56 , 14.8 , 18.3 , 15.1 , 11.5 /
      data xse303 / 0.75 ,  1.1 ,  1.2 ,  1.1 ,  1.0 /
      data xte303 / 0.64 ,  0.4 ,  0.4 ,  0.3 ,  0.2 /
      data xLA303 / 1.08 ,  1.5 ,  1.8 ,  1.6 ,  1.5 /
*
*     304 dsig/deta Et 52-75 data, stat. err. and sys. err.
      real e304(4),xse304(4),xte304(4),xLA304(4)
      data e304   / 1.16 , 1.69 , 1.84 , 0.458 /
      data xse304 / 0.33 , 0.37 , 0.39 , 0.189 /
      data xte304 / 0.08 , 0.1  , 0.12 , 0.04  /
      data xLA304 / 0.11 , 0.23 , 0.25 , 0.077 /
*
*     401 dsig/deta Et 21-35 W 95-212 data, stat. err. and sys. err.
      real e401(5),xe401(5),xse401(5),xLA401(5)
      data e401   / 32.6 , 114. , 141. , 142. , 114. /
      data xe401  /  1.5 ,   3. ,   3. ,   3. ,   3. /
      data xse401 /  0.9 ,   4. ,   3. ,   5. ,   3. /
      data xLA401 /  3.2 ,  10. ,  12. ,  13. ,  14. /
*
*     402 dsig/deta Et 21-35 W 212-285 data, stat. err. and sys. err.
      real e402(6),xe402(6),xse402(6),xLA402(6)
      data e402   / 37.3 , 133. , 127. , 91.7 , 78.7 , 59.6 /
      data xe402  /  1.2 ,   3. ,   3. ,  2.6 ,  2.6 ,  2.3 /
      data xse402 /  1.9 ,   4. ,   6. ,  3.7 ,  2.2 ,  2.4 /
      data xLA402 /  3.1 ,   9. ,  12. , 11.6 ,  6.8 ,  7.4 /
*
*     403 dsig/deta Et 35-52 W 95-212 data, stat. err. and sys. err.
      real e403(4),xse403(4),xe403(4),xLA403(4)
      data e403   / 2.72 , 8.07 , 8.27 , 6.57 /
      data xse403 / 0.46 , 0.81 , 0.81 , 0.71 /
      data xe403  / 0.17 , 0.19 , 0.20 , 0.19 /
      data xLA403 / 0.18 , 0.76 , 0.87 , 0.84 /
*
*     404 dsig/deta Et 35-52 W 212-285 data, stat. err. and sys. err.
      real e404(5),xe404(5),xse404(5),xLA404(5)
      data e404   / 7.44 , 12.1 , 10.2 , 6.85 , 4.97 /
      data xe404  / 0.75 ,  1.0 ,  0.9 , 0.77 , 0.63 /
      data xse404 / 0.62 ,  0.4 ,  0.2 , 0.19 , 0.13 /
      data xLA404 / 1.04 ,  1.3 ,  1.0 , 0.77 , 0.62 /
*
*     405 dsig/deta Et 52-75 W 212-285 data, stat. err. and sys. err.
      real e405(4),xe405(4),xse405(4),xLA405(4)
      data e405   / 1.17 , 1.49 , 1.24 , 0.423 /
      data xe405  / 0.33 , 0.35 , 0.32 , 0.191 /
      data xse405 / 0.08 , 0.08 , 0.12 , 0.191 /
      data xLA405 / 0.11 , 0.18 , 0.19 , 0.073 /
*
*     406 dsig/deta Et 5-12 W 164-242 data, stat. err. and tot. err.
      real e406(5),xe406(5),xse406(5),xLA406(5)
      data e406   / 16.2 , 18.1 , 20.6 , 24.1 , 25.8 /
      data xe406  /  0.4 ,  0.4 ,  0.4 ,  0.5 ,  0.4 /
      data xse406 /  1.1 ,  1.4 ,  1.4 ,  1.7 ,  1.7 /
      data xLA406 /  2.0 ,  2.1 ,  2.5 ,  2.8 ,  3.1 /
*
*     407 dsig/deta Et 12-21 W 164-242 data, stat. err. and tot. err.
      real e407(6),xe407(6),xse407(6),xLA407(6)
      data e407   / 0.584 , 0.987 , 1.02 , 0.803 , 1.12 , 0.824 /
      data xe407  / 0.081 , 0.11  , 0.11 , 0.096 , 0.11 , 0.078 /
      data xse407 / 0.034 , 0.08  , 0.07 , 0.06  , 0.08 , 0.056 /
      data xLA407 / 0.102 , 0.106 , 0.2  , 0.175 , 0.26 , 0.264 /
*
*     501 dsig/dEtjet -1<eta<2.5 164<W<242 Q2<0.01 data, stat. and tot. err.
      real e501(4),xe501(4),xse501(4),xLA501(4)
      data e501   / 39900. , 3840. , 595. , 126. /
      data xe501  /   200. ,   60. ,  28. ,  12. /
      data xse501 /  2600. ,  250. ,  35. ,   7. /
      data xLA501 /  4700. ,  690. ,  91. ,  33. /
*
*     502 dsig/dEtjet -1<eta<2.5 164<W<242 Q2<1 data, stat. err. and tot. err.
      real e502(6),xe502(6),xse502(6),xLA502(6)
      data e502   / 31.3 , 6.66 , 1.73 , 0.415 , 0.0794 , 0.0143 /
      data xe502  /  0.4 , 0.19 , 0.1  , 0.042 , 0.0179 , 0.0065 /
      data xse502 /  0.8 , 0.18 , 0.06 , 0.014 , 0.0048 , 0.0004 /
      data xLA502 /  3.0 , 0.57 , 0.19 , 0.047 , 0.0131 , 0.0023 /
*
*     601 S(xT) eta*<=0.5 W=200 (Cone alg, R=1) data, stat. err. and tot. err.
      real e601(6),xe601(6),xse601(6),xLA601(6)
      data e601   / 0.0441 , 0.0201 , 0.00658 , 0.00236 , 0.000684 , 
     &     0.000185 /
      data xe601  / 0.0011 , 0.0014 , 0.00106 , 0.00005 , 0.000053 , 
     &     0.000047 /
      data xse601 / 0.0024 , 0.0012 , 0.00068 , 0.00015 , 0.000016 , 
     &     0.000009  /
      data xLA601 / 0.0078 , 0.0028 , 0.00241 , 0.00022 , 0.000073 , 
     &     0.000028 /
*
*     ID 1101 - 4071 (1+delta hadr.)
*
      real e1011(6),xe1011(6)
      data e1011  / 1.03 , 1.00 , 1.00 , 0.96 , 0.98 , 0.96 /
      data xe1011 / 0.03 , 0.04 , 0.02 , 0.01 , 0.04 , 0.04 /
*
      real e1021(6),xe1021(6)
      data e1021  / 1.0  , 0.98 , 0.98 , 0.93 , 0.92 , 0.88 /
      data xe1021 / 0.03 , 0.02 , 0.01 , 0.02 , 0.04 , 0.1  /
*
      real e1031(6),xe1031(6)
      data e1031  / 1.06 , 1.03 , 1.01 , 0.98 , 1.00 , 0.97 /
      data xe1031 / 0.03 , 0.06 , 0.03 , 0.02 , 0.05 , 0.05 /
*
      real e2011(5),xe2011(5)
      data e2011  / 1.25 , 1.31 , 1.23 , 1.04 , 1.05 /
      data xe2011 / 0.06 , 0.06 , 0.04 , 0.09 , 0.17 /
*
      real e2021(6),xe2021(6)
      data e2021  / 1.04 , 1.01 , 1.0  , 0.97 , 0.95 , 0.89 /
      data xe2021 / 0.03 , 0.04 , 0.02 , 0.02 , 0.03 , 0.09 /
*
      real e3011(6),xe3011(6)
      data e3011  / 0.87 , 0.96 , 1.0  , 1.02 , 1.08 , 1.12 /
      data xe3011 / 0.05 , 0.05 , 0.04 , 0.03 , 0.01 , 0.01 /
*
      real e3021(6),xe3021(6)
      data e3021  / 0.87 , 0.96 , 1.0  , 1.02 , 1.09 , 1.13 /
      data xe3021 / 0.05 , 0.05 , 0.04 , 0.03 , 0.01 , 0.02 /
*
      real e3031(5),xe3031(5)
      data e3031  / 0.87 , 0.96 , 0.99 , 1.02 , 1.05 /
      data xe3031 / 0.03 , 0.03 , 0.02 , 0.01 , 0.02 /
*
      real e3041(4),xe3041(4)
      data e3041  / 0.96 , 0.94 , 1.02 , 1.02 /
      data xe3041 / 0.05 , 0.06 , 0.04 , 0.08 /
*
      real e4011(5),xe4011(5)
      data e4011  / 0.81 , 0.95 , 0.98 , 1.04 , 1.09 /
      data xe4011 / 0.06 , 0.03 , 0.04 , 0.02 , 0.02 /
*
      real e4021(6),xe4021(6)
      data e4021  / 0.88 , 1.01 , 1.05 , 1.11 , 1.19 , 1.2  /
      data xe4021 / 0.05 , 0.05 , 0.05 , 0.03 , 0.03 , 0.03 /
*
      real e4031(4),xe4031(4)
      data e4031  / 0.85 , 0.95 , 0.98 , 1.02 /
      data xe4031 / 0.05 , 0.02 , 0.02 , 0.02 /
*
      real e4041(5),xe4041(5)
      data e4041  / 0.88 , 0.99 , 1.02 , 1.08 , 1.09 /
      data xe4041 / 0.03 , 0.03 , 0.03 , 0.02 , 0.03 /
*
      real e4051(4),xe4051(4)
      data e4051  / 0.96 , 0.96 , 1.05 , 1.17 /
      data xe4051 / 0.05 , 0.07 , 0.07 , 0.18 /
*
      real e4061(5),xe4061(5)
      data e4061  / 1.02 , 1.15 , 1.19 , 1.27 , 1.35 /
      data xe4061 / 0.03 , 0.02 , 0.02 , 0.06 , 0.10 /
*
      real e4071(6),xe4071(6)
      data e4071  / 0.87 , 1.11 , 1.19 , 1.39 , 1.41 , 1.53 /
      data xe4071 / 0.11 , 0.11 , 0.09 , 0.08 , 0.08 , 1.14 /
*
*     ID 1012 - 4072 (1+delta u.e.)
*
      real e1012(6),xe1012(6)
      data e1012  / 1.08 , 1.06 , 1.04 , 1.01 , 1.01 , 1.00 /
      data xe1012 / 0.01 , 0.02 , 0.01 , 0.02 , 0.03 , 0.05 /
*
      real e1022(6),xe1022(6)
      data e1022  / 1.07 , 1.04 , 1.04 , 1.00 , 1.00 , 0.98 /
      data xe1022 / 0.01 , 0.01 , 0.01 , 0.03 , 0.05 , 0.12 /
*
      real e1032(6),xe1032(6)
      data e1032  / 1.10 , 1.07 , 1.05 , 1.01 , 1.01 , 1.00 /
      data xe1032 / 0.02 , 0.03 , 0.03 , 0.02 , 0.04 , 0.05 /
*
      real e2012(5),xe2012(5)
      data e2012  / 1.77 , 1.66 , 1.43 , 1.26 , 1.23 /
      data xe2012 / 0.23 , 0.11 , 0.10 , 0.09 , 0.13 /
*
      real e2022(6),xe2022(6)
      data e2022  / 1.09 , 1.07 , 1.04 , 1.01 , 1.00 , 0.95 /
      data xe2022 / 0.01 , 0.02 , 0.02 , 0.03 , 0.04 , 0.08 /
*
      real e3012(6),xe3012(6)
      data e3012  / 1.04 , 1.06 , 1.06 , 1.07 , 1.09 , 1.11 /
      data xe3012 / 0.03 , 0.02 , 0.02 , 0.02 , 0.01 , 0.02 /
*
      real e3032(5),xe3032(5)
      data e3032  / 1.01 , 1.03 , 1.03 , 1.04 , 1.06 /
      data xe3032 / 0.02 , 0.02 , 0.02 , 0.02 , 0.02 /
*
      real e3042(4),xe3042(4)
      data e3042  / 1.03 , 0.97 , 1.03 , 1.04 /
      data xe3042 / 0.05 , 0.05 , 0.04 , 0.07 /
*
      real e4012(5),xe4012(5)
      data e4012  / 1.02 , 1.06 , 1.05 , 1.06 , 1.10 /
      data xe4012 / 0.04 , 0.02 , 0.02 , 0.02 , 0.03 /
*
      real e4022(6),xe4022(6)
      data e4022  / 1.04 , 1.07 , 1.08 , 1.10 , 1.16 , 1.14 /
      data xe4022 / 0.03 , 0.02 , 0.04 , 0.03 , 0.03 , 0.03 /
*
      real e4032(4),xe4032(4)
      data e4032  / 1.03 , 1.02 , 1.02 , 1.05 /
      data xe4032 / 0.04 , 0.02 , 0.02 , 0.03 /
*
      real e4042(5),xe4042(5)
      data e4042  / 1.01 , 1.03 , 1.04 , 1.07 , 1.07 /
      data xe4042 / 0.02 , 0.02 , 0.02 , 0.02 , 0.04 /
*
      real e4052(4),xe4052(4)
      data e4052  / 1.02 , 0.96 , 1.02 , 1.15 /
      data xe4052 / 0.05 , 0.06 , 0.05 , 0.18 /
*
      real e4062(5),xe4062(5)
      data e4062  / 1.29 , 1.45 , 1.64 , 1.89 , 1.99 /
      data xe4062 / 0.06 , 0.08 , 0.13 , 0.27 , 0.32 /
*
      real e4072(6),xe4072(6)
      data e4072  / 1.12 , 1.22 , 1.33 , 1.53 , 1.74 , 1.75 /
      data xe4072 / 0.07 , 0.06 , 0.08 , 0.14 , 0.33 , 0.27 /
*
*     ID 1013 - 4073 (1+delta frag.)
*
      real e1013(6),xe1013(6)
      data e1013  / 0.95 , 0.95 , 0.95 , 0.95 , 0.97 , 0.96 /
      data xe1013 / 0.02 , 0.02 , 0.01 , 0.01 , 0.03 , 0.04 /
*
      real e1023(6),xe1023(6)
      data e1023  / 0.94 , 0.94 , 0.94 , 0.93 , 0.92 , 0.90 /
      data xe1023 / 0.02 , 0.01 , 0.02 , 0.02 , 0.04 , 0.11 /
*
      real e1033(6),xe1033(6)
      data e1033  / 0.97 , 0.95 , 0.96 , 0.97 , 0.99 , 0.97 /
      data xe1033 / 0.01 , 0.02 , 0.01 , 0.02 , 0.03 , 0.04 /
*
      real e2013(5),xe2013(5)
      data e2013  / 0.72 , 0.80 , 0.87 , 0.83 , 0.86 /
      data xe2013 / 0.06 , 0.08 , 0.08 , 0.11 , 0.17 /
*
      real e2023(6),xe2023(6)
      data e2023  / 0.95 , 0.95 , 0.96 , 0.96 , 0.95 , 0.94 /
      data xe2023 / 0.02 , 0.01 , 0.01 , 0.02 , 0.03 , 0.07 /
*
      real e3013(6),xe3013(6)
      data e3013  / 0.84 , 0.90 , 0.94 , 0.96 , 0.99 , 1.01 /
      data xe3013 / 0.03 , 0.03 , 0.02 , 0.02 , 0.01 , 0.01 /
*
      real e3033(5),xe3033(5)
      data e3033  / 0.87 , 0.94 , 0.96 , 0.98 , 0.99 /
      data xe3033 / 0.03 , 0.02 , 0.01 , 0.01 , 0.02 /
*
      real e3043(4),xe3043(4)
      data e3043  / 0.93 , 0.97 , 0.99 , 0.98 /
      data xe3043 / 0.05 , 0.04 , 0.04 , 0.06 /
*
      real e4013(5),xe4013(5)
      data e4013  / 0.79 , 0.90 , 0.93 , 0.98 , 0.99 /
      data xe4013 / 0.04 , 0.02 , 0.02 , 0.01 , 0.02 /
*
      real e4023(6),xe4023(6)
      data e4023 / 0.85,0.94,0.97,1.01,1.02,1.05/
      data xe4023 / 0.03 , 0.03 , 0.02 , 0.02,0.02,0.03  /
*
      real e4033(4),xe4033(4)
      data e4033  / 0.82 , 0.93 , 0.96 , 0.97 /
      data xe4033 / 0.04 , 0.02 , 0.02 , 0.03 /
*
      real e4043(5),xe4043(5)
      data e4043  / 0.87 , 0.96 , 0.99 , 1.00 , 1.02 /
      data xe4043 / 0.03 , 0.02 , 0.02 , 0.02 , 0.03 /
*
      real e4053(4),xe4053(4)
      data e4053  / 0.94 , 0.99 , 1.03 , 1.02 /
      data xe4053 / 0.05 , 0.04 , 0.06 , 0.08 /
*
      real e4063(5),xe4063(5)
      data e4063  / 0.79 , 0.80 , 0.73 , 0.68 , 0.69 /
      data xe4063 / 0.06 , 0.06 , 0.06 , 0.06 , 0.06 /
*
      real e4073(6),xe4073(6)
      data e4073  / 0.77 , 0.91 , 0.89 , 0.91 , 0.83 , 0.88 /
      data xe4073 / 0.11 , 0.09 , 0.09 , 0.07 , 0.14 , 0.09 /
*
* Unpublished correction factors for PYTHIA and HERWIG for Fig. 9
* They are saved in histos 9001 - 9007
*
      real aipy(net6), aihe(net6), etpy(net6), ethe(net6)
      real hipy(net6), hihe(net6), hiav(net6)
      data aipy / 1.24 , 1.09 , 0.97 , 1.19 , 1.19 , 1.76 /
      data aihe / 1.11 , 1.10 , 0.90 , 1.13 , 1.03 , 1.49 /
      data etpy / 9.2 , 13.6 , 18.1 , 24.8 , 39.1 , 55.4 /
      data ethe / 9.2 , 13.5 , 17.9 , 25.0 , 41.3 , 59.3 /
      real zero6(net6)
      data zero6 /6*0./
*
* Photon fluxes for for Q2 < 0.01 and Q2 < 1 GeV2
*
      Real pf1, pf2, pf3
      Data pf1 /0.0127/, pf2 /0.0181/, pf3 /0.0181/
      Save pf1, pf2, pf3
*
* Parameter values for histo 601 and 603
*
      Real gev2nb, alpha, a2pi, em, em2, pm, pm2
      Parameter (gev2nb = 389379.323)
      Parameter (alpha = 1. / 137.03599911, a2pi = alpha / 2. / pi)
      Parameter (em = 0.51099892e-3, em2 = em*em)
      Parameter (pm = 0.93827203, pm2 = pm*pm)
*
      Real Wmin, Wmax, ymin, ymax, steps, yste, scms
      Save ymax, ymin, yste, scms
      Data Wmin /164./, Wmax /242./    ! W range for 601 and 603 to adjust !!!
      Parameter (steps = 100000.)      ! number of integration steps for 601
      Real flux, fluxint  ! differential and inegrated photon flux functions
*
      flux(y,q2) = a2pi / q2 * (
     $     (1. + (1. - y)**2) / y - 2. * em2 * y / q2)
*
      fluxint(y) = a2pi * (
     $     (1. + (1. - y)**2) / y *
     $     (log((q2high * (1 - y)) / (y*y)) - log(em2))
     $     - 2. * ( (1 - y) / y - em2 * y / q2high) )
*
************************************************
*     Determine the process type
************************************************
*
      iproc=iflag/1000
      if ((iproc.lt.0).or.(iproc.gt.2)) then
         write(hzunit,*) 'HZ',xxxx,': illegal IPROC: ',iproc
         return
      endif
*
************************************************
*     Init step
************************************************
*
      IF (MOD(IFLAG,10).eq.1) then
*
         Nevt   = 0.
         NLO    = 0
         NLOJET = 0
*
*     Initialisation: The following MUST always be done
*     (i) make subdirectory in PAWC
*     - use the name as the xxxxxx in HZxxxxxx subroutine
*     (i) make subdirectory in o/p file
*     
         write(hzunit,*) 'HZ'//xxxx,': booking histograms'
         Call hcdir('//PAWC',' ')
         if (iproc.le.1) then 
            call hmdir(xxxx,'S')
         else
            call hcdir(xxxx,' ')  
         endif
*
         Call hcdir('//HISTO', ' ')
         if (iproc.le.1) then 
            call hmdir(xxxx,'S')
         else
            call hcdir(xxxx,' ')  
         endif
*
**********************************************
*     booking of histograms         
**********************************************
*
*     All the MC ones, for each process.
         call hbookb(10000*iproc+101,'dsig/dEtjet 95<W?[g]p!<285'
     &        ,etjet,etjbin,0.0)
         call hbookb(10000*iproc+102,'dsig/dEtjet 95<W?[g]p!<212'
     &        ,etjet,etjbin,0.0)
         call hbookb(10000*iproc+103,'dsig/dEtjet 212<W?[g]p!<285'
     &        ,etjet,etjbin,0.0)
         call hbookb(10000*iproc+201
     $        ,' dsig/dEtjet 164<W?[g]p!<242 Q2<0.01',etj,etbin,0.0)
         call hbookb(10000*iproc+202
     $        ,' dsig/dEtjet 164<W?[g]p!<242 Q2<1',etjet,etjbin,0.0)
         call hbookb(10000*iproc+301,'dsig/deta 21<Etjet<75 GeV'
     &        ,neta,netab,0.0)
         call hbookb(10000*iproc+302,'dsig/deta 21<Etjet<35 GeV'
     &        ,neta,netab,0.0)
         call hbookb(10000*iproc+303,'dsig/deta 35<Etjet<52 GeV'
     &        ,neta2,netab2,0.0)
         call hbookb(10000*iproc+304,'dsig/deta 52<Etjet<75 GeV'
     &        ,neta3,netab3,0.0)
         call hbookb(10000*iproc+401,'dsig/deta 21<Et<35 95<W<212'
     &        ,neta2,netab2,0.0)
         call hbookb(10000*iproc+402,'dsig/deta 21<Et<35 212<W<285'
     &        ,neta,netab,0.0)
         call hbookb(10000*iproc+403,'dsig/deta 35<Et<52 95<W<212'
     &        ,neta3,netab3,0.0)
         call hbookb(10000*iproc+404,'dsig/deta 35<Et<52 212<W<285'
     &        ,neta2,netab2,0.0)
         call hbookb(10000*iproc+405,'dsig/deta 52<Et<75 212<W<285'
     &        ,neta3,netab3,0.0)
         call hbookb(10000*iproc+406,'dsig/deta 5<Et<12 164<W<242'
     &        ,neta4,netab4,0.0)
         call hbookb(10000*iproc+407,'dsig/deta 12<Et<21 164<W<242'
     &        ,neta5,netab5,0.0)
         call hbookb(10000*iproc+501
     $        ,'dsig/dEt -1<eta<2.5 Q2<0.01 164<W<242',net51,netb51,0.0)
         call hbookb(10000*iproc+502
     $        ,'dsig/dEtjet -1<eta<2.5 Q2<1 164<W<242',net52,netb52,0.0)
         call hbookb(10000*iproc+601,'S(xT) eta*<=0.5 W?[g]p!=200'
     &        ,net6,netb6,0.0)
         call hbookb(10000*iproc+602,
     &        'Etjet for S(xT) 1.5<eta<2.5 164<W<242',net6,etxbin,0.0)
         call hbookb(10000*iproc+603,'S(xT) eta*<0.5 W?[g]p!=200'
     &        ,net6,netb6,0.0)
         call hbarx(10000*iproc+601)
         call hbarx(10000*iproc+602)
         call hbarx(10000*iproc+603)
*
         if (iproc.le.1) then
*
* one time only, book fixed correction factors and H1 data histograms
*
      call hbookb(9001,'A = corr. factor for PYTHIA S(xT)'
     &        ,net6,etxbin,0.0)
      call hbookb(9002,'A = corr. factor for PHOJET/HERWIG S(xT)'
     &        ,net6,etxbin,0.0)
      call hbookb(9003,'<E?T,jet!>^3! for PYTHIA S(xT)'
     &        ,net6,etxbin,0.0)
      call hbookb(9004,'<E?T,jet!>^3! for PHOJET/HERWIG S(xT)'
     &        ,net6,etxbin,0.0)
      call hbookb(9005,'H = 1 / A <E?T,jet!>^3! for PYTHIA S(xT)'
     &        ,net6,etxbin,0.0)
      call hbookb(9006,'H = 1 / A <E?T,jet!>^3! for PHOJET/HERWIG'
     &        ,net6,etxbin,0.0)
      call hbookb(9007,'H = 1 / A <E?T,jet!>^3! average for S(xT)'
     &        ,net6,etxbin,0.0)
*
      call hbookb(9011,'A = corr. factor for PYTHIA S(xT)'
     &        ,net6,netb6,0.0)
      call hbookb(9012,'A = corr. factor for PHOJET/HERWIG S(xT)'
     &        ,net6,netb6,0.0)
      call hbookb(9013,'<E?T,jet!>^3! for PYTHIA S(xT)'
     &        ,net6,netb6,0.0)
      call hbookb(9014,'<E?T,jet!>^3! for PHOJET/HERWIG S(xT)'
     &        ,net6,netb6,0.0)
      call hbookb(9015,'H = 1 / A <E?T,jet!>^3! for PYTHIA S(xT)'
     &        ,net6,netb6,0.0)
      call hbookb(9016,'H = 1 / A <E?T,jet!>^3! for PHOJET/HERWIG'
     &        ,net6,netb6,0.0)
      call hbookb(9017,'H = 1 / A <E?T,jet!>^3! average for S(xT)'
     &        ,net6,netb6,0.0)
*
*     distributions Et in Etjet bins
*
            call hbookb(-101,'H1 dsig/dEtjet 95<W?[g]p!<285 stat err.'
     $           ,etjet,etjbin,0.0)
            call hbookb(-1101
     $           ,'H1 dsig/dEtjet 95<W?[g]p!<285 syst. err.',etjet
     $           ,etjbin,0.0)
            call hbookb(1011,'ID 101 Correction 1+[d] hadr.',etjet
     $           ,etjbin,0.0)
            call hbookb(1012,'ID 101 Correction 1+[d] u.e.' ,etjet
     $           ,etjbin,0.0)
            call hbookb(1013,'ID 101 Correction 1+[d] frag.',etjet
     $           ,etjbin,0.0)
*     
            call hbookb(-102
     $           ,'H1 dsig/dEtjet  95<W?[g]p!<212 stat. err.',etjet
     $           ,etjbin,0.0)
            call hbookb(-1102
     $           ,'H1 dsig/dEtjet  95<W?[g]p!<212 syst. err.',etjet
     $           ,etjbin,0.0)
            call hbookb(1021,'ID 102 Correction 1+[d] hadr.',etjet
     $           ,etjbin,0.0)
            call hbookb(1022,'ID 102 Correction 1+[d] u.e.',etjet
     $           ,etjbin,0.0)
            call hbookb(1023,'ID 102 Correction 1+[d] frag.',etjet
     $           ,etjbin,0.0)
*     
            call hbookb(-103
     $           ,' H1 dsig/dEtjet  212<W?[g]p!<285 stat. err.',etjet
     $           ,etjbin,0.0)
            call hbookb(-1103
     $           ,'H1 dsig/dEtjet  212<W?[g]p!<285 syst. err.',etjet
     $           ,etjbin,0.0)
            call hbookb(1031,'ID 103 Correction 1+[d] hadr.',etjet
     $           ,etjbin,0.0)
            call hbookb(1032,'ID 103 Correction 1+[d] u.e.',etjet
     $           ,etjbin,0.0)
            call hbookb(1033,'ID 103 Correction 1+[d] frag.',etjet
     $           ,etjbin,0.0)
*     
*     distributions Et in Etjet bins (with restriction to Q2)
*     
            call hbookb(-201,' H1 dsig/dEt 164<W<242 Q2<0.01 stat. err.'
     $           ,etj,etbin,0.0)
            call hbookb(-1201,'H1 dsig/dEt 164<W<242 Q2<0.01 syst. err.'
     $           ,etj,etbin,0.0)
            call hbookb(2011,'ID 201 Correction 1+[d] hadr.',etj,etbin
     $           ,0.0)
            call hbookb(2012,'ID 201 Correction 1+[d] u.e.',etj,etbin,0
     $           .0)
            call hbookb(2013,'ID 201 Correction 1+[d] frag.',etj,etbin
     $           ,0.0)
*     
            call hbookb(-202
     $           ,'H1 dsig/dEt 164<W?[g]p!<242 Q2<1 stat. err.',etjet
     $           ,etjbin,0.0)
            call hbookb(-1202,'H1 dsig/dEt 164<W<242 Q2<0.01 syst. err.'
     $           ,etjet,etjbin,0.0)
            call hbookb(2021,'ID 202 Correction 1+[d] hadr.',etjet
     $           ,etjbin,0.0)
            call hbookb(2022,'ID 202 Correction 1+[d] u.e.',etjet
     $           ,etjbin,0.0)
            call hbookb(2023,'ID 202 Correction 1+[d] frag.',etjet
     $           ,etjbin,0.0)
*     
*     distributions dsig/deta in eta bins
*
            call hbookb(-301,'H1 dsig/deta 21<Et jet<75 GeV stat. err.'
     $           ,neta,netab,0.0)
            call hbookb(-1301,'H1 dsig/deta 21<Et jet<75 GeV syst. err.'
     $           ,neta,netab,0.0)
            call hbookb(3011,'ID 301 Correction 1+[d] hadr.' ,neta,netab
     $           ,0.0)
            call hbookb(3012,'ID 301 Correction 1+[d] u.e.' ,neta,netab
     $           ,0.0)
            call hbookb(3013,'ID 301 Correction 1+[d] frag.' ,neta,netab
     $           ,0.0)
*
            call hbookb(-302,'H1 dsig/deta 21<Et jet <35 stat. err.'
     $           ,neta,netab,0.0)
            call hbookb(-1302,'H1 dsig/deta 21<Et jet <35 tot. err.'
     $           ,neta,netab,0.0)
            call hbookb(3021,'ID 302 Correction 1+[d] hadr.' ,neta,netab
     $           ,0.0)
            call hbookb(3022,'ID 302 Correction 1+[d] u.e.' ,neta,netab
     $           ,0.0)
            call hbookb(3023,'ID 302 Correction 1+[d] frag.' ,neta
     $           ,netab,0.0)
*     
            call hbookb(-303,'H1 dsig/deta 35<Et jet <52 stat. err.'
     $           ,neta2,netab2,0.0)
            call hbookb(-1303,'H1 dsig/deta 35<Et jet <52 tot. err.'
     &           ,neta2,netab2,0.0)
            call hbookb(3031,'ID 303 Correction 1+[d] hadr.'
     &           ,neta2,netab2,0.0)
            call hbookb(3032,'ID 303 Correction 1+[d] u.e.'
     &           ,neta2,netab2,0.0)
            call hbookb(3033,'ID 303 Correction 1+[d] frag.'
     &           ,neta2,netab2,0.0)
*     
            call hbookb(-304,'H1 dsig/deta 52<Et jet <75 stat. err.'
     $           ,neta3,netab3,0.0)
            call hbookb(-1304,'H1 dsig/deta 52<Et jet <75 syst. err.'
     &           ,neta3,netab3,0.0)
            call hbookb(3041,'ID 304 Correction 1+[d] hadr.'
     &           ,neta3,netab3,0.0)
            call hbookb(3042,'ID 304 Correction 1+[d] u.e.'
     &           ,neta3,netab3,0.0)
            call hbookb(3043,'ID 304 Correction 1+[d] frag.'
     &           ,neta3,netab3,0.0)
*     
            call hbookb(-401,'H1 dsig/deta 21<Et<35 95<W<212 stat. err.'
     &           ,neta2,netab2,0.0)
            call hbookb(-1401
     $           ,'H1 dsig/deta 21<Et<35 95<W<212 syst. err.',neta2
     $           ,netab2,0.0)
            call hbookb(4011,'ID 401 Correction 1+[d] hadr.' ,neta2
     $           ,netab2,0.0)
            call hbookb(4012,'ID 401 Correction 1+[d] u.e.' ,neta2
     $           ,netab2,0.0)
            call hbookb(4013,'ID 401 Correction 1+[d] frag.' ,neta2
     $           ,netab2,0.0)
*
            call hbookb(-402
     $           ,'H1 dsig/deta 21<Et<35 212<W<285 stat. err.',neta
     $           ,netab,0.0)
            call hbookb(-1402
     $           ,'H1 dsig/deta 21<Et<35 212<W<285 syst. err.',neta
     $           ,netab,0.0)
            call hbookb(4021,'ID 402 Correction 1+[d] hadr.' ,neta,netab
     $           ,0.0)
            call hbookb(4022,'ID 402 Correction 1+[d] u.e.' ,neta,netab
     $           ,0.0)
            call hbookb(4023,'ID 402 Correction 1+[d] frag.' ,neta,netab
     $           ,0.0)
*     
            call hbookb(-403,'H1 dsig/deta 35<Et<52 95<W<212 stat. err.'
     $           ,neta3,netab3,0.0)
            call hbookb(-1403
     $           ,'H1 dsig/deta 35<Et<52 95<W<212 syst. err.',neta3
     $           ,netab3,0.0)
            call hbookb(4031,'ID 403 Correction 1+[d] hadr.' ,neta3
     $           ,netab3,0.0)
            call hbookb(4032,'ID 403 Correction 1+[d] u.e.' ,neta3
     $           ,netab3,0.0)
            call hbookb(4033,'ID 403 Correction 1+[d] frag.' ,neta3
     $           ,netab3,0.0)
*     
            call hbookb(-404
     $           ,'H1 dsig/deta 35<Et<52 212<W<285 stat. err.',neta2
     $           ,netab2,0.0)
            call hbookb(-1404
     $           ,'H1 dsig/deta 35<Et<52 212<W<285 syst. err.',neta2
     $           ,netab2,0.0)
            call hbookb(4041,'ID 404 Correction 1+[d] hadr.' ,neta2
     $           ,netab2,0.0)
            call hbookb(4042,'ID 404 Correction 1+[d] u.e.' ,neta2
     $           ,netab2,0.0)
            call hbookb(4043,'ID 404 Correction 1+[d] frag.' ,neta2
     $           ,netab2,0.0)
*     
            call hbookb(-405
     $           ,'H1 dsig/deta 52<Et<75 212<W<285 stat. err.',neta3
     $           ,netab3,0.0)
            call hbookb(-1405
     $           ,'H1 dsig/deta 52<Et<75 212<W<285 syst. err.',neta3
     $           ,netab3,0.0)
            call hbookb(4051,'ID 405 Correction 1+[d] hadr.'
     &           ,neta3,netab3,0.0)
            call hbookb(4052,'ID 405 Correction 1+[d] u.e.'
     &           ,neta3,netab3,0.0)
            call hbookb(4053,'ID 405 Correction 1+[d] frag.'
     &           ,neta3,netab3,0.0)
*     
            call hbookb(-406
     $           ,'H1 dsig/deta 5<Et<12  164<W<242 stat. err.',neta4
     $           ,netab4,0.0)
            call hbookb(-1406,'H1 dsig/deta 5<Et<12 164<W<242 tot. err.'
     $           ,neta4,netab4,0.0)
            call hbookb(4061,'ID 405 Correction 1+[d] hadr.' ,neta4
     $           ,netab4,0.0)
            call hbookb(4062,'ID 405 Correction 1+[d] u.e.' ,neta4
     $           ,netab4,0.0)
            call hbookb(4063,'ID 405 Correction 1+[d] frag.' ,neta4
     $           ,netab4,0.0)
*     
            call hbookb(-407
     $           ,'H1 dsig/deta 12<Et<21 164<W<242 stat. err.',neta5
     $           ,netab5,0.0)
            call hbookb(-1407
     $           ,'H1 dsig/deta 12<Et<21 164<W<242 tot. err.',neta5
     $           ,netab5,0.0)
*     
            call hbookb(-501
     $           ,'H1 Et -1<eta<2.5 Q2<0.01 164<W<242 stat. err.',net51
     $           ,netb51,0.0)
            call hbookb(-1501
     $           ,'H1 Et -1<eta<2.5 Q2<0.01 164<W<242 tot. err.',net51
     $           ,netb51,0.0)
*     
            call hbookb(-502
     $           ,'H1 Etjet -1<eta<2.5 Q2<1 164<W<242 stat. err.',net52
     $           ,netb52,0.0)
            call hbookb(-1502
     $           ,'H1 dEtje -1<eta<2.5 Q2<1 164<W<242 tot. err.',net52
     $           ,netb52,0.0)
*     
            call hbookb(-601,' H1 S(xT) eta*<=0.5 W=200 stat. err.'
     $           ,net6,netb6,0.0)
            call hbookb(-1601,' H1  S(xT) eta*<=0.5 W=200 tot. err.'
     $           ,net6,netb6,0.0)
*
*     Make errors
*     
         do i = 1, 6
            xte101(i) = sqrt(xte101(i)**2 + xse101(i)**2 + xLA101(i)**2)
            xte102(i) = sqrt(xte102(i)**2 + xse102(i)**2 + xLA102(i)**2)
            xte103(i) = sqrt(xte103(i)**2 + xse103(i)**2 + xLA103(i)**2)
*
            xte202(i) = sqrt(xte202(i)**2 + xse202(i)**2 + xLA202(i)**2)
*
            xte301(i) = sqrt(xte301(i)**2 + xse301(i)**2 + xLA301(i)**2)   
            xte302(i) = sqrt(xte302(i)**2 + xse302(i)**2 + xLA302(i)**2)
*
            xe402(i) = sqrt(xe402(i)**2 + xse402(i)**2 + xLA402(i)**2)  
            xe407(i) = sqrt(xe407(i)**2 + xse407(i)**2 + xLA407(i)**2)  
*
            xe502(i) = sqrt(xe502(i)**2 + xse502(i)**2 + xLA502(i)**2)
 
            xe601(i) = sqrt(xe601(i)**2 + xse601(i)**2 + xLA601(i)**2) 
         enddo
*
         do i = 1, 5
            xte201(i) = sqrt(xte201(i)**2 + xse201(i)**2 + xLA201(i)**2)
*
            xte303(i) = sqrt(xte303(i)**2 + xse303(i)**2 + xLA303(i)**2)
*
            xe401(i) = sqrt(xe401(i)**2 + xse401(i)**2 + xLA401(i)**2)    
            xe404(i) = sqrt(xe404(i)**2 + xse404(i)**2 + xLA404(i)**2)  
            xe406(i) = sqrt(xe406(i)**2 + xse406(i)**2 + xLA406(i)**2)  
         enddo
*
         do i = 1, 4
            xte304(i) = sqrt(xte304(i)**2 + xse304(i)**2 + xLA304(i)**2)

            xe403(i) = sqrt(xe403(i)**2 + xse403(i)**2 + xLA403(i)**2)  
            xe405(i) = sqrt(xe405(i)**2 + xse405(i)**2 + xLA405(i)**2)  
            xe501(i) = sqrt(xe501(i)**2 + xse501(i)**2 + xLA501(i)**2)  
         enddo
*
*     Pack H1 data into histos
*     
            call hpak(-101,e101)
            call hpake(-101,xse101)
            call hpak(-1101,e101)
            call hpake(-1101,xte101)
            call hpak(-102,e102)
            call hpake(-102,xse102)
            call hpak(-1102,e102)
            call hpake(-1102,xte102)
            call hpak(-103,e103)
            call hpake(-103,xse103)
            call hpak(-1103,e103)
            call hpake(-1103,xte103)
*
            call hpak(-201,e201)
            call hpake(-201,xse201)
            call hpak(-1201,e201)
            call hpake(-1201,xte201)
            call hpak(-202,e202)
            call hpake(-202,xse202)
            call hpak(-1202,e202)
            call hpake(-1202,xte202)
*
            call hpak(-301,e301)
            call hpake(-301,xse301)
            call hpak(-1301,e301)
            call hpake(-1301,xte301)
            call hpak(-302,e302)
            call hpake(-302,xse302)
            call hpak(-1302,e302)
            call hpake(-1302,xte302)
            call hpak(-303,e303)
            call hpake(-303,xse303)
            call hpak(-1303,e303)
            call hpake(-1303,xte303)
            call hpak(-304,e304)
            call hpake(-304,xse304)
            call hpak(-1304,e304)
            call hpake(-1304,xte304)
*
            call hpak(-401,e401)
            call hpake(-401,xe401)
            call hpak(-1401,e401)
            call hpake(-1401,xse401)
            call hpak(-402,e402)
            call hpake(-402,xe402)
            call hpak(-1402,e402)
            call hpake(-1402,xse402)
            call hpak(-403,e403)
            call hpake(-403,xse403)
            call hpak(-1403,e403)
            call hpake(-1403,xe403)
            call hpak(-404,e404)
            call hpake(-404,xe404)
            call hpak(-1404,e404)
            call hpake(-1404,xse404)
            call hpak(-405,e405)
            call hpake(-405,xe405)
            call hpak(-1405,e405)
            call hpake(-1405,xse405)
            call hpak(-406,e406)
            call hpake(-406,xe406)
            call hpak(-1406,e406)
            call hpake(-1406,xse406)
            call hpak(-407,e407)
            call hpake(-407,xe407)
            call hpak(-1407,e407)
            call hpake(-1407,xse407)
*
            call hpak(-501,e501)
            call hpake(-501,xe501)
            call hpak(-1501,e501)
            call hpake(-1501,xse501)
            call hpak(-502,e502)
            call hpake(-502,xe502)
            call hpak(-1502,e502)
            call hpake(-1502,xse502)
*
            call hpak(-601,e601)
            call hpake(-601,xe601)
            call hpak(-1601,e601)
            call hpake(-1601,xse601)
*
* Pack correction factors for Fig. 9 (histo 602)
*
            do i = 1, net6
               hipy(i) = 1. / (aipy(i)*(etpy(i)**3))
               hihe(i) = 1. / (aihe(i)*(ethe(i)**3))
               hiav(i) = (hipy(i) + hihe(i)) / 2.
            enddo
            call hpak(9001,aipy)
            call hpak(9002,aihe)
            call hpak(9003,etpy)
            call hpak(9004,ethe)
            call hpak(9005,hipy)
            call hpak(9006,hihe)
            call hpak(9007,hiav)
            call hpake(9001,zero6)
            call hpake(9002,zero6)
            call hpake(9003,zero6)
            call hpake(9004,zero6)
            call hpake(9005,zero6)
            call hpake(9006,zero6)
            call hpake(9007,zero6)
            call hpak(9011,aipy)
            call hpak(9012,aihe)
            call hpak(9013,etpy)
            call hpak(9014,ethe)
            call hpak(9015,hipy)
            call hpak(9016,hihe)
            call hpak(9017,hiav)
            call hpake(9011,zero6)
            call hpake(9012,zero6)
            call hpake(9013,zero6)
            call hpake(9014,zero6)
            call hpake(9015,zero6)
            call hpake(9016,zero6)
            call hpake(9017,zero6)
*
* Calculate photon flux for histos 601 and 603
*
            ierr = HZIBEAM(ipbeam,ilbeam)
            if (.not.(ierr.eq.1)) then
               write(hzunit,*) 'HZ'//xxxx,': beams not found !!!',
     $              ipbeam,ilbeam
               write(hzunit,*)
     $   'HZ'//xxxx,': default photon flux will be used for 601: ',pf3
               goto 100
            else
               scms = 4. * PHEP(4,ipbeam) * PHEP(4,ilbeam)
               write(hzunit,*) 'HZ'//xxxx,': beams : ',
     $              PHEP(4,ipbeam), PHEP(4,ilbeam), scms
            endif
*
            ymin = (Wmin**2 - pm2) / scms
            ymax = (Wmax**2 - pm2) / scms
            yste = (ymax - ymin) / steps
            pf3 = 0.
            do y = ymin, ymax, yste          ! integration over y range
               pf3 = pf3 + fluxint(y) * yste
            enddo
         write(hzunit,*) 'HZ'//xxxx,': photon flux for histo 601 : ',pf3
*
         endif
*
********************************************* 
* Event processing
*********************************************
*
      Else if (MOD(IFLAG,10).eq.2) then
*     
*     Filling: The following MUST always be done
*     (i) move to the correct sub-directory in PAWC
*
         call hcdir('//PAWC/'//xxxx,' ')
*        
* allow for total xsection calculation
* 
         if (NLO.eq.1 .and. TOT.ne.1) GoTo 11112
         Nevt = Nevt + wtx
11112    Continue
*
         if (Nevt.le.0) then
            write(hzunit,*) 'HZ'//xxxx,': NLO ',NLO,' TOT ',TOT,wtx,nevt
         endif
         NLOJET = DIJET + TRIPJET + QUADJET
*
         ierr = HZIBEAM(ipbeam,ilbeam)
*
         if (.not.(ierr.eq.1)) then
            write(hzunit,*) 'HZ'//xxxx,': beams not found !!! ',
     $           ipbeam,ilbeam
            goto 100
         else
            do i = 1, 4
               pbeam(i) = PHEP(i,ipbeam)
            enddo
         endif
*
*     get kinematics
*
         q2   = real(HZDISKIN(1))
         x    = real(HZDISKIN(2))
         y    = real(HZDISKIN(3))
         Wyp2 = real(HZDISKIN(4))
         Wyp  = sqrt(Wyp2)
*
*     get electron
*
         iel = HZIDELEC(idum)
         if (iel.eq.-1) then
            write(*,*) 'HZ'//xxxx,': electron not found !!!'
            goto 100
         endif
         Ee = real(PHEP(4,iel))
         The = real(HZPHMANG(PHEP(3,iel),
     $              sqrt(PHEP(1,iel)**2 + PHEP(2,iel)**2))) * rd
         Phe = HZPHMANG(PHEP(1,iel),PHEP(2,iel)) * rd
*     
********************************************
*     select Photoproduction events
********************************************
*
         incljet = .true.
         if (Wyp.lt.Wyplow)  incljet = .false.
         if (Wyp.gt.Wyphigh) incljet = .false.
         if (q2.gt.q2high)   incljet = .false.
c         if (The.lt.thetcut) incljet = .false.
*
*     return if no Photoproduction kinematics
*
         if (.not.incljet) goto 100
         if ((NLO.eq.1) .and. (NLOJET.eq.0)) goto 11114
*
*     find photon for boost to Breit frame
*
         ierr = HZIPGAM(ph)
         if (ierr.eq.-1) then
            write(hzunit,*) 'HZ'//xxxx,' boson vector not found !!!'
            call VZERO(ph,5)
         else
            do i = 1, 4
               pgam(i) = ph(i)
            enddo
         endif
*     
************************************************
*     do actual jet finding
*     modjet should be 3, rcone 1.
************************************************
*
         call hzjtfind(modjet,rcone,nj,pj)
*     
         if (nj.le.0) goto 100
         if (nj.gt.maxhzjets) then
            write(hzunit,*) 'hz',xxxx,' too many jets found ! '
            goto 100
         endif
*
*     now boost jets back to lab frame
*
c         call hzbrtola(nj,pj,pjlab)	
*
*     select jets (it is assumed that in pj they are ordered in pt)
*
         do ij = 1, nj
*
            ej=real(pj(ij,3))
            etaj=real(pj(ij,1))
c	    ptq=ptj**2/q2
c	    eta =0.-alog(tan(etaj/2))   ! calculate eta
*
*     Filling of Histos ID 101-202
*
	    if(ej.gt.etcut .and. 
     +         etaj .ge.raplow .and. etaj.lt.raphigh) then
*
	       if (Wyp.ge.95. .and. Wyp.lt.285. .and. q2.lt.1.) then
                  call hfill(10000*iproc+101,real(ej),0.,wtx)
               endif
               if (Wyp.ge.95. .and. Wyp.lt.212. .and. q2.lt.1.) then
                  call hfill(10000*iproc+102,real(ej),0.,wtx)
          elseif (Wyp.ge.212. .and. Wyp.lt.285. .and. q2.lt.1.) then
                  call hfill(10000*iproc+103,real(ej),0.,wtx)
               endif
*
               if (Wyp.ge.164..and. Wyp.lt.242. .and. q2.lt.1.
     &              .and. ej.ge.21. .and. ej.lt.75.) then
	          call hfill(10000*iproc+202,real(ej),0.,wtx)
               endif
               if (Wyp.ge.164..and. Wyp.lt.242. .and. q2.lt.0.01
     &              .and. ej.ge.5. .and. ej.lt.28.) then
	          call hfill(10000*iproc+201,real(ej),0.,wtx)
               endif
            endif
*
*     Filling of ID 30x
*
            if(ej.gt.etcut .and. q2.lt.1. .and.
     +           etaj.ge.raplow .and. etaj.lt.raphigh
     +           .and. Wyp.ge.95. .and. Wyp.lt.285.) then
               if (ej.ge.21. .and. ej.lt.75.) then
                  call hfill(10000*iproc+301,real(etaj),0.,wtx)
               endif
               if (ej.ge.21. .and. ej.lt.35.) then
                  call hfill(10000*iproc+302,real(etaj),0.,wtx)
               elseif (ej.ge.35. .and. ej.lt.52.) then
                  call hfill(10000*iproc+303,real(etaj),0.,wtx)
               elseif (ej.ge.52. .and. ej.lt.75.) then
                  call hfill(10000*iproc+304,real(etaj),0.,wtx)
               endif
            endif
*
*     Filling of ID 40x
*
            if (ej.gt.etcut .and. q2.lt.1. .and.
     +           etaj.ge.raplow .and. etaj.lt.raphigh) then
               if (ej.ge.21. .and. ej.lt.35.) then 
                  if (Wyp.ge.95. .and. Wyp.lt.212.) then
                     call hfill(10000*iproc+401,real(etaj),0.,wtx)
                  elseif (Wyp.ge.212. .and. Wyp.lt.285.) then
                     call hfill(10000*iproc+402,real(etaj),0.,wtx)
                  endif
               endif
*
               if (ej.ge.35. .and. ej.lt.52.) then 
                  if (Wyp.ge.95. .and. Wyp.lt.212.) then
                     call hfill(10000*iproc+403,real(etaj),0.,wtx)
                  elseif (Wyp.ge.212. .and. Wyp.lt.285.) then
                     call hfill(10000*iproc+404,real(etaj),0.,wtx)
                  endif
               endif
*
               if (ej.ge.52. .and. ej.lt.75.
     +              .and.Wyp.ge.212. .and. Wyp.lt.285.) then
                  call hfill(10000*iproc+405,real(etaj),0.,wtx)
               endif
*
               if (Wyp.ge.164. .and. Wyp.lt.242.) then
                  if (ej.ge.5. .and. ej.lt.12.) then
                     call hfill(10000*iproc+406,real(etaj),0.,wtx)
                  elseif (ej.ge.12. .and. ej.lt.21.) then
                     call hfill(10000*iproc+407,real(etaj),0.,wtx)
                  endif
               endif
            endif
*
      enddo                                        ! loop over jets
*
*     ready with jet selection and histo filling (for ID < 50x)
* NOW find jets using CONE ALGORTHMUS
*
         call hzjtfind(modje2,rcone,nj,pj)
*     
         if (nj.le.0) goto 100
         if (nj.gt.maxhzjets) then
            write(hzunit,*) 'HZ',xxxx
     $           ,': too many jets found !!! for Cone'
            goto 100
         endif
*
*     select jets (it is assumed that in pj they are ordered in pt)
*     
         do ij = 1, nj
*
            ej   = real(pj(ij,3))
            etaj = real(pj(ij,1))
*
*     filling!!!!
*
	    if (ej.gt.etcut .and. 
     +           etaj.ge.raplow .and. etaj.lt.raphigh) then
*
               if (Wyp.ge.164. .and. Wyp.lt.242. .and. q2.lt.0.01) then
                  call hfill(10000*iproc+501,real(ej),0.,wtx)
               endif
               if (Wyp.ge.164. .and. Wyp.lt.242. .and. q2.lt.1.) then
                  call hfill(10000*iproc+502,real(ej),0.,wtx)
               endif
            endif
*
            if (Wyp.ge.Wmin .and. Wyp.lt.Wmax .and. q2.lt.q2high) then
c     Calculate CMS rapidity
               yboost = 0.5*log( (2.*real(PHEP(3,ipbeam))/Wyp)**2 )
               if (abs(etaj-yboost).lt.0.5) then
                  call hfill(10000*iproc+601,(2*real(ej))/real(Wyp),0.
     $                 ,wtx*real(ej**3)/(pi*Wyp*pf3))
                  call hfill(10000*iproc+603,(2*real(ej))/real(Wyp),0.
     $                 ,wtx*real(ej**3)/(pi*Wyp*flux(y,q2)))
               endif
            endif
*
            if (Wyp.ge.164. .and. Wyp.lt.242. .and. q2.lt.q2high) then
               if (etaj.gt.1.5 .and. etaj.lt.2.5) then
                  if (ej.lt.etxbin(4)) then
                     if (q2.lt.q2low)
     $        call hfill(10000*iproc+602,real(ej),0.,wtx/(2.*pi*pf1))
                  else
              call hfill(10000*iproc+602,real(ej),0.,wtx/(2.*pi*pf2))
                  endif
               endif
            endif
*
         enddo
*     
 100     Continue
*       do ihep=1,nhep
*           Do i=1,5
*             PHEP(i,ihep)=Plab(i,ihep)
*           enddo
*       enddo
11114	 continue		 
*     
********************************************
*     Termination and normalisation
********************************************
*
      Else if (MOD(IFLAG,10).eq.3) then

         if (iproc.eq.2.or.iproc.eq.0) then
            write(hzunit,*) 'HZ',xxxx,': finishing off'
         endif
*
*     Termination: The following MUST always be done
*     (i) Move to the correct PAW subdirectory
*     
         call hcdir('//PAWC/'//xxxx,' ')
*
c         Write(hzunit,*) 'HZ'//xxxx,': x-section = ',xsec
*         x section in nb
*
         if (xsec.ne.0.) then
            lumnb = real(nevt) / real(xsec)
            lumpb = real(nevt) / real(xsec*1000.)
c            write(hzunit,*) 'HZ',xxxx,': sigma_tot = ',xsec
         else
            lumnb = 999999999.
            lumpb = 999999999.
            write(hzunit,*) 'HZ',xxxx,': sigma_tot = 0 !!!'
         endif
*
*     norm et and et2/q2 in eta bins
*
         do i = 1, 2
            call hzhinrm(10000*iproc+200+i, 0, lumpb, 1 )
            call hzhinrm(10000*iproc+500+i, 0, lumpb, 1 )
         enddo
*
         do i = 1, 3
            call hzhinrm(10000*iproc+100+i, 0, lumpb, 1 )
         enddo
*
*     norm et forward in Q2 bins 
*
         do i = 1, 4
            call hzhinrm(10000*iproc+300+i, 0, lumpb, 1 )
         enddo
*
         do i = 1, 5
            call hzhinrm(10000*iproc+400+i, 0, lumpb, 1 )
         enddo
*
         call hzhinrm(10000*iproc+406, 0, lumnb, 1 )
         call hzhinrm(10000*iproc+407, 0, lumnb, 1 )
*
         call hzhinrm(10000*iproc+601, 0, lumnb*gev2nb, 1 )
         call hzhinrm(10000*iproc+602, 0, lumnb*gev2nb, 1 )
         call hzhinrm(10000*iproc+603, 0, 
     &        lumnb*gev2nb*(ymax-ymin)*q2high, 1 )
*
* now add resolved and direct histograms, if it was generated this way
*
         if (iproc.eq.2) then
*
            do i = 1, 2 
               call hopera(10200+i,'+e', 20200+i, 200+i, 1., 1. )
               call hopera(10500+i,'+e', 20500+i, 500+i, 1., 1. )
            enddo
*     
            do i = 1, 3
               call hopera(10100+i,'+e', 20100+i, 100+i, 1., 1. )
            enddo
*     
*     norm et forward in Q2 bins 
*     
            do i = 1, 4
               call hopera(10300+i,'+e',20300+i, 300+i, 1., 1. )
            enddo
*     
            do i = 1, 5
               call hopera(10400+i,'+e',20400+i, 400+i, 1., 1. )
            enddo
*     
            call hopera(10406,'+e', 20406, 406, 1., 1. )
            call hopera(10407,'+e', 20407, 407, 1., 1. )
            call hopera(10601,'+e', 20601, 601, 1., 1. )
            call hopera(10602,'+e', 20602, 602, 1., 1. )
            call hopera(10603,'+e', 20603, 603, 1., 1. )
*
         endif
*
      Endif                    !      iflag.eq.3
*     
      RETURN
      END
*
