      subroutine hzh9905024(iflag)
*****************************************************************************
*       
* Make plots for D0 paper on the bbbar production cross section and
* angular correlations in ppbar collisions at sqrt(s)=1.9 TeV
* 
* ( Phys. Lett. B487, 264 (hep-ex/9905024 ) 
*       
* A. cross-section for dimuon production from semileptonic beauty decays
*
*    sigma(ppbar->bbbar->mu mu X) [pb]
*    
*    in 5 bins of transverse momentum of the leading muon from 4 to 25 GeV/c
*
*    cuts:
*    muons: 
*           |eta_mu| < 0.8
*           6 GeV/c^2 < m_{mu mu} < 35 GeV/c^2 
*
*    statistical and systematic errors are added in quadrature
*
* B. cross-section for dimuon production from semileptonic beauty decays
*
*    sigma(ppbar->bbbar->mu mu X) [pb]
*
*    in 9 bins of angular difference in phi of the two muons from 0 to 180 degree
*
*    cuts:
*    muons: 
*           |eta| < 0.8
*           6 GeV/c^2 < m_{mu mu} < 35 GeV/c^2 
*
* C. inclusive single b quark cross section
*
*    sigma(ppbar->b X) [nb]
*
*    extrapolated from events with dimuons
*
*    for b transverse momentum > (8,11,13,18,25) GeV/c (5 bins)
*
*    cuts:
*    b:     |y| < 1.0
*
*    statistical and systematic errors are added in quadrature
*
* D. inclusive single b quark cross section
*
*    sigma(ppbar->b X) [nb]
*
*    extrapolated from single muon events
*
*    for b transverse momentum > (6,7,9,12,15) GeV/c (5 bins)
*
*    cuts:
*    b:     |y| < 1.0
*
*    statistical and systematic errors are added in quadrature
*
* Arguments:  iflag=1 initialisation/booking of histograms
*             iflag=2 event processing/filling of MC histograms
*             iflag=3 termination/final normalisation
*                     (the variables Xsec (total cross section) and
*                      Ntot (total number of events) have to be set before
*                      calling the termination routine in order to get a
*                      correct normalisation for the MC histograms)
*
* written by: Oliver Gutsche (oliver.gutsche@desy.de) on 07.09.2003
*       
*****************************************************************************
*
* Output graphs:
*---------------
* DATA
*
* histograms -1 .. -4 contain the measured cross section data,
* -1        sigma(ppbar->b(bbar)->mu mu X) for cross section A.
* -2        sigma(ppbar->b(bbar)->mu mu X) for cross section B.
* -3        sigma(ppbar->b X) for cross section C.
* -4        sigma(ppbar->b X) for cross section D.
*
* Monte-Carlo
*  1        sigma(ppbar->b(bbar)->mu mu X) for cross section A.
*  2        sigma(ppbar->b(bbar)->mu mu X) for cross section B.
*  3        sigma(ppbar->b X) for cross section C.
*  4        sigma(ppbar->b X) for cross section D.
*               These graphs will be
*               meaningless unless Xsec and Ntot are set before
*               calling the termination routine.
*               (Xsec - total cross section returned by MC)
*               (Ntot - number of events passed to this routine)
*
*****************************************************************************	
      IMPLICIT NONE
        
#include "hepevtp.inc"
#include "heracmn.inc"
#include "hzfunc.inc"
      
*     *********************************************************     
*     Variable Declaration     
*     *********************************************************      
      
      Character xxxx*10
      Data xxxx/'h9905024'/

      DOUBLE PRECISION pi
      PARAMETER(pi=3.141592653589793238)

      
      INTEGER iflag,ID
      REAL phi

*     bins, data and errors for cross section A.
      INTEGER NABIN
      PARAMETER (NABIN=5)
      REAL ABIN(NABIN+1)
      REAL ADATA(NABIN),AERROR(NABIN)
      
      DATA ABIN /4.,5.,7.,10.,15.,25./
      SAVE ABIN
      DATA ADATA /0.30,0.21,0.064,0.018,0.0025/
      SAVE ADATA
      DATA AERROR /0.132,0.057,0.040,0.013,0.0008/
      SAVE AERROR
      
*     bins, data and errors for cross section B.
      INTEGER NBBIN
      PARAMETER (NBBIN=9)
      REAL BBIN(NBBIN+1)
      REAL BDATA(NBBIN),BERROR(NBBIN)
      
      DATA BBIN /0.,20.,40.,60.,80.,100.,120.,140.,160.,180./
      SAVE BBIN
      DATA BDATA /0.0031,0.0047,0.0083,0.0148,0.0204,0.0423,0.1583,
     +     0.1700,0.4072/
      SAVE BDATA
      DATA BERROR /0.0017,0.0022,0.0038,0.0069,0.0088,0.0163,0.0518,
     +     0.0494,0.1064/
      SAVE BERROR
      
*     bins, data and errors for cross section C.
      INTEGER NCBIN
      PARAMETER (NCBIN=5)
      REAL CBIN(NCBIN+1)
      REAL CDATA(NCBIN),CERROR(NCBIN)
      
      DATA CBIN /6.5,9.5,12.5,13.5,22.5,27.5/
      SAVE CBIN
      DATA CDATA /5960.,3100.,1710.,610.,170./
      SAVE CDATA
      DATA CERROR /2290.,1080.,590.,210.,60./
      SAVE CERROR
      
*     bins, data and errors for cross section D.
      INTEGER NDBIN
      PARAMETER (NDBIN=5)
      REAL DBIN(NDBIN+1)
      REAL DDATA(NDBIN),DERROR(NDBIN)
      
      DATA DBIN /5.5,6.5,7.5,10.5,13.5,16.5/
      SAVE DBIN
      DATA DDATA /8760.,7780.,4850,2280.,1160./
      SAVE DDATA
      DATA DERROR /2800.,1950.,1220.,580.,300./
      SAVE DERROR
      
*     loop variables
      INTEGER loop_1,loop_2,loop_3

*     b quark variables
      INTEGER NB,NMAXB
      INTEGER NBBAR,NMAXBBAR
      INTEGER NBBBAR,NMAXBBBAR
      PARAMETER (NMAXB=3,NMAXBBAR=3,NMAXBBBAR=6)
      INTEGER B(NMAXB),BBAR(NMAXBBAR),BBBAR(NMAXBBBAR)
      LOGICAL replace,inlist

*     muon variables
      INTEGER NMAXMU,NMUIND
      PARAMETER (NMAXMU=6,NMUIND=2)
      INTEGER NMU,MU(NMAXMU,NMUIND)
      INTEGER MUMOID
      REAL MUPT,MUETA
      INTEGER MAXARRAY
      PARAMETER(MAXARRAY=4096)
      INTEGER STEPINDEX,TOTINDEX,ARRAY(MAXARRAY)
      LOGICAL matched

*     bbbar array sorting in pt
      INTEGER exchange

*     bin calculation
      REAL bin

*     histo filling
      LOGICAL filled
      REAL dphi
      REAL fillpt,fillphi,mmumu

*     histo normalisation
      REAL norm

*     printout variable
      LOGICAL printout
      Real pt1,pt2
*     *********************************************************     
*     running condition
*     iflag: 
*     1: initialisation
*     2: execution
*     3: finalisation
*     *********************************************************      

      IF (iflag.gt.3) THEN
         PRINT*,xxxx,' Badly called routine'
         PRINT*,'          please set iflag to 1,2 or 3'
      ENDIF
      
*     *********************************************************     
*     initialisation run
*     *********************************************************     
      IF (iflag.eq.1) THEN
         
         CALL HCDIR('//PAWC',' ')
         CALL HMDIR(xxxx,'S')
         CALL HCDIR('//HISTO',' ')
         CALL HMDIR(xxxx,'S')
         
         ID=1
         CALL HBOOKB(ID,' [s](ppbar->bbbar->[m][m] X) ',NABIN,ABIN,0.)
         CALL HBARX(ID)
         CALL HBOOKB(-ID,' [s](ppbar->bbbar->[m][m] X) ',
     +        NABIN,ABIN,0.)
         CALL HPAK(-ID,ADATA)
         CALL HPAKE(-ID,AERROR)

         ID=2
         CALL HBOOKB(ID,' [s](ppbar->bbbar->[m] [m] X) ',
     +        NBBIN,BBIN,0.)
         CALL HBARX(ID)
         CALL HBOOKB(-ID,' [s](ppbar->bbbar->[m] [m] X) ',
     +        NBBIN,BBIN,0.)
         CALL HPAK(-ID,BDATA)
         CALL HPAKE(-ID,BERROR)

         ID=3
         CALL HBOOKB(ID,' [s](ppbar->b X) ',NCBIN,CBIN,0.)
         CALL HBARX(ID)
         CALL HBOOKB(-ID,' [s](ppbar->b X) ',NCBIN,CBIN,0.)
         CALL HPAK(-ID,CDATA)
         CALL HPAKE(-ID,CERROR)

         ID=4
         CALL HBOOKB(ID,' [s](ppbar->b X) ',NDBIN,DBIN,0.)
         CALL HBARX(ID)
         CALL HBOOKB(-ID,' [s](ppbar->b X) ',NDBIN,DBIN,0.)
         CALL HPAK(-ID,DDATA)
         CALL HPAKE(-ID,DERROR)

      ELSE IF (iflag.eq.2) THEN
         CALL HCDIR('//PAWC/'//xxxx,' ')

*     initialise variables
         NB=0
         DO loop_1=1,NMAXB
            B(loop_1)=0
         ENDDO
         NBBAR=0
         DO loop_1=1,NMAXBBAR
            BBAR(loop_1)=0
         ENDDO
         NBBBAR=0
         DO loop_1=1,NMAXBBBAR
            BBBAR(loop_1)=0
         ENDDO
         NMU=0
         DO loop_1=1,NMAXMU
            DO loop_2=1,NMUIND
               MU(loop_1,loop_2)=0
            ENDDO
         ENDDO
         inlist=.false.
         exchange=0
         bin=0.0
         dphi=0.0
         replace=.false.
         printout=.false.
         
         
*     search for specific particles in nhep
         DO loop_1=1,NHEP
            
*     search for b, pythia style, ISTHEP<21
            IF ( GEN.eq.'PYT'.or.GEN.eq.'CAS' ) THEN
*     first found b quark is kept, chain b quarks are discarded
               IF ( IDHEP(loop_1).eq.5.AND.ISTHEP(loop_1).ge.10 ) THEN
                  IF (NB.ge.NMAXB) THEN
                     print*,xxxx,' ERROR: More than ',NMAXB,' b quarks'
                     RETURN
                  ELSE
*     check 3 consecutive mother if they are already in list 
                     inlist=.false.
                     DO loop_2=1,NB
                        IF ( B(loop_2).eq.JMOHEP(1,loop_1) ) THEN
                           inlist=.true.
                        ELSE IF ( JMOHEP(1,JMOHEP(1,loop_1)).gt.0.AND.
     +                          JMOHEP(1,JMOHEP(1,loop_1)).eq.B(loop_2)
     +                          ) THEN
                           inlist=.true.
                        ELSE IF ( JMOHEP(1,JMOHEP(1,JMOHEP(1,loop_1))).
     +                          gt.0.AND.
     +                          JMOHEP(1,JMOHEP(1,JMOHEP(1,loop_1))).eq.
     +                          B(loop_2)
     +                          ) THEN
                           inlist=.true.
                        ENDIF
                     ENDDO
                     IF ( .NOT.inlist ) THEN
                        NB=NB+1
                        B(NB)=loop_1
                        IF (NBBBAR.ge.NMAXBBBAR) THEN
                           print*,xxxx,' ERROR: More than ',NMAXBBBAR,
     +                          ' b or anti bar quarks'
                           RETURN
                        ELSE
                           NBBBAR=NBBBAR+1
                           BBBAR(NBBBAR)=loop_1
                        ENDIF
                     ENDIF
                  ENDIF
               ELSE IF ( IDHEP(loop_1).eq.-5.AND.ISTHEP(loop_1).ge.10 ) 
     +                 THEN
                  IF (NBBAR.ge.NMAXBBAR) THEN
                     print*,xxxx,' ERROR: More than ',NMAXB,
     +                    ' anti b quarks'
                     RETURN
                  ELSE
*     check 3 consecutive mother if they are already in list 
                     inlist=.false.
                     DO loop_2=1,NBBAR
                        IF ( BBAR(loop_2).eq.JMOHEP(1,loop_1) ) THEN
                           inlist=.true.
                        ELSE IF ( JMOHEP(1,JMOHEP(1,loop_1)).gt.0.AND.
     +                          JMOHEP(1,JMOHEP(1,loop_1)).eq.
     +                          BBAR(loop_2) ) THEN
                           inlist=.true.
                        ELSE IF ( JMOHEP(1,JMOHEP(1,JMOHEP(1,loop_1))).
     +                          gt.0.AND.
     +                          JMOHEP(1,JMOHEP(1,JMOHEP(1,loop_1))).eq.
     +                          BBAR(loop_2)
     +                          ) THEN
                           inlist=.true.
                        ENDIF
                     ENDDO
                     IF ( .NOT.inlist ) THEN
                        NBBAR=NBBAR+1
                        BBAR(NBBAR)=loop_1
                        IF (NBBBAR.ge.NMAXBBBAR) THEN
                           print*,xxxx,' ERROR: More than ',NMAXBBBAR,
     +                          ' b or anti bar quarks'
                           RETURN
                        ELSE
                           NBBBAR=NBBBAR+1
                           BBBAR(NBBBAR)=loop_1
                        ENDIF
                     ENDIF
                  ENDIF
               ENDIF
            ELSE IF ( GEN.eq.'HRW' ) THEN
*     take all b quarks which have ISTHEP=2 (parton before hadronisation
*     quarks have as second mother color information, so only consider first mother
               IF ( IDHEP(loop_1).eq.5.AND.ISTHEP(loop_1).eq.2 ) THEN
                  IF (NB.ge.NMAXB) THEN
                     print*,xxxx,' ERROR: More than ',NMAXB,' b quarks'
                     RETURN
                  ELSE
*     check 3 consecutive mother if they are already in list 
                     inlist=.false.
                     DO loop_2=1,NB
                        IF ( B(loop_2).eq.JMOHEP(1,loop_1) ) THEN
                           inlist=.true.
                        ELSE IF ( JMOHEP(1,JMOHEP(1,loop_1)).gt.0.AND.
     +                          JMOHEP(1,JMOHEP(1,loop_1)).eq.B(loop_2)
     +                          ) THEN
                           inlist=.true.
                        ELSE IF ( JMOHEP(1,JMOHEP(1,JMOHEP(1,loop_1))).
     +                          gt.0.AND.
     +                          JMOHEP(1,JMOHEP(1,JMOHEP(1,loop_1))).eq.
     +                          B(loop_2)
     +                          ) THEN
                           inlist=.true.
                        ENDIF
                     ENDDO
                     IF ( .NOT.inlist ) THEN
                        NB=NB+1
                        B(NB)=loop_1
                        IF (NBBBAR.ge.NMAXBBBAR) THEN
                           print*,xxxx,' ERROR: More than ',NMAXBBBAR,
     +                          ' b or anti bar quarks'
                           RETURN
                        ELSE
                           NBBBAR=NBBBAR+1
                           BBBAR(NBBBAR)=loop_1
                        ENDIF
                     ENDIF
                  ENDIF
               ELSE IF ( IDHEP(loop_1).eq.-5.AND.ISTHEP(loop_1).eq.2 ) 
     +                 THEN
                  IF (NBBAR.ge.NMAXBBAR) THEN
                     print*,xxxx,' ERROR: More than ',NMAXB,
     +                    ' anti b quarks'
                     RETURN
                  ELSE
*     check 3 consecutive mother if they are already in list 
                     inlist=.false.
                     DO loop_2=1,NBBAR
                        IF ( BBAR(loop_2).eq.JMOHEP(1,loop_1) ) THEN
                           inlist=.true.
                        ELSE IF ( JMOHEP(1,JMOHEP(1,loop_1)).gt.0.AND.
     +                          JMOHEP(1,JMOHEP(1,loop_1)).eq.
     +                          BBAR(loop_2) ) THEN
                           inlist=.true.
                        ELSE IF ( JMOHEP(1,JMOHEP(1,JMOHEP(1,loop_1))).
     +                          gt.0.AND.
     +                          JMOHEP(1,JMOHEP(1,JMOHEP(1,loop_1))).eq.
     +                          BBAR(loop_2)
     +                          ) THEN
                           inlist=.true.
                        ENDIF
                     ENDDO
                     IF ( .NOT.inlist ) THEN
                        NBBAR=NBBAR+1
                        BBAR(NBBAR)=loop_1
                        IF (NBBBAR.ge.NMAXBBBAR) THEN
                           print*,xxxx,' ERROR: More than ',NMAXBBBAR,
     +                          ' b or anti bar quarks'
                           RETURN
                        ELSE
                           NBBBAR=NBBBAR+1
                           BBBAR(NBBBAR)=loop_1
                        ENDIF
                     ENDIF
                  ENDIF
               ENDIF
            ELSE
               print*,xxxx,' generator not implemented for this routine'
               RETURN
            ENDIF
*     look for muons
            IF ( ISTHEP(loop_1).eq.1 ) THEN
               IF ( IDHEP(loop_1).eq.13.OR.IDHEP(loop_1).eq.-13 ) THEN
                  MUETA=REAL(HZETA(loop_1))
                  IF ( ABS(MUETA).lt.0.8 ) THEN
                     IF ( NMU.ge.NMAXMU ) THEN
                        PRINT*,xxxx,'ERROR: More than ',NMAXMU,
     +                       ' muons'
                        RETURN
                     ELSE 
                        NMU=NMU+1
                        MU(NMU,1)=loop_1
                     ENDIF
                  ENDIF
C     ENDIF
               ENDIF
            ENDIF
         ENDDO

*     sort b quark arrays for pt
         DO loop_1=1,NB
            DO loop_2=(loop_1+1),NB
               IF ( HZPT(B(loop_2)).gt.HZPT(B(loop_1)) ) THEN
                  exchange = B(loop_2)
                  B(loop_2) = B(loop_1)
                  B(loop_1) = exchange
               ENDIF
            ENDDO
         ENDDO
         DO loop_1=1,NBBAR
            DO loop_2=(loop_1+1),NBBAR
               IF ( HZPT(BBAR(loop_2)).gt.HZPT(BBAR(loop_1)) ) THEN
                  exchange = BBAR(loop_2)
                  BBAR(loop_2) = BBAR(loop_1)
                  BBAR(loop_1) = exchange
               ENDIF
            ENDDO
         ENDDO
         DO loop_1=1,NBBBAR
            DO loop_2=(loop_1+1),NBBBAR
               IF ( HZPT(BBBAR(loop_2)).gt.HZPT(BBBAR(loop_1)) ) THEN
                  exchange = BBBAR(loop_2)
                  BBBAR(loop_2) = BBBAR(loop_1)
                  BBBAR(loop_1) = exchange
               ENDIF
            ENDDO
         ENDDO

*     if two or more muons, check for muons from which b-quark in list bbbar they come from
         matched=.false.
         stepindex=0
         totindex=0
         IF ( NMU.ge.1 ) THEN
            DO loop_1=1,NMU
               IF ( NBBBAR.ge.1 ) THEN
                  DO loop_2=1,NBBBAR
                     matched=.false.
                     stepindex=0
                     totindex=0
                     IF ( JDAHEP(1,BBBAR(loop_2)).gt.0 ) THEN
                        IF ( JDAHEP(1,BBBAR(loop_2)).le.
     +                       JDAHEP(2,BBBAR(loop_2)) ) THEN
                           DO loop_3=JDAHEP(1,BBBAR(loop_2)),
     +                          JDAHEP(2,BBBAR(loop_2))
                              IF ( loop_3.eq.MU(loop_1,1) ) THEN
                                 MU(loop_1,2)=BBBAR(loop_2)
                                 matched=.true.
                                 stepindex=totindex
                              ELSE
                                 IF ( totindex.ge.maxarray ) THEN
                                    print*,xxxx,' ERROR: More than ',
     +                                   MAXARRAY,' entries in array'
                                    RETURN
                                 ELSE
                                    totindex=totindex+1
                                    array(totindex)=loop_3
                                 ENDIF
                              ENDIF
                           ENDDO
                        ELSE
                           IF ( JDAHEP(1,BBBAR(loop_2)).eq.MU(loop_1,1)
     +                          ) THEN
                              MU(loop_1,2)=BBBAR(loop_2)
                              matched=.true.
                              stepindex=totindex
                           ELSE
                              IF ( totindex.ge.maxarray ) THEN
                                 print*,xxxx,' ERROR: More than ',
     +                                MAXARRAY,' entries in array'
                                 RETURN
                              ELSE
                                 totindex=totindex+1
                                 array(totindex)=JDAHEP(1,BBBAR(loop_2))
                              ENDIF
                           ENDIF
                        ENDIF
                     ENDIF
                     IF ( .NOT.matched ) THEN
                        DO WHILE ( stepindex.lt.totindex )
                           IF ( .NOT.matched ) THEN
                              stepindex=stepindex+1
                              IF ( JDAHEP(1,array(stepindex)).gt.0) THEN
                                 IF ( JDAHEP(1,array(stepindex)).le.
     +                                JDAHEP(2,array(stepindex)) ) THEN
                                    DO loop_3=JDAHEP(1,
     +                                   array(stepindex)),
     +                                JDAHEP(2,array(stepindex))
                                       IF ( .NOT.Matched ) THEN
                                          IF ( loop_3.eq.MU(loop_1,1) 
     +                                         ) THEN
                                             MU(loop_1,2)=
     +                                            BBBAR(loop_2)
                                             matched=.true.
                                             stepindex=totindex
                                          ELSE
                                             IF ( totindex.ge.
     +                                            maxarray ) 
     +                                            THEN
                                                print*,xxxx,
     +                                               ' ERROR:', 
     +                                               ' More than ',
     +                                               MAXARRAY,
     +                                               ' entries in ',
     +                                               'array'
                                                RETURN
                                             ELSE
                                                totindex=totindex+1
                                                array(totindex)=
     +                                               loop_3
                                             ENDIF
                                          ENDIF
                                       ENDIF
                                    ENDDO
                                 ELSE
                                    IF ( JDAHEP(1,array(stepindex))
     +                                   .eq.MU(loop_1,1) ) THEN
                                       MU(loop_1,2)=BBBAR(loop_2)
                                       matched=.true.
                                       stepindex=totindex
                                    ELSE
                                       IF ( totindex.ge.maxarray ) 
     +                                      THEN
                                          print*,xxxx,
     +                                         ' ERROR: More than ',
     +                                         MAXARRAY,
     +                                         ' entries in array'
                                          RETURN
                                       ELSE
                                          totindex=totindex+1
                                          array(totindex)=
     +                                         JDAHEP(1,
     +                                         array(stepindex))
                                       ENDIF
                                    ENDIF
                                 ENDIF
                              ENDIF
                           ENDIF
                        ENDDO
                     ENDIF
                  ENDDO
               ENDIF
            ENDDO
         ENDIF

*     fill histogram, always remember to reset filled flag

*     fill histo A
         filled=.false.
         FILLPT=9999.99
         IF ( NB.gt.0.AND.NBBAR.gt.0.AND.NMU.ge.2 ) THEN
*     check if dimuon pair passes cuts.
            DO loop_1=1,NMU
               DO loop_2=(loop_1+1),NMU
                  IF ( FILLPT.eq.9999.99 ) THEN
                     if ( MU(loop_1,2).gt.0.AND.MU(loop_2,2).gt.0.AND.
     +                    MU(loop_1,2).ne.MU(loop_2,2) ) THEN
                        MMUMU=REAL(HZINVMAS(MU(loop_1,1),MU(loop_2,1)))
                        IF ( MMUMU.gt.6.0.AND.MMUMU.lt.35.0 ) THEN
                           pt1= HZPT(MU(loop_1,1))
                           pt2= HZPT(MU(loop_2,1))
                           if(pt1.ge.4.and.pt1.le.25.and.
     &                          pt2.ge.4.and.pt2.le.25.) then 
                              IF ( REAL(HZPT(MU(loop_1,1))).ge.
     +                          REAL(HZPT(MU(loop_2,1))) ) THEN
                                 FILLPT=REAL(HZPT(MU(loop_1,1)))
                                 CALL HFILL (1,FILLPT,0.,1.)
                                 ELSE
                                 FILLPT=REAL(HZPT(MU(loop_2,1)))
                                 CALL HFILL (1,FILLPT,0.,1.)
                              ENDIF
                           ENDIF
                        ENDIF
                     ENDIF
                  ENDIF
               ENDDO
            ENDDO
         ENDIF

*     fill histo B
         filled=.false.
         FILLPHI=9999.99
         IF ( NB.gt.0.AND.NBBAR.gt.0.AND.NMU.ge.2 ) THEN
*     check if dimuon pair passes cuts.
            DO loop_1=1,NMU
               DO loop_2=(loop_1+1),NMU
                  IF ( FILLPHI.eq.9999.99 ) THEN
                     if ( MU(loop_1,2).gt.0.AND.MU(loop_2,2).gt.0.AND.
     +                    MU(loop_1,2).ne.MU(loop_2,2) ) THEN
                        MMUMU=REAL(HZINVMAS(MU(loop_1,1),MU(loop_2,1)))
                        IF ( MMUMU.gt.6.0.AND.MMUMU.lt.35.0 ) THEN
                           FILLPHI=REAL(HZDPHI(MU(loop_1,1),
     +                          MU(loop_2,1)))/pi*180
                           pt1= HZPT(MU(loop_1,1))
                           pt2= HZPT(MU(loop_2,1))
c                           write(6,*) ' pt1, pt2 ',pt1,pt2 
                           if(pt1.ge.4.and.pt1.le.25.and.
     &                          pt2.ge.4.and.pt2.le.25.) then 
                                CALL HFILL (2,FILLPHI,0.,1.)
                           endif
                        ENDIF
                     ENDIF
                  ENDIF
               ENDDO
            ENDDO
         ENDIF

*     fill histo C
*     fill only b quark with hightest pt satisfying cuts
         filled=.false.
         IF ( NB.gt.0 ) THEN
            DO loop_1=1,NB
               IF ( .NOT.filled ) THEN
                  IF ( ABS(REAL(HZRAP(B(loop_1)))).lt.1.0 ) THEN
                     DO loop_2=1,NCBIN
                        bin=REAL(CBIN(loop_2)+
     +                       ((CBIN(loop_2+1)-CBIN(loop_2))/2))
                        IF ( REAL(HZPT(B(loop_1))).ge.bin ) THEN
                           CALL HFILL (3,bin,0.,1.)
                           filled=.true.
                        ENDIF
                     ENDDO
                  ENDIF
               ENDIF
            ENDDO
         ENDIF
         
*     fill histo D
*     fill only b quark with hightest pt satisfying cuts
         filled=.false.
         IF ( NB.gt.0 ) THEN
            DO loop_1=1,NB
               IF ( .NOT.filled ) THEN
                  IF ( ABS(REAL(HZRAP(B(loop_1)))).lt.1.0 ) THEN
                     DO loop_2=1,NDBIN
                        bin=REAL(DBIN(loop_2)+
     +                       ((DBIN(loop_2+1)-DBIN(loop_2))/2))
                        IF ( REAL(HZPT(B(loop_1))).ge.bin ) THEN
                           CALL HFILL (4,bin,0.,1.)
                           filled=.true.
                        ENDIF
                     ENDDO
                  ENDIF
               ENDIF
            ENDDO
         ENDIF

*     printout
         IF ( printout ) THEN
            IF ( NB.gt.0.OR.NBBAR.gt.0 ) THEN
               DO loop_1=1,NB
                  print*,'NB: ',loop_1,' id: ',B(loop_1),
     +                 ' mo1: ',JMOHEP(1,B(loop_1)),
     +                 ' mo2: ',JMOHEP(2,B(loop_1)),
     +                 ' da1: ',JDAHEP(1,B(loop_1)),
     +                 ' da2: ',JDAHEP(2,B(loop_1)),
     +                 ' isthep: ',ISTHEP(B(loop_1)),
     +                 ' phi: ',HZPHI(B(loop_1))+pi
               ENDDO
               DO loop_1=1,NBBAR
                  print*,'NBBAR: ',loop_1,' id: ',BBAR(loop_1),
     +                 ' mo1: ',JMOHEP(1,BBAR(loop_1)),
     +                 ' mo2: ',JMOHEP(2,BBAR(loop_1)),
     +                 ' da1: ',JDAHEP(1,BBAR(loop_1)),
     +                 ' da2: ',JDAHEP(2,BBAR(loop_1)),
     +                 ' isthep: ',ISTHEP(BBAR(loop_1)),
     +                 ' phi: ',HZPHI(BBAR(loop_1))+pi
               ENDDO
               DO loop_1=1,NBBBAR
                  print*,'NBBBAR: ',loop_1,' id: ',BBBAR(loop_1),
     +                 ' mo1: ',JMOHEP(1,BBBAR(loop_1)),
     +                 ' mo2: ',JMOHEP(2,BBBAR(loop_1)),
     +                 ' da1: ',JDAHEP(1,BBBAR(loop_1)),
     +                 ' da2: ',JDAHEP(2,BBBAR(loop_1)),
     +                 ' isthep: ',ISTHEP(BBBAR(loop_1)),
     +                 ' phi: ',HZPHI(BBBAR(loop_1))+pi
               ENDDO
            ENDIF
            IF ( NMU.GT.0 ) THEN
               DO loop_1=1,NMU
                  print*,'NMU: ',loop_1,' id: ',MU(loop_1,1),
     +                 ' QUARK: ',MU(loop_1,2),' pt: ',
     +                 REAL(HZPT(MU(loop_1,1))),' eta: ',
     +                 REAL(HZETA(MU(loop_1,1)))
               ENDDO
            ENDIF
            IF ( NB.gt.0.OR.NBBAR.gt.0.OR.NMU.GT.0 ) THEN
               DO loop_1=1,NHEP
                  print*,'id: ',loop_1,
     +                 ' idhep: ',IDHEP(loop_1),
     +                 ' isthep: ',ISTHEP(loop_1),
     +                 ' mo1: ',JMOHEP(1,loop_1),
     +                 ' mo2: ',JMOHEP(2,loop_1),
     +                 ' da1: ',JDAHEP(1,loop_1),
     +                 ' da2: ',JDAHEP(2,loop_1)
               ENDDO
               
            ENDIF
            
         ENDIF
         
      ELSE IF (iflag.eq.3) THEN
         CALL HCDIR('//PAWC/'//xxxx,' ')

*     initialisation
         norm = 0.

         IF (Xsec.eq.0) THEN
            PRINT*,xxxx,': termination called with zero cross 
     +           section'
            PRINT*,'          cross section graph meaningless'
            Xsec=1
         ENDIF
         IF (Ntot.eq.0) THEN
            PRINT*,xxxx,' no total events'
            PRINT*,'          cross section graph meaningless'
            Ntot=1
         ENDIF
         norm=XSEC/Ntot/1000.

         write(6,*) xxxx,': ntot= ', ntot,' xsec (nb)= ',xsec
         print*,'norm: ',norm


*     normalize to nb, diff cross sections
         CALL HZHINRM(1,0,1./norm,1)

*     normalize to nb and 20 degree bins
         CALL HOPERA(2,'+e',2,2,norm,0.)

* normalize to nb, cross sections
         CALL HOPERA(3,'+e',3,3,norm,0.)
         CALL HOPERA(4,'+e',4,4,norm,0.)

      ELSE
         WRITE(6,*) xxxx,' Unknown flag',iflag
      ENDIF
      RETURN
      END        

















