      SUBROUTINE HZ02228(iflag)
c     ----------------------------------------------------------------------
c     by C Targett-Adams
c

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c                 							     c
c			INTRODUCTION					     c
c									     c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     HZTOOL routine for ZEUS paper DESY-02-0228:
c     'Scaling violations and determination of alpha_s from jet production
c     in gamma-proton interactions at HERA'
c     By the ZEUS Collaboration.
c
c     This photoproduction routine has to be run twice with the 
c     following code additions:
c     +1000 for the DIRECT component run,
c     +2000 for the RESOLVED component run,
c     +0 for both together
c     for all three phases (iflag=1,2,3)
c
c     +10000 to run on parton showers instead of final state particles.
c     +100000 is used by NLO integration options.
c
c     iflag = 1,2 or 3 depending on whether it is the initialization,
c     processing or termination phase (respectively)
c
c     The default jetfinder is KTCLUS.	
c     To change jetfinder use these values to call the initialisation
c     phase.
c     (1,2 or 3) + 10 x chjet (chjet = jetfinder number (see HZTOOL man 
c     under routine HZJTFIND)
c     So if 0 is chosen then the default finder is used (i.e. that used
c     in the paper). Examples
c     iflag=11041 : Parton showers selected, Jetfinder 3 (GPCONE finder),
c                   Direct component run, Intialization phase.
c
c     iflag=2002  : Resolved component run, default jetfinder (KTCLUS in
c     this papers case), processing phase.
c
c     The <xT> bins are not explicitly specified in the paper but they 
c     are as follows:
c
c     0.193 - 0.230
c     0.230 - 0.267
c     0.267 - 0.322
c     0.322 - 0.377
c     0.377 - 0.579
c
c     Histograms ID:
c
c     id 11     dsigma/dETjet (pb/GeV) versus ETjet (GeV) (fig 1) 
c	
c     id 12     (ETjet^4)<(Ejet)(d^3)(sigma)/dpxdpydpz>_et vs <xT>
c               W=180GeV (fig 2a)
c
c     id 13     (ETjet^4)<(Ejet)(d^3)(sigma)/dpxdpydpz>_et vs <xT>
c               W=255GeV (fig 2b)
c
c     id 14     Ratio of id 12 and id 13 plots vs xT (fig 3)
c
c     The histograms labelled 31-40 contain ETjet distributins in different
c     regions of xT. These are used in the imtermediate stages of the
c     calculation of the scale invariant cross sections (id 12 and 13).
c
c     The cuts used are explained in the cuts section below
c

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									     c
c				BEGIN ROUTINE				     c
c									     c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc


      IMPLICIT NONE

c     These included files contain function declarations and various 
c     parameter declarations which are required by the hztool routines.
c     In particular Xsec and Ntot (global variables) are defined in 
c     'heracmn.inc'

#include "hepevtp.inc"
#include "heracmn.inc"
#include "hzfunc.inc"
#include "hzjetcmn.inc"

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									     c
c				FUNCTION DECLARATIONS			     c
c									     c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     Function declaration for HBOOK function HSTATi which calculates the
c     statistics (mean, standard deviation etc) of a histogram.

      REAL HSTATi 
      CHARACTER*4 hist

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									     c
c			MISC VARIABLE DECLARATIONS			     c
c									     c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

      CHARACTER*6 xxxx
      DATA xxxx /'d02228'/

c     Define number of xT bins

      INTEGER   no_xt
      PARAMETER (no_xt=5)

c     Define number of bins for Table 1 data.

      INTEGER no_etjet_bins
      PARAMETER (no_etjet_bins=9)

c     Various counters to be used in loops

      INTEGER i_etxt,i_bin,i_jet,j_jet,i_plot,i_book

c     N_jet is the number of jets lying in the correct ET range. This is
c     used in the processing (Monte Carlo) section

      INTEGER N_jet

c     The index array is used in the processing stage to store the indices
c     of the Jets array (see 'Jet stuff' below) which contain jets in the
c     relevant energy range i.e. 17 <= ETjet <= 95 GeV. The size of this
c     array is defined to be the maximum number of jets that can be found 
c     (i.e 50 -> Jets(50,8)).

      INTEGER index(50)

c     s denotes the electron proton center of mass energy. q2 is the 
c     4-momentum transfer squared.

      REAL E_e,E_p,s,q2,y

c     Electron beam energy is 27.5GeV and the proton beam energy is 920GeV 
	
      PARAMETER (E_e=27.5 , E_p=920.)

c     Variables used for the calulation of W_gamma_proton and the rapidity
c     in the gamma_proton centre of mass frame.

      REAL W,eta_gamma_p

c     Corrective factor for boosting the rapidity from the lab frame in to 
c     the gamma_proton centre of mass frame.

      REAL eta_correct

c     The photon flux correction factor flux_correct is needed in the 
c     calculation of ratio of scaled invariant cross sections (figure 2).
c     The factor corrects for the difference in the photon fluxes in the
c     two respective regions of W_gamma_proton

      REAL flux_correct
      PARAMETER (flux_correct=0.663) 

c     elecE is the initial state electron energy. myip, myil and hzflag
c     are variables required in routine HZIBEAM

      DOUBLE PRECISION elecE
      INTEGER myil, myip, hzflag

c     lp is used to select whether or not certain parameters should
c     be printed out on screen each time the routine is called

      LOGICAL lp
      DATA lp / .false. /

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									     c
c				    CUTS				     c
c									     c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     Define cut arrays.

      REAL q2_cut,etjet_cut(2), rapidity_cut(2), rapidity_gam_cut(2),
     &     W_180_cut(2), W_255_cut(2), xt_cut(2), y_cut(2)

c     Q^2 <= 1 GeV^2 is a standard cut used to select photoproduction
c     events 

      DATA q2_cut / 1. /

c     0.2 <= y <= 0.85 GeV. Cut on y used in the paper. 

      DATA y_cut / 0.2 , 0.85 /

c     Jets(in Table 1) are considered in the range of 17GeV<=ETjet<=95GeV.

      DATA etjet_cut / 17. , 95. /

c     rapidity_cut contains the rapidity cuts made in the lab frame.

      DATA rapidity_cut / -1. , 2.5 /     

c     rapidity_gam_cut conatins the rapidity cuts made in the gamma
c     proton center of mass frame. 

      DATA rapidity_gam_cut / -2. , 0. /

c     W_180_cut and W_255_cut conatins the cuts used to produce the 
c     Table 2 graphs. 

      DATA W_180_cut / 161. , 191. /
      DATA W_255_cut / 240. , 270. /

c     Table 2 figures require xT to be in the range 0.193<=xT<=0.579

      DATA xt_cut / .193 , .579 /

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									     c
c			MISC DECLARATIONS				     c
c									     c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     Arrays to be used in the calculation of <ET_xT(i)> in the terminatio
c     routine

      INTEGER no_et_xt_bins
      PARAMETER (no_et_xt_bins=100)
      REAL et_xt(no_et_xt_bins+1)
      SAVE et_xt

c     Error arrays. These will be the arrays which store the combined 
c     statistical, systematic and jet scale uncertainties. Used in the
c     termination phase.

      REAL dsigma_err(no_etjet_bins), dsigma_w180_err(no_xt),
     &     dsigma_w255_err(no_xt), ratio_err(no_xt)

c     These factors are used in the termination routine in the 
c     final calculation of the histograms.

      INTEGER factor1
      REAL hbar_c, pi, w_180, w_255,factor_w180,factor_w255
      REAL xt_et_w180_mean(no_xt),xt_et_w255_mean(no_xt),
     &     xt_et_w180_errs(no_xt),xt_et_w255_errs(no_xt)

      DATA xt_et_w180_errs / no_xt*0. /
      DATA xt_et_w255_errs / no_xt*0. /

      PARAMETER (hbar_c=0.389E6, factor1=2000, pi=3.1415927,
     &          w_180=180,w_255=255)


c     Define and fill arrays containing bin width errors. These are
c     trivially zero. They are needed later in the termination section.


c     Variables used in the 'Extract iflag parameters section'

      INTEGER iproc,iflag
      LOGICAL parton_showers

c     Variables required to help calculate histogram means. See termination
c     section.

      REAL mean_w180, mean_w255, lumpb

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									     c
c   			    JET RELATED STUFF				     c
c									     c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     x_T will be used in the processing stage. x_T=(2*ETjet)/W

      REAL x_T

c     Declaration for jetf variable to be used in hztool routine
c     HZJTNAME(chjet,jetf).

      CHARACTER*6 jetf
      INTEGER chjet
      SAVE chjet

c     Choose the same jet finder as in the paper (KTCLUS). 
      DATA   chjet / 3 / 

c     The following variables are used in hztool routine 
c     HZJTFIND(chjet,CONER,NJET,Jets). Jets must me a 50x8 array.
c     The maximum number of jets is 50.

      INTEGER NJET
c      DOUBLE PRECISION Jets(50,8)
      DOUBLE PRECISION CONER	
      SAVE CONER

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									     c
c				DATA					     c
c									     c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

ccccccccccccccccccccccccc
c			c
c      TABLE 1		c
c			c
ccccccccccccccccccccccccc

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     Table 1: Put data from Table 1 in to arrays.

c     1.(a) - Define and fill  <ETjet> (GeV) array.

      REAL etjet(no_etjet_bins+1)
      DATA etjet / 17.,21.,25.,29.,35.,41.,47.,55.,71.,95. /  

c     1.(b) - Define and fill dsigma/dETjet (pb) array.

      REAL dsigma(no_etjet_bins)
      DATA dsigma / 290.,97.,37.6,14.2,4.7,1.64,.59,.120,.0109 /

c     1.(c) - Define and fill dsigma/dETjet statistical errors array (pb)
	
      REAL dsigma_stat_err(no_etjet_bins)
      DATA dsigma_stat_err / 1.,1.,.3,.2,.1,.06,.03,.01,.0024 /

c     1.(d) - Define and fill dsigma/dETjet systematic errors array (pb).
c             jet scale uncertainty is added to the systeamtic errors
c             in quadrature. These will need to be square rooted later.

      REAL dsigma_sys_err_up(no_etjet_bins)
      DATA dsigma_sys_err_up /
     &     317.,
     &     32.,
     &     9.32,
     &     1.64,
     &     0.13,
     &     0.0181,
     &     0.0018,
     &     0.000145,
     &     2.02e-06/

      REAL dsigma_sys_err_down(no_etjet_bins)
      DATA dsigma_sys_err_down /
     &     340.,
     &     32.,
     &     10.37,
     &     1.49,
     &     0.18,
     &     0.0225,
     &     0.0025,
     &     0.000145,
     &     2.5e-06/
	
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

ccccccccccccccccccccccccc
c		        c
c	TABLE 2		c	
c			c
ccccccccccccccccccccccccc

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     Table 2: Put data from Table 2 in to arrays

c     2.(a) - W_gamma_p = 180 GeV. Relevant variables will be labelled
c             with 'w180'.

c     Define and fill <xT> array. These values aren't explicitly given in
c     the paper (see the introduction).

      REAL xt(no_xt+1)
      DATA xt / .193,.23,.267,.322,.377,.579 /

c     Define and fill (ETjet^4)<(Ejet)(d^3)(sigma)/dpxdpydpz>_eta
c     (x0.389x10^6) arrays.
	
      REAL dsigma_w180(no_xt)
      DATA dsigma_w180 / 18.7,12.3,7.38,4.14,1.36 /

c     Define and fill dsigma_w180 statistical error array

      REAL dsigma_w180_stat_err(no_xt)
      DATA dsigma_w180_stat_err / .2,.2,.15,.15,.06 /

c     Define and fill dsigma_w180/dxT systematic errors array (pb).
c     jet scale uncertainty is added to the systeamtic errors
c     in quadrature. These will need to be square rooted later.

      REAL dsigma_w180_sys_err_up(no_xt)
      DATA dsigma_w180_sys_err_up /
     &     1.7,
     &     0.41,
     &     0.3697,
     &     0.2554,
     &     0.0338/
       
      REAL dsigma_w180_sys_err_down(no_xt)
      DATA dsigma_w180_sys_err_down /
     &     1.7,
     &     0.52,
     &     0.377,
     &     0.2601,
     &     0.037/

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     2.(b) - W_gamma_p = 255 GeV. Relevant variables will be labelled
c             with 'w255'.

c     Define and fill (ETjet^4)<(Ejet)(d^3)(sigma)/dpxdpydpz>_eta
c     (x0.389x10^6) arrays.

      REAL dsigma_w255(no_xt)
      DATA dsigma_w255 / 10.2,6.86,4.41,2.12,.66 /

c     Define and fill dsigma_255 statistical error array

      REAL dsigma_w255_stat_err(no_xt)
      DATA dsigma_w255_stat_err / .2,.2,.17,.15,.06 /

c     Define and fill dsigma_w255/dxT systematic errors array (pb).
c     jet scale uncertainty is added to the systeamtic errors
c     in quadrature. These will need to be square rooted later.

      REAL dsigma_w255_sys_err_up(no_xt)
      DATA dsigma_w255_sys_err_up /
     &     0.32,
     &     0.2896,
     &     0.0628,
     &     0.0557,
     &     0.008/
       
      REAL dsigma_w255_sys_err_down(no_xt)
      DATA dsigma_w255_sys_err_down /
     &     0.32,
     &     0.3536,
     &     0.0884,
     &     0.0296,
     &     0.0089/

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     2.(c) - Ratio. Relevant variables will be labelled
c             with 'ratio'.

c     Define and fill ratio array.
	
      REAL ratio(no_xt)
      DATA ratio / 1.21,1.19,1.11,1.3,1.37 /

c     Define and fill ratio statistical error array

      REAL ratio_stat_err(no_xt)
      DATA ratio_stat_err / .03,.04,.05,.1,.13 /

c     Define and fill ratio systematic errors array (pb).
c     jet scale uncertainty is added to the systeamtic errors
c     in quadrature. These will need to be square rooted later.

      REAL ratio_sys_err_up(no_xt)
      DATA ratio_sys_err_up /
     &     0.0082,
     &     0.005,
     &     0.0068,
     &     0.0137,
     &     0.0122/
       
      REAL ratio_sys_err_down(no_xt)
      DATA ratio_sys_err_down /
     &     0.0081,
     &     0.0053,
     &     0.0064,
     &     0.0122,
     &     0.0125/

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									      c
c			MISC CALCULATIONS				      c
c									      c
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     The figures in table 2 have are the true cross section multiplied by
c     hbar_c. We want the true cross section so we must divide the table 2
c     data by hbar_c. This section of code is dangerous. 

c      DO i_bin=1,no_xt
c         dsigma_w180(i_bin)=dsigma_w180(i_bin)/1.5
c         dsigma_w255(i_bin)=dsigma_w255(i_bin)/1.5
c         write(hzunit,*) dsigma_w180(i_bin) 
c      ENDDO


c     Calculate the centre of mass energy squared

      s=4*E_e*E_p

c     Cone radius for jet finder. The standard cone radius is 1.00. 
c     HZJETRAD(2,CONER). The first argument is set to return the cone
c     radius in CONER. This must be called before histogram 'initialisation'

      CALL HZJETRAD(2,CONER)

      IF (CONER.lt.0.0) THEN
         CONER=1.0
      ENDIF

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									      c
c		 	EXTRACT IFLAG PARAMETERS			      c
c									      c
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c     Parton showers variable set to default value of false

      parton_showers = .FALSE.
	      
*     Determine the process type.
      iproc=(mod(iflag,10000)/1000)
      if ((iproc.lt.0).or.(iproc.gt.2)) then
         write(HZUNIT,*) 'HZ',xxxx,': illegal IPROC:',iproc
         return
      endif
      
*     --- choose jet finder
      IF ((MOD(iflag,100)/10.gt.0).and.MOD(iflag,10).eq.1) THEN
         chjet=INT(MOD(iflag,100)/10)
      ENDIF
      
*     Decide whether we are running on parton showers or final state particles.
      IF (MOD(iflag,100000)/10000.gt.0) THEN
         parton_showers=.TRUE.
*     use a different paw directory for parton showers.
         xxxx = 'PS'//xxxx
         chjet=-1*ABS(chjet)
      ENDIF
      
      CALL HZJTNAME(chjet,jetf)
      
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									      c
c			INITIALIZATION					      c
c									      c
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

      IF (MOD(iflag,10).eq.1) THEN
         
c     Create directories. This always needs to be done
         
         IF (iproc.le.1) THEN
            CALL HCDIR('//HISTO',' ')
            IF (parton_showers) THEN
               CALL HMDIR('ps'//xxxx,'S')
               CALL HCDIR('//PAWC',' ')
               CALL HMDIR('ps'//xxxx,'S')
            ELSE
               CALL HMDIR(xxxx,'S')
               CALL HCDIR('//PAWC',' ')
               CALL HMDIR(xxxx,'S')
            ENDIF
            
c     Now we need book the data dsigma/dETjet plot (figure 1)
c     We also need to sort out the errors. The systematic erros
c     are asymmetric. HBOOK is incapable of dealing with asymmetric
c     errors so we need to displace each data point so that it lies
c     in the center of each systematic error band. The statistical 
c     error band is assumed to move along with the point i.e. so
c     that by moving the point we are not making the statistical
c     error band assymetric.

c     Book the data dsigma/dETjet plot (figure 1). 	      
	     
            CALL HBOOKB(-11,'DATA: dsigma/dETjet,ETjet',no_etjet_bins,
     &	            etjet,0.)	

c     Now let's square root the errors that we added in quadrature
c     in the 'Data: Table 1' section
            
            DO i_bin=1,no_etjet_bins
               dsigma_sys_err_up(i_bin)=SQRT(dsigma_sys_err_up(i_bin))
               dsigma_sys_err_down(i_bin)=SQRT(dsigma_sys_err_down(i_bin
     $              ))
               
c     Now lets find the combined error
               
               dsigma_err(i_bin)=SQRT((dsigma_stat_err(i_bin)**2)+
     &              0.25*((dsigma_sys_err_up(i_bin)+
     &              dsigma_sys_err_down(i_bin))**2))
               
c     Now let's alter the data point so that it lies at the midpoint
c     of the systematic error bar.
               
               dsigma(i_bin)=dsigma(i_bin)+
     &              0.5*(dsigma_sys_err_up(i_bin)-
     &              dsigma_sys_err_down(i_bin))
               
            ENDDO
            
c     Now fill the histogram
            
            CALL HPAK(-11,dsigma)
            CALL HPAKE(-11,dsigma_err)
            
c     Table 1 data has now been booked. Now lets work on Table 2.
            
            CALL HBOOKB(-12,
     &           'DATA: (ETjet^4)<(Ejet)(d^3)(sigma)/dpxdpydpz>_et,
     &           xT (W = 180GeV)', no_xt, xt, .0)
            
            CALL HBOOKB(-13,
     &           'DATA: (ETjet^4)<(Ejet)(d^3)(sigma)/dpxdpydpz>_et,
     &           xT (W = 255GeV)', no_xt, xt, .0)
            
            CALL HBOOKB(-14, 'DATA: Ratio, xt', no_xt, xt, .0)
            
            DO i_bin=1,no_xt
               
c     Square root all errors. The next block of code is in an identical
c     lay out to the do loop above this one.
               
               dsigma_w180_stat_err(i_bin)=(1/hbar_c)*
     &              dsigma_w180_stat_err(i_bin)
               
               dsigma_w255_stat_err(i_bin)=(1/hbar_c)*
     &              dsigma_w180_stat_err(i_bin)
               
               dsigma_w180_sys_err_up(i_bin)=
     &              (1/hbar_c)*SQRT(dsigma_w180_sys_err_up(i_bin))   
               
               dsigma_w180_sys_err_down(i_bin)=
     &              (1/hbar_c)*SQRT(dsigma_w180_sys_err_down(i_bin))
               
               dsigma_w255_sys_err_up(i_bin)=
     &              (1/hbar_c)*SQRT(dsigma_w255_sys_err_up(i_bin))   
               
               dsigma_w255_sys_err_down(i_bin)=
     &              (1/hbar_c)*SQRT(dsigma_w255_sys_err_down(i_bin))
               
               ratio_sys_err_up(i_bin)=
     &              SQRT(ratio_sys_err_up(i_bin))   
               
               ratio_sys_err_down(i_bin)=
     &              SQRT(ratio_sys_err_down(i_bin))
               
               dsigma_w180_err(i_bin)=SQRT((dsigma_w180_stat_err(i_bin)
     $              **2)+(0.25*((dsigma_w180_sys_err_up(i_bin)
     $              +dsigma_w180_sys_err_down(i_bin))**2)))      
               
               dsigma_w255_err(i_bin)=SQRT((dsigma_w255_stat_err(i_bin)
     $              **2)+(0.25*((dsigma_w255_sys_err_up(i_bin)
     $              +dsigma_w255_sys_err_down(i_bin))**2)))
               
               ratio_err(i_bin)=SQRT((ratio_stat_err(i_bin)**2)
     &              +(0.25*((ratio_sys_err_up(i_bin)
     &              +ratio_sys_err_down(i_bin))**2)))
               
               dsigma_w180(i_bin)=(1/hbar_c)*(dsigma_w180(i_bin)+
     &              0.5*(dsigma_w180_sys_err_up(i_bin)-
     &              dsigma_w180_sys_err_down(i_bin)))
               
               dsigma_w255(i_bin)=(1/hbar_c)*(dsigma_w255(i_bin)+
     &              0.5*(dsigma_w255_sys_err_up(i_bin)-
     &              dsigma_w255_sys_err_down(i_bin)))
               
               ratio(i_bin)=ratio(i_bin)+
     &              0.5*(ratio_sys_err_up(i_bin)-
     &              ratio_sys_err_down(i_bin))
               
            ENDDO
            
            CALL HPAK(-12,dsigma_w180)
            CALL HPAKE(-12,dsigma_w180_err)
            CALL HPAK(-13,dsigma_w255)
            CALL HPAKE(-13,dsigma_w255_err)
            CALL HPAK(-14,ratio)
            CALL HPAKE(-14,ratio_err)
            

c     Now we need the histograms which will be used to calculate <ET_xT(i)>.
c     These will not be plotted but are needed in an intermediate step in
c     the calculation of the scale invariant cross section.


c     Book the ratio vs xT plot (figure 3)

            CALL HBOOKB(14, 'MC: Ratio, xt', no_xt, xt, .0)

c     Fill arrays to be used in the intermediate calculation of the scale
c     invariant cross section.
      
            DO i_etxt=1,no_et_xt_bins+1
               et_xt(i_etxt)=i_etxt-1
            ENDDO 

         ENDIF

         IF (parton_showers) THEN
            CALL HCDIR('//HISTO/ps'//xxxx,' ')
            CALL HCDIR('//PAWC/ps'//xxxx,' ')
         ELSE
            CALL HCDIR('//HISTO/'//xxxx,' ')
            CALL HCDIR('//PAWC/'//xxxx,' ')
         ENDIF

c     Now we need the individual direct and resolved plots corresponding
c     to the above plots.

         CALL HBOOKB(iproc*100+11,'MC: dsigma/dETjet,ETjet',
     $        no_etjet_bins,etjet,.0)	      

         CALL HBOOKB(iproc*100+12,
     &        'MC: (ETjet^4)<(Ejet)(d^3)(sigma)/dpxdpydpz>_et,
     &        xT (W = 180GeV)', no_xt, xt, .0)	   
         
         CALL HBOOKB(iproc*100+13,
     &        'MC: (ETjet^4)<(Ejet)(d^3)(sigma)/dpxdpydpz>_et,
     &        xT (W = 255GeV)', no_xt, xt, .0)
         
c     Now the intermediate plots

         CALL HBOOKB(iproc*100+31,'180: <ET> for xT bin 1',
     &        no_et_xt_bins,et_xt,.0)
         
         CALL HBOOKB(iproc*100+32,'180: <ET> for xT bin 2',
     &        no_et_xt_bins,et_xt,.0)
         
         CALL HBOOKB(iproc*100+33,'180: <ET> for xT bin 3',
     &        no_et_xt_bins,et_xt,.0)
         
         CALL HBOOKB(iproc*100+34,'180: <ET> for xT bin 4',
     &        no_et_xt_bins,et_xt,.0)
         
         CALL HBOOKB(iproc*100+35,'180: <ET> for xT bin 5',
     &        no_et_xt_bins,et_xt,.0)
         
         CALL HBOOKB(iproc*100+36,'255: <ET> for xT bin 1',
     &        no_et_xt_bins,et_xt,.0)
         
         CALL HBOOKB(iproc*100+37,'255: <ET> for xT bin 2',
     &        no_et_xt_bins,et_xt,.0)
         
         CALL HBOOKB(iproc*100+38,'255: <ET> for xT bin 3',
     &        no_et_xt_bins,et_xt,.0)
         
         CALL HBOOKB(iproc*100+39,'255: <ET> for xT bin 4',
     &        no_et_xt_bins,et_xt,.0)
         
         CALL HBOOKB(iproc*100+40,'255: <ET> for xT bin 5',
     &        no_et_xt_bins,et_xt,.0)

 	      
         WRITE(HZUNIT,*)'**********************************************'
         WRITE(HZUNIT,*)'* HZ02228 called, histograms will be output. *'
         WRITE(HZUNIT,*)'*     Jet finder selected : ',jetf
     $        ,'           *'
         WRITE(HZUNIT,1001)'*        with cone radius : ',CONER,'   *'
         WRITE(HZUNIT,*)'**********************************************'

 1001    FORMAT(A29,F5.2,A13)

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									     c
c				PROCESSING				     c
c									     c
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

      ELSE IF (MOD(iflag,10).eq.2) THEN

c     Change directory to our graphs

         IF (parton_showers) THEN              
            CALL HCDIR('//PAWC/ps'//xxxx,' ')
         ELSE
            CALL HCDIR('//PAWC/'//xxxx,' ')
         ENDIF	

c     Now the NLO stuff. HO1 is the NLO generator.

         IF (gen(1:3).EQ.'HO1') THEN

            DO i_plot=11,13
               CALL HZSNLO(i_plot,i_plot+200,i_plot+100)
            ENDDO

            DO i_plot=31,40
               CALL HZSNLO(i_plot,i_plot+200,i_plot+100)
            ENDDO

            iproc = 1

         ENDIF

c     Get value for Q^2

         q2=hzphokin(1)

c        Check that the value of q2 is sound.

         IF (q2.eq.-1) THEN
            PRINT* , 'HZ02228: HZPHOKIN returns error for Q^2 (q2)'
         ELSEIF (q2.lt.0) THEN
            q2=abs(q2)
         ENDIF
	
c        Get value for y

         y=hzphokin(3) 

c        Check that the value of y is sound

         IF (y.eq.-1) THEN
            PRINT* , 'HZ02228: HZPHOKIN returns error for y'
         ENDIF

c        All events must pass the y cut (or the W cut which is the same) 
c        and the Q^2 cut.

         IF ((y.ge.y_cut(1)).AND.(y.le.y_cut(2))
     &      .AND.(q2.lt.q2_cut)) THEN

c     Calculate the gamma_proton centre of mass energy via the equation 
c     W=sqrt(s*y).

            W=SQRT(s*y)

c     Calculate the correction factor for boosting the rapidity in to the 
c     gamma_proton center of mass frame. See page 5 of the paper.

            eta_correct=LOG((2*E_p)/W)
	   
c     Get initial state electron energy

            hzflag=HZIBEAM(myip,myil)

c     If hzflag=0 then only a lepton beam is found. See page 95 of
c     the hztool manual.
	
            IF (hzflag.ge.0) THEN
               elecE=abs(PHEP(4,myil))
            ELSE
               PRINT* , 'HZ02228: Electron not found. E=0.001'
               PRINT* , '         event will be rejected'
               RETURN
            ENDIF

c     Find the jets

            CALL HZJTFIND(chjet,CONER,NJET,Jets)

            IF (lp) THEN
               WRITE(HZUNIT,*) 'Njet=', NJET
            ENDIF

c     We want to consider only the jets with ETjet in the range 
c     17 <= ETjet <= 95 GeV. Count how many of the jets found fall
c     in this range.  

            i_jet=0
            DO j_jet=1,NJET
               IF ((Jets(j_jet,3).ge.etjet_cut(1)).AND.
     &            (Jets(j_jet,3).le.etjet_cut(2))) THEN
                  i_jet=i_jet+1
                  index(i_jet)=j_jet
               ENDIF
            ENDDO 

c     Size of the index array is N_jet

            N_jet=i_jet

c     Now isolate indices of jets in the Jets array which satisfy the
c     Rapidity (in the lab frame) cuts.	      

            DO j_jet=1,N_jet
               IF ((Jets(index(j_jet),1).ge.rapidity_cut(1)).AND.
     &            (Jets(index(j_jet),1).le.rapidity_cut(2))) THEN

c     All jets which fullfill this cut can be used to fill the figure 
c     one data (histogram iproc*100+11). The variable wtx is a global 
c     variable defined in 'heracmn.inc'. The X channel array has to be 
c     real. Jets was defined as a double precision array

                  CALL HFILL(iproc*100+11,REAL(Jets(index(j_jet),3))
     &                      ,0.,wtx)

c     Now we will work on the filling of the Table 2 histograms (iproc*100+12
c     and +13).
                  IF (((Jets(index(j_jet),1)-eta_correct).ge.
     &               rapidity_gam_cut(1)).AND.
     &	             ((Jets(index(j_jet),1)-eta_correct).le.
     &               rapidity_gam_cut(2))) THEN	

                     x_T=(2*Jets(index(j_jet),3))/W

                     IF((x_T.ge.xt_cut(1)).AND.(x_T.lt.xt_cut(2))) THEN

c     Having isolated the correct rapidity region for the table 2 plots
c     now we pick out the relevant W_gamma_proton regions. 

                        IF ((W.ge.W_180_cut(1)).AND.
     &                      (W.le.W_180_cut(2))) THEN
	 
                           CALL HFILL(iproc*100+12,x_T,0.,wtx)
	 
                           IF ((x_T.ge.xt(1)).AND.(x_T.lt.xt(2))) 
     &                        THEN
                              CALL HFILL(iproc*100+31,
     &                              REAL(Jets(index(j_jet),3)),0.,wtx)

                           ELSEIF ((x_T.ge.xt(2)).AND.
     &                             (x_T.lt.xt(3))) THEN
                              CALL HFILL(iproc*100+32,
     &                              REAL(Jets(index(j_jet),3)),0.,wtx)

                           ELSEIF ((x_T.ge.xt(3)).AND.
     &                             (x_T.lt.xt(4))) THEN
                              CALL HFILL(iproc*100+33,
     &                              REAL(Jets(index(j_jet),3)),0.,wtx)

                           ELSEIF ((x_T.ge.xt(4)).AND.
     &                             (x_T.lt.xt(5))) THEN
                              CALL HFILL(iproc*100+34,
     &                              REAL(Jets(index(j_jet),3)),0.,wtx)

                           ELSEIF ((x_T.ge.xt(5)).AND.
     &                             (x_T.lt.xt(6))) THEN
                              CALL HFILL(iproc*100+35,
     &                              REAL(Jets(index(j_jet),3)),0.,wtx)
                           ENDIF

                        ELSEIF ((W.ge.W_255_cut(1)).AND.
     &                          (W.le.W_255_cut(2))) THEN

                           CALL HFILL(iproc*100+13,x_T,0.,wtx)

                           IF ((x_T.ge.xt(1)).AND.
     &                         (x_T.lt.xt(2))) THEN
                              CALL HFILL(iproc*100+36,
     &                              REAL(Jets(index(j_jet),3)),0.,wtx)

                           ELSEIF ((x_T.ge.xt(2)).AND.
     &                             (x_T.lt.xt(3))) THEN
                              CALL HFILL(iproc*100+37,
     &                              REAL(Jets(index(j_jet),3)),0.,wtx)

                           ELSEIF ((x_T.ge.xt(3)).AND.
     &                             (x_T.lt.xt(4))) THEN
                              CALL HFILL(iproc*100+38,
     &                              REAL(Jets(index(j_jet),3)),0.,wtx)

                           ELSEIF ((x_T.ge.xt(4)).AND.
     &                             (x_T.lt.xt(5))) THEN
                              CALL HFILL(iproc*100+39,
     &                              REAL(Jets(index(j_jet),3)),0.,wtx)

                           ELSEIF ((x_T.ge.xt(5)).AND.
     &                             (x_T.lt.xt(6))) THEN
                              CALL HFILL(iproc*100+40,
     &                              REAL(Jets(index(j_jet),3)),0.,wtx)
                           ENDIF
                        ENDIF
                     ENDIF
                  ENDIF
               ENDIF
            ENDDO
c	Quite a few ENDIF's here. The next ENDIF is for the IF statement that 
c	selects photoproduction events and selects events within the 
c	correct y range
	   
         ENDIF
         
c     End the processing IF statement.

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c									      c
c				TERMINATION				      c
c									      c
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

      ELSE IF (MOD(iflag,10).eq.3) THEN


         IF (iproc.EQ.2.or.iproc.EQ.0) THEN
            WRITE (HZUNIT,*) 'HZ02228: finishing off'
         ENDIF

c     Now we will begin the final stage. First change directories
         
         IF (parton_showers) THEN
            CALL HCDIR('//PAWC/ps'//xxxx,' ')
         ELSE
            CALL HCDIR('//PAWC/'//xxxx,' ')
         ENDIF
         
c     Check soundness of Xsec and Ntot variables. These are global variables
c     declared in the 'heracmn.inc' file.
         
         IF (Xsec.eq.0) THEN
            PRINT*,'HZ02228: Termination called with zero cross section'
            PRINT*,'          cross section graph meaningless'
            PRINT*,'          in process :',iproc*1000
            Xsec=1
         ENDIF
         
         IF (Ntot.eq.0) THEN
            PRINT*,'HZ02228: Termination called with no total events'
            PRINT*,'          cross section graph meaningless'          
	    PRINT*,'		in process :',iproc*1000
            Ntot=1
         ENDIF
         
         
c     Calculate differential cross section as a function
c     of transverse energy.
         IF (gen(1:3).NE.'HO1') THEN 
            
            lumpb = REAL(0.001*ntot/xsec)
c     Scale by bin width.
            CALL HZHINRM(100*iproc+11,0,lumpb,1)
            CALL HZHINRM(100*iproc+12,0,lumpb,1)
            CALL HZHINRM(100*iproc+13,0,lumpb,1)
            
c     Now work out the arrays for <ET_xT(i)> needed for the calculation of
c     the invariant cross section. First add together the direct and resloved
c     parts of the ET plots, weighting them accordingly.
            
            DO i_plot = 1,10
               CALL HZHINRM(100*iproc+30+i_plot,0,lumpb,1)
            ENDDO
            
         ENDIF
         
         
         IF ((iproc.eq.2.or.iproc.eq.0).and.gen(1:3).EQ.'HO1') THEN
            
c     We need to do the NLO bit here. The factor of 0.5 isn't needed and
c     the factor of 1000 should be taken account in outfun. All we really 
c     have to do is deal with the final round of integration.
            
c     First the main cross section graph
            
            CALL HZSNLO(11,211,111)
            CALL HZHINRM(11,0,0.001,1)
            
c     Now the dsigma/dxT plots
            
            DO i_plot=12,13
               CALL HZSNLO(i_plot,i_plot+200,i_plot+100)                  
c     Divide by bin width.
               CALL HZHINRM(i_plot,0,0.001,1)
            ENDDO
            
            DO i_plot=31,40
               CALL HZSNLO(i_plot,i_plot+200,i_plot+100)
            ENDDO

         ENDIF


         IF (iproc.EQ.2) THEN

c     Add the resolved and direct processes together.

            DO i_plot=1,10
               CALL HOPERA(130+i_plot,'+E',230+i_plot,30+i_plot,
     &              1.,1.)
            ENDDO            

            DO i_plot=11,13
               CALL HOPERA(100+i_plot,'+E',200+i_plot,i_plot,1.,1.)
            ENDDO

         ENDIF


         IF (iproc.EQ.2.or.iproc.EQ.0) THEN

c     Now we just need to polish off the plots

            DO i_plot=1,5
               mean_w180 = HSTATi(30+i_plot,1,hist,1)
               mean_w255 = HSTATi(35+i_plot,1,hist,1)
               xt_et_w180_mean(i_plot) = mean_w180*mean_w180*mean_w180
               xt_et_w255_mean(i_plot) = mean_w255*mean_w255*mean_w255
            ENDDO
            
            CALL HBOOKB(41,'W180 ETjet means',no_xt,xt,.0)
            CALL HBOOKB(42,'W255 ETjet means',no_xt,xt,.0)	
            
            CALL HPAK(41,xt_et_w180_mean)
            CALL HPAKE(41,xt_et_w180_errs)		
            CALL HPAK(42,xt_et_w255_mean)
            CALL HPAKE(42,xt_et_w255_errs)	
            
            factor_w180=1/(factor1*pi*w_180*hbar_c)
            factor_w255=1/(factor1*pi*w_255*hbar_c)  
            
c     Now compute the scale invariant cross sections
            
            CALL HOPERA(41,'*E',12,12,factor_w180,1.)
            CALL HOPERA(42,'*E',13,13,factor_w255,1.)

c     Now compute the ratio plot. 

            CALL HOPERA(12,'/E',13,14,flux_correct,1.)

c     All plots are now completed

         ENDIF

      ENDIF

      RETURN

      END




















      
